@@ -527,12 +527,47 @@ extern "C"
 
 #define CXD56_GNSS_IOCTL_GET_VAR_EPHEMERIS 49
 
+/* Set usecase mode
+ * This command must be issued in idle mode.
+ *
+ * param[in] arg
+ * The usecase definitions
+ */
+
+#define CXD56_GNSS_IOCTL_SET_USECASE 50
+
+/* Get usecase mode
+ *
+ * param[out] arg
+ * The usecase definitions
+ */
+
+#define CXD56_GNSS_IOCTL_GET_USECASE 51
+
+/* Set enable or disable of 1PPS output
+ * This command must be issued in idle mode.
+ *
+ * param[in] arg
+ * enable(1) or disable(0)
+ */
+
+#define CXD56_GNSS_IOCTL_SET_1PPS_OUTPUT 52
+
+/**
+ * Get the current 1PPS output setting
+ *
+ * @param[out] arg
+ * enable(1) or disable(0)
+ */
+
+#define CXD56_GNSS_IOCTL_GET_1PPS_OUTPUT 53
+
 /* check macros for GNSS commands */
 
 #define CXD56_GNSS_IOCTL_INVAL 0
-#define CXD56_GNSS_IOCTL_MAX   50
+#define CXD56_GNSS_IOCTL_MAX   54
 
-/* Same value to GD Start mode CXD56_GNSS_STMOD_XXXX for GD_Start */
+/* Same value to GD Start mode CXD56_GNSS_STMOD_XXXX for fw_gd_start */
 
 #define CXD56_GNSS_STMOD_COLD       0 /* Cold Start */
 #define CXD56_GNSS_STMOD_WARM       1 /* Warm Start */
@@ -593,6 +628,10 @@ extern "C"
 
 #define CXD56_GNSS_READ_OFFSET_DCREPORT     0x9800
 
+/* Offset for SAR/RLM */
+
+#define CXD56_GNSS_READ_OFFSET_SARRLM       0x9900
+
 /* Offset for Spectrum data */
 
 #define CXD56_GNSS_READ_OFFSET_SPECTRUM     0xa000
@@ -643,6 +682,10 @@ extern "C"
 
 #define CXD56_GNSS_SIG_DCREPORT     15
 
+/* Signal type is GAL SAR/RLM */
+
+#define CXD56_GNSS_SIG_SARRLM       16
+
 /****************************************************************************
  * Public Types
  ****************************************************************************/
