@@ -77,6 +77,7 @@
  ****************************************************************************/
 
 /* Configuration ************************************************************/
+
 /* If processing is not done at the interrupt level, then work queue support
  * is required.
  */
@@ -128,9 +129,9 @@
 /* This should be disabled unless you are performing very low level debug */
 
 #undef CONFIG_C5471_NET_DUMPBUFFER
-//#define CONFIG_C5471_NET_DUMPBUFFER 1
 
 /* Timing values ************************************************************/
+
 /* TX poll deley = 1 seconds. CLK_TCK=number of clock ticks per second */
 
 #define C5471_WDDELAY         (1*CLK_TCK)
@@ -175,6 +176,7 @@
 #define NUM_DESC_RX           64
 
 /* TX descriptor, word #1 */
+
                                          /* Bit 15: reserved */
 #define EIM_TXDESC_PADCRC     0x00004000 /* Bit 14: Enable padding small frames */
                                          /* Bits 11-13: reserved */
@@ -202,10 +204,12 @@
 #define EIM_RXDESC_PADCRC     0x00004000 /* Enable padding for small frames */
 
 /* RX descriptor, word #1 */
+
                                          /* Bits 11-15: reserved */
 #define EIM_RXDESC_BYTEMASK   0x000007ff /* Bits 0-10: Descriptor byte count */
 
 /* EIM_CPU_FILTER bit settings */
+
                                          /* Bits 5-31: reserved */
 #define EIM_FILTER_MACLA      0x00000010 /* Bit 4: Enable logical address+multicast filtering */
 #define EIM_FILTER_LOGICAL    0x00000008 /* Bit 3: Enable ENET logical filtering */
@@ -214,6 +218,7 @@
 #define EIM_FILTER_UNICAST    0x00000001 /* Bit 0: Enable dest CPU address matching */
 
 /* EIM_CTRL bit settings */
+
                                          /* Bits 16-31: Reserved */
 #define EIM_CTRL_ESM_EN       0x00008000 /* Bit 15: Ethernet state machine enable */
                                          /* Bits 9-14: reserved */
@@ -227,6 +232,7 @@
 #define EIM_CTRL_TXCPU_EN     0x00000001 /* Bit 0: Enable processing of CPU TX queue */
 
 /* EIM_STATUS bit settings */
+
                                          /* Bits 10-31: reserved */
 #define EIM_STATUS_CPU_TXLIF  0x00000200 /* Bit 9: Last descriptor of TX packet filled */
 #define EIM_STATUS_CPU_RXLIF  0x00000100 /* Bit 8: Last descriptor of RX queue processed */
@@ -243,7 +249,7 @@
 #define EIM_INTEN_CPU_RXLIF  0x00000100 /* Bit 8: Last descriptor of RX queue processed */
 #define EIM_INTEN_CPU_TX     0x00000080 /* Bit 7: Descriptor filled in TX queue */
 #define EIM_INTEN_CPU_RX     0x00000040 /* Bit 6: Descriptor filled in RX queue */
-                                         /* Bits 3-5: reserved */
+                                        /* Bits 3-5: reserved */
 #define EIM_INTEN_ENET0_ERR  0x00000004 /* Bit 2: ENET0 error interrupt */
 #define EIM_INTEN_ENET0_TX   0x00000002 /* Bit 1: ENET0 TX interrupt */
 #define EIM_INTEN_ENET0_RX   0x00000001 /* Bit 0: ENET0 RX interrupt */
@@ -256,6 +262,7 @@
 #define ENET_ADDR_PCOMPARE    0x00000001 /* Bit 0: Enable physical address comparison */
 
 /* ENET0_MODE bit settings */
+
                                          /* Bits 16-31: reserved */
 #define ENET_MODO_FIFO_EN     0x00008000 /* Bit 15: Fifo enable */
                                          /* Bits 8-14: reserved */
@@ -292,7 +299,7 @@
 
 #define nop() asm("    nop");
 
-/* This is a helper pointer for accessing the contents of the Ethernet header */
+/* This is a helper pointer for accessing the contents of Ethernet header */
 
 #define BUF ((struct eth_hdr_s *)priv->c_dev.d_buf)
 
@@ -311,15 +318,16 @@ static uint8_t g_pktbuf[MAX_NETDEV_PKTSIZE + CONFIG_NET_GUARDSIZE];
 struct c5471_driver_s
 {
   bool    c_bifup;           /* true:ifup false:ifdown */
-  WDOG_ID c_txpoll;          /* TX poll timer */
-  WDOG_ID c_txtimeout;       /* TX timeout timer */
+  struct wdog_s c_txpoll;    /* TX poll timer */
+  struct wdog_s c_txtimeout; /* TX timeout timer */
   struct work_s c_irqwork;   /* For deferring interrupt work to the work queue */
   struct work_s c_pollwork;  /* For deferring poll work to the work queue */
 
-  /* Note: According to the C547x documentation: "The software has to maintain
-   * two pointers to the current RX-CPU and TX-CPU descriptors. At init time,
-   * they have to be set to the first descriptors of each queue, and they have
-   * to be incremented each time a descriptor ownership is give to the SWITCH".
+  /* Note: According to the C547x documentation: "The software has to
+   * maintain two pointers to the current RX-CPU and TX-CPU descriptors.
+   * At init time, they have to be set to the first descriptors of each
+   * queue, and they have to be incremented each time a descriptor
+   * ownership is give to the SWITCH".
    */
 
   volatile uint32_t c_txcpudesc;
@@ -408,10 +416,10 @@ static int  c5471_interrupt(int irq, FAR void *context, FAR void *arg);
 /* Watchdog timer expirations */
 
 static void c5471_txtimeout_work(FAR void *arg);
-static void c5471_txtimeout_expiry(int argc, uint32_t arg, ...);
+static void c5471_txtimeout_expiry(wdparm_t arg);
 
 static void c5471_poll_work(FAR void *arg);
-static void c5471_poll_expiry(int argc, uint32_t arg, ...);
+static void c5471_poll_expiry(wdparm_t arg);
 
 /* NuttX callback functions */
 
@@ -449,8 +457,8 @@ static void c5471_macassign(struct c5471_driver_s *priv);
 static inline void c5471_dumpbuffer(const char *msg, const uint8_t *buffer,
                                     unsigned int nbytes)
 {
-  /* CONFIG_DEBUG_FEATURES, CONFIG_DEBUG_INFO, and CONFIG_DEBUG_NET have to be
-   * defined or the following does nothing.
+  /* CONFIG_DEBUG_FEATURES, CONFIG_DEBUG_INFO, and CONFIG_DEBUG_NET have to
+   * be defined or the following does nothing.
    */
 
   ninfodumpbuffer(msg, buffer, nbytes);
@@ -481,8 +489,8 @@ static inline void c5471_dumpbuffer(const char *msg, const uint8_t *buffer,
 
 static void c5471_mdtxbit (int bit_state)
 {
-  /* Note: any non-zero "bit_state" supplied by the caller means we should clk a "1"
-   * out the MDIO pin.
+  /* Note: any non-zero "bit_state" supplied by the caller means we should
+   * clk a "1" out the MDIO pin.
    */
 
   /* Config MDIO as output pin. */
@@ -722,17 +730,17 @@ static int c5471_mdread (int adr, int reg)
  *   handle the physical layer (PHY). It's a h/w block that on the one end
  *   offers a Media Independent Interface (MII) which is connected to the
  *   Ethernet Interface Module (EIM) internal to the C547x and on the other
- *   end offers either the 10baseT or 100baseT electrical interface connecting
- *   to an RJ45 onboard network connector. The PHY transeiver has several
- *   internal registers allowing host configuration and status access. These
- *   internal registers are accessible by clocking serial data in/out of the
- *   MDIO pin of the LU3X31T-T64 chip. For c547X, the MDC and the MDIO pins
- *   are connected to the C547x GPIO15 and GPIO14 pins respectively. Host
- *   software twiddles the GPIO pins appropriately to get data serially into
- *   and out of the chip. This is typically a one time operation at boot and
- *   normal operation of the transeiver involves EIM/Transeiver interaction at
- *   the other pins of the transeiver chip and doesn't require host intervention
- *   at the MDC and MDIO pins.
+ *   end offers either the 10baseT or 100baseT electrical interface
+ *   connecting to an RJ45 onboard network connector. The PHY transeiver has
+ *   several internal registers allowing host configuration and status
+ *   access. These internal registers are accessible by clocking serial data
+ *   in/out of the MDIO pin of the LU3X31T-T64 chip. For c547X, the MDC and
+ *   the MDIO pins are connected to the C547x GPIO15 and GPIO14 pins
+ *   respectively. Host software twiddles the GPIO pins appropriately to get
+ *   data serially into and out of the chip. This is typically a one time
+ *   operation at boot and normal operation of the transeiver involves
+ *   EIM/Transeiver interaction at the other pins of the transeiver chip and
+ *   doesn't require host intervention at the MDC and MDIO pins.
  *
  ****************************************************************************/
 
@@ -746,7 +754,7 @@ static int c5471_phyinit (void)
 
   /* enable gpio bits 15,14 */
 
-  putreg32((getreg32(GPIO_EN) | 0x0000C000), GPIO_EN);
+  putreg32((getreg32(GPIO_EN) | 0x0000c000), GPIO_EN);
 
   /* config gpio(15); out -> MDCLK */
 
@@ -758,7 +766,7 @@ static int c5471_phyinit (void)
 
   /* initial pin state; MDCLK = 0 */
 
-  putreg32((getreg32(GPIO_IO) & 0x000F3FFF), GPIO_IO);
+  putreg32((getreg32(GPIO_IO) & 0x000f3fff), GPIO_IO);
 
   /* Next, request a chip reset */
 
@@ -770,7 +778,8 @@ static int c5471_phyinit (void)
 
   /* Next, Read out the chip ID */
 
-  phyid = (c5471_mdread(0, MD_PHY_MSB_REG) << 16) | c5471_mdread(0, MD_PHY_LSB_REG);
+  phyid = (c5471_mdread(0, MD_PHY_MSB_REG) << 16) |
+          c5471_mdread(0, MD_PHY_LSB_REG);
   if (phyid != LU3X31_T64_PHYID)
     {
       nerr("ERROR: Unrecognized PHY ID: %08x\n", phyid);
@@ -805,10 +814,10 @@ static int c5471_phyinit (void)
 
   /* Next, Setup GPIO pins to talk serially to the Lucent transeiver chip */
 
-  putreg32((getreg32(GPIO_EN)  |  0x0000C000), GPIO_EN);   /* enable gpio bits 15,14 */
+  putreg32((getreg32(GPIO_EN)  |  0x0000c000), GPIO_EN);  /* enable gpio bits 15,14 */
   putreg32((getreg32(GPIO_CIO) & ~0x00008000), GPIO_CIO); /* config gpio(15); out -> MDCLK */
-  putreg32((getreg32(GPIO_CIO) |  0x00004000), GPIO_CIO);  /* config gpio(14); in <- MDIO */
-  putreg32((getreg32(GPIO_IO)  &  0x000F3FFF), GPIO_IO);   /* initial pin state; MDCLK = 0 */
+  putreg32((getreg32(GPIO_CIO) |  0x00004000), GPIO_CIO); /* config gpio(14); in <- MDIO */
+  putreg32((getreg32(GPIO_IO)  &  0x000f3fff), GPIO_IO);  /* initial pin state; MDCLK = 0 */
 
   return 1;
 }
@@ -902,8 +911,9 @@ static int c5471_transmit(struct c5471_driver_s *priv)
 
   while (nbytes)
     {
-      /* Verify that the hardware is ready to send another packet */
-      /* Words #0 and #1 of descriptor */
+      /* Verify that the hardware is ready to send another packet
+       * Words #0 and #1 of descriptor
+       */
 
       while (EIM_TXDESC_OWN_HOST & getreg32(priv->c_rxcpudesc))
         {
@@ -914,18 +924,22 @@ static int c5471_transmit(struct c5471_driver_s *priv)
 
       if (bfirstframe)
         {
-          putreg32((getreg32(priv->c_rxcpudesc) | EIM_RXDESC_FIF), priv->c_rxcpudesc);
+          putreg32((getreg32(priv->c_rxcpudesc) | EIM_RXDESC_FIF),
+                   priv->c_rxcpudesc);
         }
       else
         {
-          putreg32((getreg32(priv->c_rxcpudesc) & ~EIM_RXDESC_FIF), priv->c_rxcpudesc);
+          putreg32((getreg32(priv->c_rxcpudesc) & ~EIM_RXDESC_FIF),
+                   priv->c_rxcpudesc);
         }
 
-      putreg32((getreg32(priv->c_rxcpudesc) & ~EIM_RXDESC_PADCRC), priv->c_rxcpudesc);
+      putreg32((getreg32(priv->c_rxcpudesc) & ~EIM_RXDESC_PADCRC),
+               priv->c_rxcpudesc);
 
       if (bfirstframe)
         {
-          putreg32((getreg32(priv->c_rxcpudesc) | EIM_RXDESC_PADCRC), priv->c_rxcpudesc);
+          putreg32((getreg32(priv->c_rxcpudesc) | EIM_RXDESC_PADCRC),
+                   priv->c_rxcpudesc);
         }
 
       if (nbytes >= EIM_PACKET_BYTES)
@@ -937,8 +951,10 @@ static int c5471_transmit(struct c5471_driver_s *priv)
           framelen = nbytes;
         }
 
-      /* Submit ether frame bytes to the C5472 Ether Module packet memory space. */
-      /* Get the number of 16-bit values to transfer by dividing by 2 with round up. */
+      /* Submit ether frame bytes to the C5472 Ether Module packet memory
+       * space. Get the number of 16-bit values to transfer by dividing by
+       * 2 with round up.
+       */
 
       nshorts = (framelen + 1) >> 1;
 
@@ -952,25 +968,31 @@ static int c5471_transmit(struct c5471_driver_s *priv)
           packetmem[i] = htons(((uint16_t *)dev->d_buf)[j]);
         }
 
-      putreg32(((getreg32(priv->c_rxcpudesc) & ~EIM_RXDESC_BYTEMASK) | framelen),
-               priv->c_rxcpudesc);
+      putreg32(((getreg32(priv->c_rxcpudesc) & ~EIM_RXDESC_BYTEMASK) |
+                framelen), priv->c_rxcpudesc);
       nbytes -= framelen;
-      ninfo("Wrote framelen: %d nbytes: %d nshorts: %d\n", framelen, nbytes, nshorts);
+      ninfo("Wrote framelen: %d nbytes: %d nshorts: %d\n",
+            framelen, nbytes, nshorts);
 
       if (0 == nbytes)
         {
-          putreg32((getreg32(priv->c_rxcpudesc) | EIM_RXDESC_LIF), priv->c_rxcpudesc);
+          putreg32((getreg32(priv->c_rxcpudesc) | EIM_RXDESC_LIF),
+                   priv->c_rxcpudesc);
         }
       else
         {
-          putreg32((getreg32(priv->c_rxcpudesc) & ~EIM_RXDESC_LIF), priv->c_rxcpudesc);
+          putreg32((getreg32(priv->c_rxcpudesc) & ~EIM_RXDESC_LIF),
+                   priv->c_rxcpudesc);
         }
 
       /* We're done with that descriptor; give access rights back to h/w */
 
-      putreg32((getreg32(priv->c_rxcpudesc) | EIM_RXDESC_OWN_HOST), priv->c_rxcpudesc);
+      putreg32((getreg32(priv->c_rxcpudesc) | EIM_RXDESC_OWN_HOST),
+               priv->c_rxcpudesc);
 
-      /* Next, tell Ether Module that those submitted bytes are ready for the wire */
+      /* Next, tell Ether Module that
+       * those submitted bytes are ready for the wire
+       */
 
       putreg32(0x00000001, EIM_CPU_RXREADY);
       priv->c_lastdescend = priv->c_rxcpudesc;
@@ -989,8 +1011,8 @@ static int c5471_transmit(struct c5471_driver_s *priv)
 
   /* Setup the TX timeout watchdog (perhaps restarting the timer) */
 
-  wd_start(priv->c_txtimeout, C5471_TXTIMEOUT,
-           c5471_txtimeout_expiry, 1, (wdparm_t)priv);
+  wd_start(&priv->c_txtimeout, C5471_TXTIMEOUT,
+           c5471_txtimeout_expiry, (wdparm_t)priv);
   return OK;
 }
 
@@ -998,8 +1020,9 @@ static int c5471_transmit(struct c5471_driver_s *priv)
  * Function: c5471_txpoll
  *
  * Description:
- *   The transmitter is available, check if the network has any outgoing packets ready
- *   to send.  This is a callback from devif_poll().  devif_poll() may be called:
+ *   The transmitter is available, check if the network has any outgoing
+ *   packets ready to send. This is a callback from devif_poll().
+ *   devif_poll() may be called:
  *
  *   1. When the preceding TX packet send is complete,
  *   2. When the preceding TX packet send timesout and the interface is reset
@@ -1053,8 +1076,8 @@ static int c5471_txpoll(struct net_driver_s *dev)
 
           c5471_transmit(priv);
 
-          /* Check if the ESM has let go of the RX descriptor giving us access
-           * rights to submit another Ethernet frame.
+          /* Check if the ESM has let go of the RX descriptor giving us
+           * access rights to submit another Ethernet frame.
            */
 
           if ((EIM_TXDESC_OWN_HOST & getreg32(priv->c_rxcpudesc)) != 0)
@@ -1066,8 +1089,8 @@ static int c5471_txpoll(struct net_driver_s *dev)
         }
     }
 
-  /* If zero is returned, the polling will continue until all connections have
-   * been examined.
+  /* If zero is returned, the polling will continue until all connections
+   * have been examined.
    */
 
   return 0;
@@ -1114,7 +1137,9 @@ static void c5471_rxstatus(struct c5471_driver_s *priv)
           break;
         }
 
-      /* This packet is made up of several descriptors, find next one in chain. */
+      /* This packet is made up of several descriptors,
+       * find next one in chain.
+       */
 
       if (EIM_TXDESC_WRAP_NEXT & getreg32(desc))
         {
@@ -1203,8 +1228,9 @@ static void c5471_receive(struct c5471_driver_s *priv)
   int j = 0;
 
   /* Walk the newly received packet contained within the EIM and transfer
-   * its contents to the network buffer. This frees up the memory contained within
-   * the EIM for additional packets that might be received later from the network.
+   * its contents to the network buffer. This frees up the memory contained
+   * within the EIM for additional packets that might be received later from
+   * the network.
    */
 
   ninfo("Reading TX CPU desc: %08x\n", priv->c_txcpudesc);
@@ -1226,24 +1252,28 @@ static void c5471_receive(struct c5471_driver_s *priv)
       framelen   = (getreg32(priv->c_txcpudesc) & EIM_TXDESC_BYTEMASK);
       packetlen += framelen;
 
-      /* Check if the received packet will fit within the network packet buffer */
+      /* Check if the received packet will fit
+       * within the network packet buffer
+       */
 
       if (packetlen < (CONFIG_NET_ETH_PKTSIZE + 4))
         {
           /* Get the packet memory from words #2 and #3 of descriptor */
 
-          packetmem = (uint16_t *)getreg32(priv->c_txcpudesc + sizeof(uint32_t));
+          packetmem = (uint16_t *)
+            getreg32(priv->c_txcpudesc + sizeof(uint32_t));
 
           /* Divide by 2 with round up to get the number of 16-bit words. */
 
           nshorts = (framelen + 1) >> 1;
-          ninfo("Reading framelen: %d packetlen: %d nshorts: %d packetmen: %p\n",
+          ninfo("Reading framelen: "
+                "%d packetlen: %d nshorts: %d packetmen: %p\n",
                  framelen, packetlen, nshorts, packetmem);
 
           for (i = 0 ; i < nshorts; i++, j++)
             {
-              /* Copy the data data from the hardware to priv->c_dev.d_buf 16-bits at
-               * a time.
+              /* Copy the data data from the hardware to priv->c_dev.d_buf
+               * 16-bits at a time.
                */
 
               ((uint16_t *)dev->d_buf)[j] = htons(packetmem[i]);
@@ -1259,23 +1289,30 @@ static void c5471_receive(struct c5471_driver_s *priv)
           bmore = false;
         }
 
-      /* Next, Clear all bits of words0/1 of the emptied descriptor except preserve
-       * the settings of a select few. Can leave descriptor words 2/3 alone.
+      /* Next, Clear all bits of words0/1 of the emptied descriptor
+       * except preserve the settings of a select few. Can leave
+       * descriptor words 2/3 alone.
        */
 
-      putreg32((getreg32(priv->c_txcpudesc) & (EIM_TXDESC_WRAP_NEXT | EIM_TXDESC_INTRE)),
+      putreg32((getreg32(priv->c_txcpudesc) &
+               (EIM_TXDESC_WRAP_NEXT | EIM_TXDESC_INTRE)),
                priv->c_txcpudesc);
 
-      /* Next, Give ownership of now emptied descriptor back to the Ether Module's SWITCH */
+      /* Next, Give ownership of now emptied descriptor back to
+       * the Ether Module's SWITCH
+       */
 
-      putreg32((getreg32(priv->c_txcpudesc) | EIM_TXDESC_OWN_HOST), priv->c_txcpudesc);
+      putreg32((getreg32(priv->c_txcpudesc) | EIM_TXDESC_OWN_HOST),
+               priv->c_txcpudesc);
 
       /* Advance to the next data buffer */
 
       c5471_inctxcpu(priv);
     }
 
-  /* Adjust the packet length to remove the CRC bytes that the network doesn't care about. */
+  /* Adjust the packet length to remove the CRC bytes
+   * that the network doesn't care about.
+   */
 
   packetlen -= 4;
 
@@ -1285,8 +1322,8 @@ static void c5471_receive(struct c5471_driver_s *priv)
   priv->c_rxpackets++;
 #endif
 
-  /* If we successfully transferred the data into the network buffer, then pass it on
-   * to the network for processing.
+  /* If we successfully transferred the data into the network buffer,
+   * then pass it on to the network for processing.
    */
 
   if (packetlen > 0 && packetlen < CONFIG_NET_ETH_PKTSIZE)
@@ -1294,11 +1331,12 @@ static void c5471_receive(struct c5471_driver_s *priv)
       /* Set amount of data in priv->c_dev.d_len. */
 
       dev->d_len = packetlen;
-      ninfo("Received packet, packetlen: %d type: %02x\n", packetlen, ntohs(BUF->type));
+      ninfo("Received packet, packetlen: %d type: %02x\n",
+            packetlen, ntohs(BUF->type));
       c5471_dumpbuffer("Received packet", dev->d_buf, dev->d_len);
 
 #ifdef CONFIG_NET_PKT
-      /* When packet sockets are enabled, feed the frame into the packet tap */
+      /* When packet sockets are enabled, feed the frame into the tap */
 
       pkt_input(dev);
 #endif
@@ -1318,9 +1356,9 @@ static void c5471_receive(struct c5471_driver_s *priv)
           ipv4_input(dev);
 
           /* If the above function invocation resulted in data that should be
-           * sent out on the network, the field  d_len will set to a value > 0.
-           * Send that data now if ESM has let go of the RX descriptor giving us
-           * access rights to submit another Ethernet frame.
+           * sent out on the network, d_len field will set to a value > 0.
+           * Send that data now if ESM has let go of the RX descriptor giving
+           * us access rights to submit another Ethernet frame.
            */
 
           if (dev->d_len > 0 &&
@@ -1358,9 +1396,9 @@ static void c5471_receive(struct c5471_driver_s *priv)
           ipv6_input(dev);
 
           /* If the above function invocation resulted in data that should be
-           * sent out on the network, the field  d_len will set to a value > 0.
-           * Send that data now if ESM has let go of the RX descriptor giving us
-           * access rights to submit another Ethernet frame.
+           * sent out on the network, d_len field will set to a value > 0.
+           * Send that data now if ESM has let go of the RX descriptor giving
+           * us access rights to submit another Ethernet frame.
            */
 
           if (dev->d_len > 0 &&
@@ -1394,9 +1432,9 @@ static void c5471_receive(struct c5471_driver_s *priv)
           arp_arpin(dev);
 
           /* If the above function invocation resulted in data that should be
-           * sent out on the network, the field  d_len will set to a value > 0.
-           * Send that data now if ESM has let go of the RX descriptor giving us
-           * access rights to submit another Ethernet frame.
+           * sent out on the network, d_len field will set to a value > 0.
+           * Send that data now if ESM has let go of the RX descriptor giving
+           * us access rights to submit another Ethernet frame.
            */
 
           if (dev->d_len > 0 &&
@@ -1453,7 +1491,9 @@ static void c5471_txstatus(struct c5471_driver_s *priv)
               break;
             }
 
-          /* This packet is made up of several descriptors, find next one in chain. */
+          /* This packet is made up of several descriptors,
+           * find next one in chain.
+           */
 
           if (EIM_RXDESC_WRAP_NEXT & getreg32(priv->c_rxcpudesc))
             {
@@ -1535,7 +1575,7 @@ static void c5471_txdone(struct c5471_driver_s *priv)
 {
   /* If no further xmits are pending, then cancel the TX timeout */
 
-  wd_cancel(priv->c_txtimeout);
+  wd_cancel(&priv->c_txtimeout);
 
   /* Then poll the network for new XMIT data */
 
@@ -1572,13 +1612,14 @@ static void c5471_interrupt_work(FAR void *arg)
   priv->c_eimstatus = getreg32(EIM_STATUS);
 
   /* Handle interrupts according to status bit settings */
+
   /* Check if we received an incoming packet, if so, call c5471_receive() */
 
   if ((EIM_STATUS_CPU_TX & priv->c_eimstatus) != 0)
     {
       /* An incoming packet has been received by the EIM from the network and
-       * the interrupt associated with EIM's CPU TX queue has been asserted. It
-       * is the EIM's CPU TX queue that we need to read from to get those
+       * the interrupt associated with EIM's CPU TX queue has been asserted.
+       * It is the EIM's CPU TX queue that we need to read from to get those
        * packets.  We use this terminology to stay consistent with the Orion
        * documentation.
        */
@@ -1594,12 +1635,14 @@ static void c5471_interrupt_work(FAR void *arg)
       c5471_receive(priv);
     }
 
-  /* Check is a packet transmission just completed.  If so, call c5471_txdone */
+  /* Check is a packet transmission just completed.
+   * If so, call c5471_txdone
+   */
 
   if ((EIM_STATUS_CPU_RX & priv->c_eimstatus) != 0)
     {
       /* An outgoing packet has been processed by the EIM and the interrupt
-       * associated with EIM's CPU RX queue has been asserted. It is the EIM's
+       * associated with EIM's CPU RX queue has been asserted. It is EIM's
        * CPU RX queue that we put packets on to send them *out*. TWe use this
        * terminology to stay consistent with the Orion documentation.
        */
@@ -1662,7 +1705,7 @@ static int c5471_interrupt(int irq, FAR void *context, FAR void *arg)
        * expiration and the deferred interrupt processing.
        */
 
-       wd_cancel(priv->c_txtimeout);
+       wd_cancel(&priv->c_txtimeout);
     }
 
   /* Schedule to perform the interrupt processing on the worker thread. */
@@ -1719,8 +1762,7 @@ static void c5471_txtimeout_work(FAR void *arg)
  *   The last TX never completed.  Reset the hardware and start again.
  *
  * Input Parameters:
- *   argc - The number of available arguments
- *   arg  - The first argument
+ *   arg  - The argument
  *
  * Returned Value:
  *   None
@@ -1730,7 +1772,7 @@ static void c5471_txtimeout_work(FAR void *arg)
  *
  ****************************************************************************/
 
-static void c5471_txtimeout_expiry(int argc, wdparm_t arg, ...)
+static void c5471_txtimeout_expiry(wdparm_t arg)
 {
   struct c5471_driver_s *priv = (struct c5471_driver_s *)arg;
 
@@ -1776,15 +1818,17 @@ static void c5471_poll_work(FAR void *arg)
   net_lock();
   if ((EIM_TXDESC_OWN_HOST & getreg32(priv->c_rxcpudesc)) == 0)
     {
-      /* If so, update TCP timing states and poll the network for new XMIT data */
+      /* If so, update TCP timing states and
+       * poll the network for new XMIT data
+       */
 
       devif_timer(&priv->c_dev, C5471_WDDELAY, c5471_txpoll);
     }
 
   /* Setup the watchdog poll timer again */
 
-  wd_start(priv->c_txpoll, C5471_WDDELAY, c5471_poll_expiry, 1,
-           (wdparm_t)priv);
+  wd_start(&priv->c_txpoll, C5471_WDDELAY,
+           c5471_poll_expiry, (wdparm_t)priv);
   net_unlock();
 }
 
@@ -1795,8 +1839,7 @@ static void c5471_poll_work(FAR void *arg)
  *   Periodic timer handler.  Called from the timer interrupt handler.
  *
  * Input Parameters:
- *   argc - The number of available arguments
- *   arg  - The first argument
+ *   arg  - The argument
  *
  * Returned Value:
  *   None
@@ -1806,7 +1849,7 @@ static void c5471_poll_work(FAR void *arg)
  *
  ****************************************************************************/
 
-static void c5471_poll_expiry(int argc, wdparm_t arg, ...)
+static void c5471_poll_expiry(wdparm_t arg)
 {
   struct c5471_driver_s *priv = (struct c5471_driver_s *)arg;
 
@@ -1860,18 +1903,18 @@ static int c5471_ifup(struct net_driver_s *dev)
   putreg32(((getreg32(EIM_INTEN) | EIM_INTEN_CPU_TX | EIM_INTEN_CPU_RX)),
            EIM_INTEN);
 
-  /* Next, go on-line. According to the C547X documentation the enables have to
-   * occur in this order to insure proper operation; ESM first then the ENET.
+  /* Next, go on-line. According to the C547X documentation the enables have
+   * to occur in this order to insure proper operation; ESM first then ENET.
    */
 
-  putreg32((getreg32(EIM_CTRL) | EIM_CTRL_ESM_EN), EIM_CTRL);   /* enable ESM */
+  putreg32((getreg32(EIM_CTRL) | EIM_CTRL_ESM_EN), EIM_CTRL);      /* enable ESM */
   putreg32((getreg32(ENET0_MODE) | ENET_MODE_ENABLE), ENET0_MODE); /* enable ENET */
   up_mdelay(100);
 
   /* Set and activate a timer process */
 
-  wd_start(priv->c_txpoll, C5471_WDDELAY, c5471_poll_expiry,
-           1, (wdparm_t)priv);
+  wd_start(&priv->c_txpoll, C5471_WDDELAY,
+           c5471_poll_expiry, (wdparm_t)priv);
 
   /* Enable the Ethernet interrupt */
 
@@ -1923,8 +1966,8 @@ static int c5471_ifdown(struct net_driver_s *dev)
 
   /* Cancel the TX poll timer and TX timeout timers */
 
-  wd_cancel(priv->c_txpoll);
-  wd_cancel(priv->c_txtimeout);
+  wd_cancel(&priv->c_txpoll);
+  wd_cancel(&priv->c_txtimeout);
 
   /* Reset the device */
 
@@ -2035,7 +2078,8 @@ static int c5471_txavail(FAR struct net_driver_s *dev)
 #ifdef CONFIG_NET_MCASTGROUP
 static int c5471_addmac(struct net_driver_s *dev, FAR const uint8_t *mac)
 {
-  FAR struct c5471_driver_s *priv = (FAR struct c5471_driver_s *)dev->d_private;
+  FAR struct c5471_driver_s *priv =
+    (FAR struct c5471_driver_s *)dev->d_private;
 
   /* Add the MAC address to the hardware multicast routing table */
 
@@ -2048,8 +2092,8 @@ static int c5471_addmac(struct net_driver_s *dev, FAR const uint8_t *mac)
  * Function: c5471_rmmac
  *
  * Description:
- *   NuttX Callback: Remove the specified MAC address from the hardware multicast
- *   address filtering
+ *   NuttX Callback: Remove the specified MAC address from the hardware
+ *   multicast address filtering
  *
  * Input Parameters:
  *   dev  - Reference to the NuttX driver state structure
@@ -2065,7 +2109,8 @@ static int c5471_addmac(struct net_driver_s *dev, FAR const uint8_t *mac)
 #ifdef CONFIG_NET_MCASTGROUP
 static int c5471_rmmac(struct net_driver_s *dev, FAR const uint8_t *mac)
 {
-  FAR struct c5471_driver_s *priv = (FAR struct c5471_driver_s *)dev->d_private;
+  FAR struct c5471_driver_s *priv =
+    (FAR struct c5471_driver_s *)dev->d_private;
 
   /* Add the MAC address to the hardware multicast routing table */
 
@@ -2140,13 +2185,13 @@ static void c5471_eimconfig(struct c5471_driver_s *priv)
   int i;
 
   desc = EIM_RAM_START;
-  pbuf = EIM_RAM_START + 0x6C0;
+  pbuf = EIM_RAM_START + 0x6c0;
 
   /* TX ENET 0 */
 
   ninfo("TX ENET0 desc: %08x pbuf: %08x\n", desc, pbuf);
   putreg32((desc & 0x0000ffff), ENET0_TDBA); /* 16-bit offset address */
-  for (i = NUM_DESC_TX-1; i >= 0; i--)
+  for (i = NUM_DESC_TX - 1; i >= 0; i--)
     {
       if (i == 0)
         val = EIM_TXDESC_WRAP_NEXT;
@@ -2173,7 +2218,7 @@ static void c5471_eimconfig(struct c5471_driver_s *priv)
 
   ninfo("RX ENET0 desc: %08x pbuf: %08x\n", desc, pbuf);
   putreg32((desc & 0x0000ffff), ENET0_RDBA); /* 16-bit offset address */
-  for (i = NUM_DESC_RX-1; i >= 0; i--)
+  for (i = NUM_DESC_RX - 1; i >= 0; i--)
     {
       if (i == 0)
         val = EIM_RXDESC_WRAP_NEXT;
@@ -2201,7 +2246,7 @@ static void c5471_eimconfig(struct c5471_driver_s *priv)
   ninfo("TX CPU desc: %08x pbuf: %08x\n", desc, pbuf);
   priv->c_txcpudesc = desc;
   putreg32((desc & 0x0000ffff), EIM_CPU_TXBA); /* 16-bit offset address */
-  for (i = NUM_DESC_TX-1; i >= 0; i--)
+  for (i = NUM_DESC_TX - 1; i >= 0; i--)
     {
       /* Set words 1+2 of the TXDESC */
 
@@ -2231,7 +2276,7 @@ static void c5471_eimconfig(struct c5471_driver_s *priv)
   ninfo("RX CPU desc: %08x pbuf: %08x\n", desc, pbuf);
   priv->c_rxcpudesc = desc;
   putreg32((desc & 0x0000ffff), EIM_CPU_RXBA); /* 16-bit offset address */
-  for (i = NUM_DESC_RX-1; i >= 0; i--)
+  for (i = NUM_DESC_RX - 1; i >= 0; i--)
     {
       /* Set words 1+2 of the RXDESC */
 
@@ -2266,9 +2311,10 @@ static void c5471_eimconfig(struct c5471_driver_s *priv)
 
 #if 0
   putreg32(EIM_FILTER_UNICAST, EIM_CPU_FILTER);
+#elif 0
+  putreg32(EIM_FILTER_LOGICAL | EIM_FILTER_UNICAST | EIM_FILTER_MULTICAST |
+           EIM_FILTER_BROADCAST, EIM_CPU_FILTER);
 #else
-//  putreg32(EIM_FILTER_LOGICAL | EIM_FILTER_UNICAST | EIM_FILTER_MULTICAST |
-//           EIM_FILTER_BROADCAST, EIM_CPU_FILTER);
   putreg32(EIM_FILTER_UNICAST | EIM_FILTER_MULTICAST | EIM_FILTER_BROADCAST,
            EIM_CPU_FILTER);
 #endif
@@ -2440,7 +2486,8 @@ void arm_netinitialize(void)
 
   /* Initialize the driver structure */
 
-  memset(g_c5471, 0, CONFIG_C5471_NET_NINTERFACES*sizeof(struct c5471_driver_s));
+  memset(g_c5471, 0,
+    CONFIG_C5471_NET_NINTERFACES * sizeof(struct c5471_driver_s));
   g_c5471[0].c_dev.d_buf     = g_pktbuf;        /* Single packet buffer */
   g_c5471[0].c_dev.d_ifup    = c5471_ifup;      /* I/F down callback */
   g_c5471[0].c_dev.d_ifdown  = c5471_ifdown;    /* I/F up (new IP address) callback */
@@ -2449,12 +2496,7 @@ void arm_netinitialize(void)
   g_c5471[0].c_dev.d_addmac  = c5471_addmac;    /* Add multicast MAC address */
   g_c5471[0].c_dev.d_rmmac   = c5471_rmmac;     /* Remove multicast MAC address */
 #endif
-  g_c5471[0].c_dev.d_private = (void *)g_c5471; /* Used to recover private state from dev */
-
-  /* Create a watchdog for timing polling for and timing of transmissions */
-
-  g_c5471[0].c_txpoll        = wd_create();     /* Create periodic poll timer */
-  g_c5471[0].c_txtimeout     = wd_create();     /* Create TX timeout timer */
+  g_c5471[0].c_dev.d_private = g_c5471;         /* Used to recover private state from dev */
 
   /* Register the device with the OS so that socket IOCTLs can be performed */
 
