@@ -644,8 +644,6 @@ static int dma_setintrcallback(int ch, dma_callback_t func, void *data)
   g_dmach[ch].callback = func;
   g_dmach[ch].arg = data;
 
-  up_enable_irq(irq_map[ch]);
-
   return 0;
 }
 
@@ -659,8 +657,6 @@ static int dma_clearintrcallback(int ch)
   g_dmach[ch].callback = NULL;
   g_dmach[ch].arg = NULL;
 
-  up_disable_irq(irq_map[ch]);
-
   return 0;
 }
 
@@ -738,6 +734,7 @@ void weak_function arm_dma_initialize(void)
   for (i = 0; i < NCHANNELS; i++)
     {
       g_dmach[i].chan = i;
+      up_enable_irq(irq_map[i]);
     }
 
   nxsem_init(&g_dmaexc, 0, 1);
@@ -775,7 +772,7 @@ DMA_HANDLE cxd56_dmachannel(int ch, ssize_t maxsize)
 
   /* Get exclusive access to allocate channel */
 
-  nxsem_wait(&g_dmaexc);
+  nxsem_wait_uninterruptible(&g_dmaexc);
 
   if (ch < 0 || ch >= NCHANNELS)
     {
@@ -858,7 +855,7 @@ void cxd56_dmafree(DMA_HANDLE handle)
       return;
     }
 
-  nxsem_wait(&g_dmaexc);
+  nxsem_wait_uninterruptible(&g_dmaexc);
 
   if (!dmach->inuse)
     {
