@@ -98,7 +98,7 @@ struct cxd56_i2cdev_s
 
   sem_t            mutex;      /* Only one thread can access at a time */
   sem_t            wait;       /* Place to wait for transfer completion */
-  WDOG_ID          timeout;    /* watchdog to timeout when bus hung */
+  struct wdog_s    timeout;    /* watchdog to timeout when bus hung */
   uint32_t         frequency;  /* Current I2C frequency */
   ssize_t          reg_buff_offset;
   ssize_t          rw_size;
@@ -146,6 +146,9 @@ static struct cxd56_i2cdev_s g_i2c2dev =
  * Private Functions
  ****************************************************************************/
 
+static inline int i2c_takesem(FAR sem_t *sem);
+static inline int i2c_givesem(FAR sem_t *sem);
+
 static inline uint32_t i2c_reg_read(struct cxd56_i2cdev_s *priv,
                                     uint32_t offset);
 static inline void i2c_reg_write(struct cxd56_i2cdev_s *priv,
@@ -159,19 +162,37 @@ static int cxd56_i2c_disable(struct cxd56_i2cdev_s *priv);
 static void cxd56_i2c_enable(struct cxd56_i2cdev_s *priv);
 
 static int  cxd56_i2c_interrupt(int irq, FAR void *context, FAR void *arg);
-static void cxd56_i2c_timeout(int argc, uint32_t arg, ...);
+static void cxd56_i2c_timeout(wdparm_t arg);
 static void cxd56_i2c_setfrequency(struct cxd56_i2cdev_s *priv,
                                    uint32_t frequency);
 static int  cxd56_i2c_transfer(FAR struct i2c_master_s *dev,
                                FAR struct i2c_msg_s *msgs, int count);
 #ifdef CONFIG_I2C_RESET
-static int cxd56_i2c_reset(FAR struct i2c_master_s * dev);
+static int cxd56_i2c_reset(FAR struct i2c_master_s *dev);
 #endif
 #if defined(CONFIG_CXD56_I2C0_SCUSEQ) || defined(CONFIG_CXD56_I2C1_SCUSEQ)
 static int  cxd56_i2c_transfer_scu(FAR struct i2c_master_s *dev,
                                    FAR struct i2c_msg_s *msgs, int count);
 #endif
 
+/****************************************************************************
+ * Name: i2c_takesem
+ ****************************************************************************/
+
+static inline int i2c_takesem(FAR sem_t *sem)
+{
+  return nxsem_wait_uninterruptible(sem);
+}
+
+/****************************************************************************
+ * Name: i2c_givesem
+ ****************************************************************************/
+
+static inline int i2c_givesem(FAR sem_t *sem)
+{
+  return nxsem_post(sem);
+}
+
 /****************************************************************************
  * Name: cxd56_i2c_pincontrol
  *
@@ -362,13 +383,13 @@ static void cxd56_i2c_setfrequency(struct cxd56_i2cdev_s *priv,
  *
  ****************************************************************************/
 
-static void cxd56_i2c_timeout(int argc, uint32_t arg, ...)
+static void cxd56_i2c_timeout(wdparm_t arg)
 {
   struct cxd56_i2cdev_s *priv = (struct cxd56_i2cdev_s *)arg;
   irqstate_t flags            = enter_critical_section();
 
   priv->error = -ENODEV;
-  nxsem_post(&priv->wait);
+  i2c_givesem(&priv->wait);
   leave_critical_section(flags);
 }
 
@@ -472,10 +493,10 @@ static int cxd56_i2c_interrupt(int irq, FAR void *context, FAR void *arg)
        * Therefore, call nxsem_post() only when wd_cancel() succeeds.
        */
 
-      ret = wd_cancel(priv->timeout);
+      ret = wd_cancel(&priv->timeout);
       if (ret == OK)
         {
-          nxsem_post(&priv->wait);
+          i2c_givesem(&priv->wait);
         }
     }
 
@@ -529,8 +550,8 @@ static int cxd56_i2c_receive(struct cxd56_i2cdev_s *priv, int last)
         }
 
       flags = enter_critical_section();
-      wd_start(priv->timeout, I2C_TIMEOUT, cxd56_i2c_timeout, 1,
-              (uint32_t)priv);
+      wd_start(&priv->timeout, I2C_TIMEOUT,
+               cxd56_i2c_timeout, (wdparm_t)priv);
 
       /* Set stop flag for indicate the last data */
 
@@ -538,7 +559,7 @@ static int cxd56_i2c_receive(struct cxd56_i2cdev_s *priv, int last)
 
       i2c_reg_rmw(priv, CXD56_IC_INTR_MASK, INTR_RX_FULL, INTR_RX_FULL);
       leave_critical_section(flags);
-      nxsem_wait(&priv->wait);
+      i2c_takesem(&priv->wait);
 
       if (priv->error != OK)
         {
@@ -575,7 +596,8 @@ static int cxd56_i2c_send(struct cxd56_i2cdev_s *priv, int last)
   while (!(i2c_reg_read(priv, CXD56_IC_STATUS) & STATUS_TFNF));
 
   flags = enter_critical_section();
-  wd_start(priv->timeout, I2C_TIMEOUT, cxd56_i2c_timeout, 1, (uint32_t)priv);
+  wd_start(&priv->timeout, I2C_TIMEOUT,
+           cxd56_i2c_timeout, (wdparm_t)priv);
   i2c_reg_write(priv, CXD56_IC_DATA_CMD,
                 (uint32_t)msg->buffer[i] | (last ? CMD_STOP : 0));
 
@@ -584,7 +606,7 @@ static int cxd56_i2c_send(struct cxd56_i2cdev_s *priv, int last)
   i2c_reg_rmw(priv, CXD56_IC_INTR_MASK, INTR_TX_EMPTY, INTR_TX_EMPTY);
   leave_critical_section(flags);
 
-  nxsem_wait(&priv->wait);
+  i2c_takesem(&priv->wait);
 
   return 0;
 }
@@ -613,7 +635,7 @@ static int cxd56_i2c_transfer(FAR struct i2c_master_s *dev,
 
   /* Get exclusive access to the I2C bus */
 
-  nxsem_wait(&priv->mutex);
+  i2c_takesem(&priv->mutex);
 
   /* Check wait semaphore value. If the value is not 0, the transfer can not
    * be performed normally.
@@ -691,7 +713,8 @@ static int cxd56_i2c_transfer(FAR struct i2c_master_s *dev,
 
   cxd56_i2c_clock_gate_enable(priv->port);
 
-  nxsem_post(&priv->mutex);
+  i2c_givesem(&priv->mutex);
+
   return ret;
 }
 
@@ -829,7 +852,7 @@ static int cxd56_i2c_transfer_scu(FAR struct i2c_master_s *dev,
 
   /* Get exclusive access to the I2C bus */
 
-  nxsem_wait(&priv->mutex);
+  i2c_takesem(&priv->mutex);
 
   /* Apply frequency for request msgs */
 
@@ -866,7 +889,7 @@ static int cxd56_i2c_transfer_scu(FAR struct i2c_master_s *dev,
         }
     }
 
-  nxsem_post(&priv->mutex);
+  i2c_givesem(&priv->mutex);
 
   return ret;
 }
@@ -1031,8 +1054,7 @@ struct i2c_master_s *cxd56_i2cbus_initialize(int port)
 
   nxsem_init(&priv->mutex, 0, 1);
   nxsem_init(&priv->wait, 0, 0);
-
-  priv->timeout = wd_create();
+  nxsem_set_protocol(&priv->wait, SEM_PRIO_NONE);
 
   /* Attach Interrupt Handler */
 
@@ -1095,8 +1117,7 @@ int cxd56_i2cbus_uninitialize(FAR struct i2c_master_s *dev)
   up_disable_irq(priv->irqid);
   irq_detach(priv->irqid);
 
-  wd_delete(priv->timeout);
-  priv->timeout = NULL;
+  wd_cancel(&priv->timeout);
   nxsem_destroy(&priv->mutex);
   nxsem_destroy(&priv->wait);
 
