@@ -52,6 +52,7 @@
 
 #include <arch/board/board.h>
 
+#include "clock/clock.h"
 #include "arm_arch.h"
 #include "cxd56_rtc.h"
 
@@ -208,16 +209,6 @@ static int cxd56_rtc_interrupt(int irq, FAR void *context, FAR void *arg)
       id = RTC_ALARM0;
       clear = source & RTCREG_ALM0_MASK;
     }
-  else if (source & RTCREG_ALM1_MASK)
-    {
-      id = RTC_ALARM1;
-      clear = source & RTCREG_ALM1_MASK;
-    }
-  else if (source & RTCREG_ALM2_MASK)
-    {
-      id = RTC_ALARM2;
-      clear = source & RTCREG_ALM2_MASK;
-    }
   else
     {
       rtcerr("ERROR: Invalid ALARM\n");
@@ -259,17 +250,12 @@ static int cxd56_rtc_interrupt(int irq, FAR void *context, FAR void *arg)
  *
  ****************************************************************************/
 
-static void cxd56_rtc_initialize(int argc, uint32_t arg, ...)
+static void cxd56_rtc_initialize(wdparm_t arg)
 {
   struct timespec ts;
 #ifdef CONFIG_CXD56_RTC_LATEINIT
-  static WDOG_ID s_wdog = NULL;
-  static int     s_retry = 0;
-
-  if (s_wdog == NULL)
-    {
-      s_wdog = wd_create();
-    }
+  static struct wdog_s s_wdog;
+  static int s_retry = 0;
 
   /* Check whether RTC clock source selects the external RTC and the
    * synchronization from the external RTC is completed.
@@ -287,8 +273,8 @@ static void cxd56_rtc_initialize(int argc, uint32_t arg, ...)
         {
           rtcinfo("retry count: %d\n", s_retry);
 
-          if (OK == wd_start(s_wdog, MSEC2TICK(RTC_CLOCK_CHECK_INTERVAL),
-                             cxd56_rtc_initialize, 1, (wdparm_t)NULL))
+          if (OK == wd_start(&s_wdog, MSEC2TICK(RTC_CLOCK_CHECK_INTERVAL),
+                             cxd56_rtc_initialize, 0))
             {
               /* Again, this function is called recursively */
 
@@ -301,20 +287,15 @@ static void cxd56_rtc_initialize(int argc, uint32_t arg, ...)
 
   /* RTC clock is stable, or give up using the external RTC */
 
-  if (s_wdog != NULL)
-    {
-      wd_delete(s_wdog);
-    }
+  wd_cancel(&s_wdog);
 #endif
 
 #ifdef CONFIG_RTC_ALARM
   /* Configure RTC interrupt to catch overflow and alarm interrupts. */
 
   irq_attach(CXD56_IRQ_RTC0_A0, cxd56_rtc_interrupt, NULL);
-  irq_attach(CXD56_IRQ_RTC0_A2, cxd56_rtc_interrupt, NULL);
   irq_attach(CXD56_IRQ_RTC_INT, cxd56_rtc_interrupt, NULL);
   up_enable_irq(CXD56_IRQ_RTC0_A0);
-  up_enable_irq(CXD56_IRQ_RTC0_A2);
   up_enable_irq(CXD56_IRQ_RTC_INT);
 #endif
 
@@ -332,9 +313,11 @@ static void cxd56_rtc_initialize(int argc, uint32_t arg, ...)
       clock_systime_timespec(&ts);
     }
 
-  /* Synchronize the system time to the RTC time */
+#ifdef CONFIG_RTC_HIRES
+  /* Synchronize the base time to the RTC time */
 
-  clock_synchronize();
+  up_rtc_gettime(&g_basetime);
+#endif
 
   if (g_rtc_save->offset == 0)
     {
@@ -372,7 +355,7 @@ static void cxd56_rtc_initialize(int argc, uint32_t arg, ...)
 
 int up_rtc_initialize(void)
 {
-  cxd56_rtc_initialize(1, (wdparm_t)NULL);
+  cxd56_rtc_initialize(0);
   return OK;
 }
 
@@ -463,7 +446,7 @@ int up_rtc_settime(FAR const struct timespec *tp)
   irqstate_t flags;
   uint64_t count;
 
-  flags = enter_critical_section();
+  flags = spin_lock_irqsave();
 
 #ifdef RTC_DIRECT_CONTROL
   /* wait until previous write request is completed */
@@ -486,7 +469,7 @@ int up_rtc_settime(FAR const struct timespec *tp)
   g_rtc_save->offset = (int64_t)count - (int64_t)cxd56_rtc_count();
 #endif
 
-  leave_critical_section(flags);
+  spin_unlock_irqrestore(flags);
 
   rtc_dumptime(tp, "Setting time");
 
@@ -514,12 +497,12 @@ uint64_t cxd56_rtc_count(void)
    * 1st post -> 2nd pre, and should be operated in atomic.
    */
 
-  flags = enter_critical_section();
+  flags = spin_lock_irqsave();
 
   val = (uint64_t)getreg32(CXD56_RTC0_RTPOSTCNT) << 15;
   val |= getreg32(CXD56_RTC0_RTPRECNT);
 
-  leave_critical_section(flags);
+  spin_unlock_irqrestore(flags);
 
   return val;
 }
@@ -541,12 +524,12 @@ uint64_t cxd56_rtc_almcount(void)
   uint64_t val;
   irqstate_t flags;
 
-  flags = enter_critical_section();
+  flags = spin_lock_irqsave();
 
   val = (uint64_t)getreg32(CXD56_RTC0_SETALMPOSTCNT(0)) << 15;
   val |= (getreg32(CXD56_RTC0_SETALMPRECNT(0)) & 0x7fff);
 
-  leave_critical_section(flags);
+  spin_unlock_irqrestore(flags);
 
   return val;
 }
@@ -587,7 +570,7 @@ int cxd56_rtc_setalarm(FAR struct alm_setalarm_s *alminfo)
     {
       /* The set the alarm */
 
-      flags = enter_critical_section();
+      flags = spin_lock_irqsave();
 
       cbinfo->ac_cb  = alminfo->as_cb;
       cbinfo->ac_arg = alminfo->as_arg;
@@ -611,7 +594,7 @@ int cxd56_rtc_setalarm(FAR struct alm_setalarm_s *alminfo)
 
       while (RTCREG_ALM_BUSY_MASK & getreg32(CXD56_RTC0_ALMOUTEN(id)));
 
-      leave_critical_section(flags);
+      spin_unlock_irqrestore(flags);
 
       rtc_dumptime(&alminfo->as_time, "New Alarm time");
       ret = OK;
@@ -652,7 +635,7 @@ int cxd56_rtc_cancelalarm(enum alm_id_e alarmid)
     {
       /* Unset the alarm */
 
-      flags = enter_critical_section();
+      flags = spin_lock_irqsave();
 
       cbinfo->ac_cb = NULL;
 
@@ -660,7 +643,7 @@ int cxd56_rtc_cancelalarm(enum alm_id_e alarmid)
 
       putreg32(0, CXD56_RTC0_ALMOUTEN(alarmid));
 
-      leave_critical_section(flags);
+      spin_unlock_irqrestore(flags);
 
       ret = OK;
     }
