@@ -171,7 +171,7 @@ struct imxrt_dev_s
   sdio_eventset_t waitevents;         /* Set of events to be waited for */
   uint32_t waitints;                  /* Interrupt enables for event waiting */
   volatile sdio_eventset_t wkupevent; /* The event that caused the wakeup */
-  WDOG_ID waitwdog;                   /* Watchdog that handles event timeouts */
+  struct wdog_s waitwdog;             /* Watchdog that handles event timeouts */
 
   /* Callback support */
 
@@ -288,7 +288,7 @@ static void imxrt_transmit(struct imxrt_dev_s *priv);
 static void imxrt_receive(struct imxrt_dev_s *priv);
 #endif
 
-static void imxrt_eventtimeout(int argc, uint32_t arg, ...);
+static void imxrt_eventtimeout(wdparm_t arg);
 static void imxrt_endwait(struct imxrt_dev_s *priv,
               sdio_eventset_t wkupevent);
 static void imxrt_endtransfer(struct imxrt_dev_s *priv,
@@ -1006,8 +1006,7 @@ static void imxrt_receive(struct imxrt_dev_s *priv)
  *   any other waited-for event occurring.
  *
  * Input Parameters:
- *   argc   - The number of arguments (should be 1)
- *   arg    - The argument (state structure reference cast to uint32_t)
+ *   arg    - The argument
  *
  * Returned Value:
  *   None
@@ -1017,11 +1016,11 @@ static void imxrt_receive(struct imxrt_dev_s *priv)
  *
  ****************************************************************************/
 
-static void imxrt_eventtimeout(int argc, uint32_t arg, ...)
+static void imxrt_eventtimeout(wdparm_t arg)
 {
   struct imxrt_dev_s *priv = (struct imxrt_dev_s *)arg;
 
-  DEBUGASSERT(argc == 1 && priv != NULL);
+  DEBUGASSERT(priv != NULL);
   DEBUGASSERT((priv->waitevents & SDIOWAIT_TIMEOUT) != 0);
 
   /* Is a data transfer complete event expected? */
@@ -1062,7 +1061,7 @@ static void imxrt_endwait(struct imxrt_dev_s *priv,
 {
   /* Cancel the watchdog timeout */
 
-  wd_cancel(priv->waitwdog);
+  wd_cancel(&priv->waitwdog);
 
   /* Disable event-related interrupts */
 
@@ -1398,7 +1397,7 @@ static void imxrt_reset(FAR struct sdio_dev_s *dev)
   priv->xfrflags   = 0;         /* Used to synchronize SDIO and DMA completion */
 #endif
 
-  wd_cancel(priv->waitwdog);    /* Cancel any timeouts */
+  wd_cancel(&priv->waitwdog);   /* Cancel any timeouts */
 
   /* Interrupt mode data transfer support */
 
@@ -2279,7 +2278,7 @@ static int imxrt_cancel(FAR struct sdio_dev_s *dev)
 
   /* Cancel any watchdog timeout */
 
-  wd_cancel(priv->waitwdog);
+  wd_cancel(&priv->waitwdog);
 
   /* If this was a DMA transfer, make sure that DMA is stopped */
 
@@ -2708,8 +2707,8 @@ static sdio_eventset_t imxrt_eventwait(FAR struct sdio_dev_s *dev,
       /* Start the watchdog timer */
 
       delay = MSEC2TICK(timeout);
-      ret = wd_start(priv->waitwdog, delay, imxrt_eventtimeout,
-                     1, (uint32_t) priv);
+      ret = wd_start(&priv->waitwdog, delay,
+                     imxrt_eventtimeout, (wdparm_t)priv);
 
       if (ret < 0)
         {
@@ -2738,7 +2737,7 @@ static sdio_eventset_t imxrt_eventwait(FAR struct sdio_dev_s *dev,
            * return an SDIO error.
            */
 
-          wd_cancel(priv->waitwdog);
+          wd_cancel(&priv->waitwdog);
           return SDIOWAIT_ERROR;
         }
 
@@ -3119,11 +3118,6 @@ FAR struct sdio_dev_s *imxrt_usdhc_initialize(int slotno)
 
   nxsem_set_protocol(&priv->waitsem, SEM_PRIO_NONE);
 
-  /* Create a watchdog timer */
-
-  priv->waitwdog = wd_create();
-  DEBUGASSERT(priv->waitwdog);
-
   switch (priv->addr)
     {
     case IMXRT_USDHC1_BASE:
