@@ -76,7 +76,8 @@
  * Pre-processor Definitions
  ****************************************************************************/
 
-/* Some sanity checks *******************************************************/
+/* Some sanity checks */
+
 /* Is there at least one UART enabled and configured as a RS-232 device? */
 
 #ifndef HAVE_UART_DEVICE
@@ -502,27 +503,26 @@ static struct up_dev_s g_uart0priv =
   .rxdma_reqsrc   = KINETIS_DMA_REQUEST_SRC_UART0_RX,
   .rxfifo         = g_uart0rxfifo,
 #endif
-
 };
 
 static uart_dev_t g_uart0port =
 {
-  .recv     =
-  {
-    .size   = CONFIG_UART0_RXBUFSIZE,
-    .buffer = g_uart0rxbuffer,
-  },
-  .xmit     =
-  {
-    .size   = CONFIG_UART0_TXBUFSIZE,
-    .buffer = g_uart0txbuffer,
-   },
+  .recv       =
+    {
+      .size   = CONFIG_UART0_RXBUFSIZE,
+      .buffer = g_uart0rxbuffer,
+    },
+  .xmit       =
+    {
+      .size   = CONFIG_UART0_TXBUFSIZE,
+      .buffer = g_uart0txbuffer,
+    },
 #ifdef CONFIG_KINETIS_UART0_RXDMA
-  .ops      = &g_uart_dma_ops,
+  .ops        = &g_uart_dma_ops,
 #else
-  .ops      = &g_uart_ops,
+  .ops        = &g_uart_ops,
 #endif
-  .priv     = &g_uart0priv,
+  .priv       = &g_uart0priv,
 };
 #endif
 
@@ -557,22 +557,22 @@ static struct up_dev_s g_uart1priv =
 
 static uart_dev_t g_uart1port =
 {
-  .recv     =
-  {
-    .size   = CONFIG_UART1_RXBUFSIZE,
-    .buffer = g_uart1rxbuffer,
-  },
-  .xmit     =
-  {
-    .size   = CONFIG_UART1_TXBUFSIZE,
-    .buffer = g_uart1txbuffer,
-   },
+  .recv       =
+    {
+      .size   = CONFIG_UART1_RXBUFSIZE,
+      .buffer = g_uart1rxbuffer,
+    },
+  .xmit       =
+    {
+      .size   = CONFIG_UART1_TXBUFSIZE,
+      .buffer = g_uart1txbuffer,
+    },
 #ifdef CONFIG_KINETIS_UART1_RXDMA
-  .ops      = &g_uart_dma_ops,
+  .ops        = &g_uart_dma_ops,
 #else
-  .ops      = &g_uart_ops,
+  .ops        = &g_uart_ops,
 #endif
-  .priv     = &g_uart1priv,
+  .priv       = &g_uart1priv,
 };
 #endif
 
@@ -607,22 +607,22 @@ static struct up_dev_s g_uart2priv =
 
 static uart_dev_t g_uart2port =
 {
-  .recv     =
-  {
-    .size   = CONFIG_UART2_RXBUFSIZE,
-    .buffer = g_uart2rxbuffer,
-  },
-  .xmit     =
-  {
-    .size   = CONFIG_UART2_TXBUFSIZE,
-    .buffer = g_uart2txbuffer,
-   },
+  .recv       =
+    {
+      .size   = CONFIG_UART2_RXBUFSIZE,
+      .buffer = g_uart2rxbuffer,
+    },
+  .xmit       =
+    {
+      .size   = CONFIG_UART2_TXBUFSIZE,
+      .buffer = g_uart2txbuffer,
+    },
 #ifdef CONFIG_KINETIS_UART2_RXDMA
-  .ops      = &g_uart_dma_ops,
+  .ops        = &g_uart_dma_ops,
 #else
-  .ops      = &g_uart_ops,
+  .ops        = &g_uart_ops,
 #endif
-  .priv     = &g_uart2priv,
+  .priv       = &g_uart2priv,
 };
 #endif
 
@@ -657,22 +657,22 @@ static struct up_dev_s g_uart3priv =
 
 static uart_dev_t g_uart3port =
 {
-  .recv     =
-  {
-    .size   = CONFIG_UART3_RXBUFSIZE,
-    .buffer = g_uart3rxbuffer,
-  },
-  .xmit     =
-  {
-    .size   = CONFIG_UART3_TXBUFSIZE,
-    .buffer = g_uart3txbuffer,
-   },
+  .recv       =
+    {
+      .size   = CONFIG_UART3_RXBUFSIZE,
+      .buffer = g_uart3rxbuffer,
+    },
+  .xmit       =
+    {
+      .size   = CONFIG_UART3_TXBUFSIZE,
+      .buffer = g_uart3txbuffer,
+    },
 #ifdef CONFIG_KINETIS_UART3_RXDMA
-  .ops      = &g_uart_dma_ops,
+  .ops        = &g_uart_dma_ops,
 #else
-  .ops      = &g_uart_ops,
+  .ops        = &g_uart_ops,
 #endif
-  .priv     = &g_uart3priv,
+  .priv       = &g_uart3priv,
 };
 #endif
 
@@ -707,22 +707,22 @@ static struct up_dev_s g_uart4priv =
 
 static uart_dev_t g_uart4port =
 {
-  .recv     =
-  {
-    .size   = CONFIG_UART4_RXBUFSIZE,
-    .buffer = g_uart4rxbuffer,
-  },
-  .xmit     =
-  {
-    .size   = CONFIG_UART4_TXBUFSIZE,
-    .buffer = g_uart4txbuffer,
-   },
+  .recv       =
+    {
+      .size   = CONFIG_UART4_RXBUFSIZE,
+      .buffer = g_uart4rxbuffer,
+    },
+  .xmit       =
+    {
+      .size   = CONFIG_UART4_TXBUFSIZE,
+      .buffer = g_uart4txbuffer,
+    },
 #ifdef CONFIG_KINETIS_UART4_RXDMA
-  .ops      = &g_uart_dma_ops,
+  .ops        = &g_uart_dma_ops,
 #else
-  .ops      = &g_uart_ops,
+  .ops        = &g_uart_ops,
 #endif
-  .priv     = &g_uart4priv,
+  .priv       = &g_uart4priv,
 };
 #endif
 
@@ -757,22 +757,22 @@ static struct up_dev_s g_uart5priv =
 
 static uart_dev_t g_uart5port =
 {
-  .recv     =
-  {
-    .size   = CONFIG_UART5_RXBUFSIZE,
-    .buffer = g_uart5rxbuffer,
-  },
-  .xmit     =
-  {
-    .size   = CONFIG_UART5_TXBUFSIZE,
-    .buffer = g_uart5txbuffer,
-   },
+  .recv       =
+    {
+      .size   = CONFIG_UART5_RXBUFSIZE,
+      .buffer = g_uart5rxbuffer,
+    },
+  .xmit       =
+    {
+      .size   = CONFIG_UART5_TXBUFSIZE,
+      .buffer = g_uart5txbuffer,
+    },
 #ifdef CONFIG_KINETIS_UART5_RXDMA
-  .ops      = &g_uart_dma_ops,
+  .ops        = &g_uart_dma_ops,
 #else
-  .ops      = &g_uart_ops,
+  .ops        = &g_uart_ops,
 #endif
-  .priv     = &g_uart5priv,
+  .priv       = &g_uart5priv,
 };
 #endif
 
@@ -793,7 +793,8 @@ static inline uint8_t up_serialin(struct up_dev_s *priv, int offset)
  * Name: up_serialout
  ****************************************************************************/
 
-static inline void up_serialout(struct up_dev_s *priv, int offset, uint8_t value)
+static inline void up_serialout(struct up_dev_s *priv, int offset,
+                                uint8_t value)
 {
   putreg8(value, priv->uartbase + offset);
 }
@@ -807,7 +808,9 @@ static void up_setuartint(struct up_dev_s *priv)
   irqstate_t flags;
   uint8_t regval;
 
-  /* Re-enable/re-disable interrupts corresponding to the state of bits in ie */
+  /* Re-enable/re-disable interrupts corresponding to the state of bits in
+   * ie
+   */
 
   flags    = enter_critical_section();
   regval   = up_serialin(priv, KINETIS_UART_C2_OFFSET);
@@ -825,7 +828,9 @@ static void up_restoreuartint(struct up_dev_s *priv, uint8_t ie)
 {
   irqstate_t flags;
 
-  /* Re-enable/re-disable interrupts corresponding to the state of bits in ie */
+  /* Re-enable/re-disable interrupts corresponding to the state of bits in
+   * ie
+   */
 
   flags    = enter_critical_section();
   priv->ie = ie & UART_C2_ALLINTS;
@@ -952,23 +957,25 @@ static int up_dma_setup(struct uart_dev_s *dev)
         }
     }
 
-  /* Acquire the DMA channel.*/
+  /* Acquire the DMA channel. */
 
   rxdma = kinetis_dmachannel(priv->rxdma_reqsrc,
                              priv->uartbase + KINETIS_UART_D_OFFSET,
                              KINETIS_DMA_DATA_SZ_8BIT,
                              KINETIS_DMA_DIRECTION_PERIPHERAL_TO_MEMORY);
   if (rxdma == NULL)
-  {
-    return -EBUSY;
-  }
+    {
+      return -EBUSY;
+    }
 
   /* Configure for circular DMA reception into the RX FIFO */
 
   kinetis_dmasetup(rxdma, (uint32_t)priv->rxfifo, RXDMA_BUFFER_SIZE,
                    SERIAL_DMA_CONTROL_WORD);
 
-  /* Reset our DMA shadow pointer to match the address just programmed above. */
+  /* Reset our DMA shadow pointer to match the address just programmed
+   * above.
+   */
 
   priv->rxdmanext = 0;
 
@@ -1045,14 +1052,15 @@ static void up_dma_shutdown(struct uart_dev_s *dev)
  * Name: up_attach
  *
  * Description:
- *   Configure the UART to operation in interrupt driven mode.  This method is
- *   called when the serial port is opened.  Normally, this is just after the
- *   the setup() method is called, however, the serial console may operate in
- *   a non-interrupt driven mode during the boot phase.
+ *   Configure the UART to operation in interrupt driven mode.  This method
+ *   is called when the serial port is opened.  Normally, this is just after
+ *   the the setup() method is called, however, the serial console may
+ *   operate in a non-interrupt driven mode during the boot phase.
  *
- *   RX and TX interrupts are not enabled when by the attach method (unless the
- *   hardware supports multiple levels of interrupt enabling).  The RX and TX
- *   interrupts are not enabled until the txint() and rxint() methods are called.
+ *   RX and TX interrupts are not enabled when by the attach method (unless
+ *   the hardware supports multiple levels of interrupt enabling).  The RX
+ *   and TX interrupts are not enabled until the txint() and rxint() methods
+ *   are called.
  *
  ****************************************************************************/
 
@@ -1089,8 +1097,8 @@ static int up_attach(struct uart_dev_s *dev)
  *
  * Description:
  *   Detach UART interrupts.  This method is called when the serial port is
- *   closed normally just before the shutdown method is called.  The exception
- *   is the serial console which is never shutdown.
+ *   closed normally just before the shutdown method is called.  The
+ *   exception is the serial console which is never shutdown.
  *
  ****************************************************************************/
 
@@ -1305,7 +1313,7 @@ static int up_ioctl(struct file *filep, int cmd, unsigned long arg)
       {
         if ((arg & SER_SINGLEWIRE_PULLUP) != 0)
           {
-            ret = -EINVAL; // Not supported
+            ret = -EINVAL; /* Not supported */
             break;
           }
 
@@ -1341,11 +1349,9 @@ static int up_ioctl(struct file *filep, int cmd, unsigned long arg)
             break;
           }
 
-        cfsetispeed(termiosp, priv->baud);
-
-        /* Note: CSIZE only supports 5-8 bits. The driver only support 8/9 bit
-         * modes and therefore is no way to report 9-bit mode, we always claim
-         * 8 bit mode.
+        /* Note: CSIZE only supports 5-8 bits. The driver only support
+         * 8/9 bit modes and therefore is no way to report 9-bit mode, we
+         * always claim 8 bit mode.
          */
 
         termiosp->c_cflag =
@@ -1360,6 +1366,8 @@ static int up_ioctl(struct file *filep, int cmd, unsigned long arg)
 #  endif
           CS8;
 
+        cfsetispeed(termiosp, priv->baud);
+
         /* TODO: CCTS_IFLOW, CCTS_OFLOW */
       }
       break;
@@ -1666,8 +1674,8 @@ static void up_rxint(struct uart_dev_s *dev, bool enable)
   flags = enter_critical_section();
   if (enable)
     {
-      /* Receive an interrupt when their is anything in the Rx data register (or an Rx
-       * timeout occurs).
+      /* Receive an interrupt when their is anything in the Rx data register
+       * (or an RX timeout occurs).
        */
 
 #ifndef CONFIG_SUPPRESS_SERIAL_INTS
@@ -1935,7 +1943,8 @@ static bool up_txempty(struct uart_dev_s *dev)
 
   /* Return true if the transmit buffer/fifo is "empty." */
 
-  return (up_serialin(priv, KINETIS_UART_SFIFO_OFFSET) & UART_SFIFO_TXEMPT) != 0;
+  return (up_serialin(priv, KINETIS_UART_SFIFO_OFFSET) & \
+          UART_SFIFO_TXEMPT) != 0;
 }
 #endif
 
@@ -2042,26 +2051,26 @@ unsigned int kinetis_uart_serialinit(unsigned int first)
 
   /* Register all UARTs */
 
-  devname[(sizeof(devname)/sizeof(devname[0]))-2] = '0' + first++;
+  devname[(sizeof(devname) / sizeof(devname[0]))-2] = '0' + first++;
   uart_register(devname, &TTYS0_DEV);
 #ifdef TTYS1_DEV
-  devname[(sizeof(devname)/sizeof(devname[0]))-2] = '0' + first++;
+  devname[(sizeof(devname) / sizeof(devname[0]))-2] = '0' + first++;
   uart_register(devname, &TTYS1_DEV);
 #endif
 #ifdef TTYS2_DEV
-  devname[(sizeof(devname)/sizeof(devname[0]))-2] = '0' + first++;
+  devname[(sizeof(devname) / sizeof(devname[0]))-2] = '0' + first++;
   uart_register(devname, &TTYS2_DEV);
 #endif
 #ifdef TTYS3_DEV
-  devname[(sizeof(devname)/sizeof(devname[0]))-2] = '0' + first++;
+  devname[(sizeof(devname) / sizeof(devname[0]))-2] = '0' + first++;
   uart_register(devname, &TTYS3_DEV);
 #endif
 #ifdef TTYS4_DEV
-  devname[(sizeof(devname)/sizeof(devname[0]))-2] = '0' + first++;
+  devname[(sizeof(devname) / sizeof(devname[0]))-2] = '0' + first++;
   uart_register(devname, &TTYS4_DEV);
 #endif
 #ifdef TTYS5_DEV
-  devname[(sizeof(devname)/sizeof(devname[0]))-2] = '0' + first++;
+  devname[(sizeof(devname) / sizeof(devname[0]))-2] = '0' + first++;
   uart_register(devname, &TTYS5_DEV);
 #endif
   return first;
