@@ -83,23 +83,23 @@ static sem_t _sdc_sem[2] =
   SEM_INITIALIZER(1)
 };
 
-static struct SdDrCfg_s _sdch0;
-static struct SdDrCfg_s _sdch1;
+static struct sddrcfg_s _sdch0;
+static struct sddrcfg_s _sdch1;
 
-static struct SdDrCfg_s *_cfg[2] =
+static struct sddrcfg_s *_cfg[2] =
 {
   &_sdch0,
   &_sdch1
 };
 
-static unsigned long _work0[512/4];
+static unsigned long _work0[512 / 4];
 #ifdef CONFIG_LC823450_SDIF_SDC
-static unsigned long _work1[512/4];
+static unsigned long _work1[512 / 4];
 #endif
 
 #ifdef CONFIG_LC823450_SDC_CACHE
 static uint8_t   _sec_cache_enabled;
-static uint32_t  _sec_cache[512/4];
+static uint32_t  _sec_cache[512 / 4];
 static uint32_t  _sec_cache_add = 0xffffffff;
 #endif
 
@@ -111,22 +111,22 @@ static uint32_t  _sec_cache_add = 0xffffffff;
 
 extern uint8_t cpu_ver;
 
-extern SINT_T sddep0_hw_init(struct SdDrCfg_s *);
-extern SINT_T sddep0_hw_exit(struct SdDrCfg_s *);
-extern SINT_T sddep1_hw_init(struct SdDrCfg_s *);
-extern SINT_T sddep1_hw_exit(struct SdDrCfg_s *);
+extern SINT_T sddep0_hw_init(struct sddrcfg_s *);
+extern SINT_T sddep0_hw_exit(struct sddrcfg_s *);
+extern SINT_T sddep1_hw_init(struct sddrcfg_s *);
+extern SINT_T sddep1_hw_exit(struct sddrcfg_s *);
 
-extern SINT_T sddep_os_init(struct SdDrCfg_s *);
-extern SINT_T sddep_os_exit(struct SdDrCfg_s *);
-extern void   sddep_voltage_switch(struct SdDrCfg_s *cfg);
-extern void   sddep_set_clk(struct SdDrCfg_s *);
-extern SINT_T sddep_wait(UI_32, struct SdDrCfg_s *);
+extern SINT_T sddep_os_init(struct sddrcfg_s *);
+extern SINT_T sddep_os_exit(struct sddrcfg_s *);
+extern void   sddep_voltage_switch(struct sddrcfg_s *cfg);
+extern void   sddep_set_clk(struct sddrcfg_s *);
+extern SINT_T sddep_wait(UI_32, struct sddrcfg_s *);
 extern SINT_T sddep_wait_status(UI_32 req, UI_32 *status,
-                                struct SdDrCfg_s *cfg);
+                                struct sddrcfg_s *cfg);
 extern SINT_T sddep_read(void *src, void *dst, UI_32 size, SINT_T type,
-                         struct SdDrCfg_s *cfg);
+                         struct sddrcfg_s *cfg);
 extern SINT_T sddep_write(void *src, void *dst, UI_32 size, SINT_T type,
-                          struct SdDrCfg_s *cfg);
+                          struct sddrcfg_s *cfg);
 
 /****************************************************************************
  * Private Functions
@@ -154,11 +154,11 @@ static void _sdc_semgive(FAR sem_t *sem)
  * Name: _lc823450_sdc_support_trim
  ****************************************************************************/
 
-static int _lc823450_sdc_support_trim(struct SdDrCfg_s *cf)
+static int _lc823450_sdc_support_trim(struct sddrcfg_s *cf)
 {
   /* NOTE: to avoid conflicts, SDDR_SUPPORT_TRIM() macro is not used here */
 
-  int ret = ((SdDrRefMediaType(cf) == SDDR_MEDIA_TYPE_MMC) ?
+  int ret = ((sddr_refmediatype(cf) == SDDR_MEDIA_TYPE_MMC) ?
              (((cf)->ex.mmc.extcsd_sec_feature_support & (1UL << 4)) ?
               1 : 0) : 0);
   return ret;
@@ -207,7 +207,7 @@ int lc823450_sdc_clearcardinfo(uint32_t ch)
       return ret;
     }
 
-  ret = SdDrClearCardInfo(_cfg[ch]);
+  ret = sddr_clearcardinfo(_cfg[ch]);
 
 #ifdef CONFIG_LC823450_SDC_CACHE
   if (ch)
@@ -234,7 +234,7 @@ int lc823450_sdc_initialize(uint32_t ch)
 
   DEBUGASSERT(1 == cpu_ver);
 
-  struct SdDrCfg_s *psd = _cfg[ch];
+  struct sddrcfg_s *psd = _cfg[ch];
 
   psd->sysclk           = lc823450_get_systemfreq();
   psd->detecttime       = DET_TIME;
@@ -279,7 +279,7 @@ int lc823450_sdc_initialize(uint32_t ch)
   ret = _sdc_semtake(&_sdc_sem[ch]);
   if (ret >= 0)
     {
-      ret = SdDrInitialize(_cfg[ch]);
+      ret = sddr_initialize(_cfg[ch]);
       _sdc_semgive(&_sdc_sem[ch]);
       mcinfo("---- end ret=%d \n", ret);
     }
@@ -300,7 +300,7 @@ int lc823450_sdc_finalize(uint32_t ch)
   ret = _sdc_semtake(&_sdc_sem[ch]);
   if (ret >= 0)
     {
-      ret = SdDrFinalize(_cfg[ch]);
+      ret = sddr_finalize(_cfg[ch]);
       _sdc_semgive(&_sdc_sem[ch]);
       mcinfo("---- end ret=%d \n", ret);
     }
@@ -324,7 +324,7 @@ int lc823450_sdc_identifycard(uint32_t ch)
       return ret;
     }
 
-  ret = SdDrIdentifyCard(_cfg[ch]);
+  ret = sddr_identifycard(_cfg[ch]);
 
 #ifdef CONFIG_LC823450_SDC_CACHE
   if (ch)
@@ -347,12 +347,13 @@ int lc823450_sdc_setclock(uint32_t ch, uint32_t limitclk, uint32_t sysclk)
 {
   int ret;
 
-  mcinfo("++++ start ch=%ld limitClk=%ld sysClk=%ld\n", ch, limitClk, sysClk);
+  mcinfo("++++ start ch=%ld limitClk=%ld sysClk=%ld\n",
+         ch, limitclk, sysclk);
 
   ret = _sdc_semtake(&_sdc_sem[ch]);
   if (ret >= 0)
     {
-      ret = SdDrSetClock(limitclk, sysclk, _cfg[ch]);
+      ret = sddr_setclock(limitclk, sysclk, _cfg[ch]);
       _sdc_semgive(&_sdc_sem[ch]);
       mcinfo("---- end ret=%d \n", ret);
     }
@@ -377,7 +378,7 @@ int lc823450_sdc_refmediatype(uint32_t ch)
   ret = _sdc_semtake(&_sdc_sem[ch]);
   if (ret >= 0)
     {
-      ret = SdDrRefMediaType(_cfg[ch]);
+      ret = sddr_refmediatype(_cfg[ch]);
       _sdc_semgive(&_sdc_sem[ch]);
       mcinfo("---- end ret=%d \n", ret);
     }
@@ -396,10 +397,10 @@ int lc823450_sdc_getcardsize(uint32_t ch,
 
   mcinfo("++++ start \n");
 
-  ret =_sdc_semtake(&_sdc_sem[ch]);
+  ret = _sdc_semtake(&_sdc_sem[ch]);
   if (ret >= 0)
     {
-      ret = SdDrGetCardSize(psecnum, psecsize, _cfg[ch]);
+      ret = sddr_getcardsize(psecnum, psecsize, _cfg[ch]);
 
       _sdc_semgive(&_sdc_sem[ch]);
       mcinfo("---- end ret=%d \n", ret);
@@ -446,9 +447,9 @@ int lc823450_sdc_readsector(uint32_t ch,
   for (i = 0; i < 5; i++)
     {
 #ifdef CONFIG_LC823450_SDIF_PATCH
-      ret = fixedSdDrReadSector(addr, cnt, pbuf, type, _cfg[ch]);
+      ret = fixed_sddr_readsector(addr, cnt, pbuf, type, _cfg[ch]);
 #else
-      ret = SdDrReadSector(addr, cnt, pbuf, type, _cfg[ch]);
+      ret = sddr_readsector(addr, cnt, pbuf, type, _cfg[ch]);
 #endif
       if (0 == ret)
         {
@@ -527,7 +528,7 @@ int lc823450_sdc_writesector(uint32_t ch,
   sched_add_bo((uint64_t)cnt);
 #endif
 
-  ret = SdDrWriteSector(addr, cnt, pbuf, type, _cfg[ch]);
+  ret = sddr_writesector(addr, cnt, pbuf, type, _cfg[ch]);
 
   if (0 > ret)
     {
@@ -553,7 +554,8 @@ int lc823450_sdc_checktrim(uint32_t ch)
  * Name: lc823450_sdc_trimsector
  ****************************************************************************/
 
-int lc823450_sdc_trimsector(uint32_t ch, unsigned long addr, unsigned short cnt)
+int lc823450_sdc_trimsector(uint32_t ch, unsigned long addr,
+                            unsigned short cnt)
 {
   int ret;
 
@@ -573,7 +575,7 @@ int lc823450_sdc_trimsector(uint32_t ch, unsigned long addr, unsigned short cnt)
   sched_add_bt((uint64_t)cnt);
 #endif
 
-  ret = SdDrEraseSeq(0x00000001, addr, cnt, _cfg[ch]);
+  ret = sddr_eraseseq(0x00000001, addr, cnt, _cfg[ch]);
   if (0 > ret)
     {
       mcinfo("ret=%d ch=%d add=%ld cnt=%d \n", ret, ch, addr, cnt);
@@ -598,7 +600,7 @@ int lc823450_sdc_cachectl(uint32_t ch, int ctrl)
   ret = _sdc_semtake(&_sdc_sem[ch]);
   if (ret >= 0)
     {
-      ret = SdDrCacheCtrl(ctrl, _cfg[ch]);
+      ret = sddr_cachectrl(ctrl, _cfg[ch]);
 
       _sdc_semgive(&_sdc_sem[ch]);
       mcinfo("----  end ret=%d \n", ret);
@@ -623,7 +625,7 @@ int lc823450_sdc_changespeedmode(uint32_t ch, int mode)
       return ret;
     }
 
-  ret = SdDrChangeSpeedMode(mode, _cfg[ch]);
+  ret = sddr_changespeedmode(mode, _cfg[ch]);
 
   if (0 == ret)
     {
@@ -665,7 +667,7 @@ int lc823450_sdc_getcid(uint32_t ch, char *cidstr, int length)
       return ret;
     }
 
-  ret = SdDrGetCid((UI_32 *)cid, _cfg[ch]);
+  ret = sddr_getcid((UI_32 *)cid, _cfg[ch]);
 
   if (0 == ret && length >= (2 * sizeof(cid) + 1))
     {
