@@ -1,36 +1,20 @@
 /****************************************************************************
  * arch/arm/src/lc823450/lc823450_serial.c
  *
- *   Copyright 2014,2015,2016,2017,2018 Sony Video & Sound Products Inc.
- *   Author: Masatoshi Tateishi <Masatoshi.Tateishi@jp.sony.com>
- *   Author: Masayuki Ishikawa <Masayuki.Ishikawa@jp.sony.com>
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.  The
+ * ASF licenses this file to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance with the
+ * License.  You may obtain a copy of the License at
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- * 3. Neither the name NuttX nor the names of its contributors may be
- *    used to endorse or promote products derived from this software
- *    without specific prior written permission.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
- * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
- * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
- * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
- * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
- * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
- * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
- * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+ * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
+ * License for the specific language governing permissions and limitations
+ * under the License.
  *
  ****************************************************************************/
 
@@ -314,7 +298,7 @@ static uart_dev_t g_uart1port =
   {
     .size   = CONFIG_UART1_TXBUFSIZE,
     .buffer = g_uart1txbuffer,
-   },
+  },
   .ops      = &g_uart_ops,
   .priv     = &g_uart1priv,
 };
@@ -344,7 +328,7 @@ static uart_dev_t g_uart2port =
   {
     .size   = CONFIG_UART2_TXBUFSIZE,
     .buffer = g_uart2txbuffer,
-   },
+  },
   .ops      = &g_uart_ops,
   .priv     = &g_uart2priv,
 };
@@ -372,7 +356,8 @@ static inline uint32_t up_serialin(struct up_dev_s *priv, int offset)
  * Name: up_serialout
  ****************************************************************************/
 
-static inline void up_serialout(struct up_dev_s *priv, int offset, uint32_t value)
+static inline void up_serialout(struct up_dev_s *priv,
+                                int offset, uint32_t value)
 {
   putreg32(value, priv->uartbase + offset);
 }
@@ -449,7 +434,11 @@ static int up_setup(struct uart_dev_s *dev)
 {
   struct up_dev_s *priv = (struct up_dev_s *)dev->priv;
   uint32_t ctl;
-  int min_diff = INT_MAX, udiv = -1, tmp_reg, real_baud, i;
+  int min_diff = INT_MAX;
+  int udiv = -1;
+  int tmp_reg;
+  int real_baud;
+  int i;
 
   /* Note:  The logic here depends on the fact that that the UART module
    * was enabled and the GPIOs were configured in up_lowsetup().
@@ -605,14 +594,16 @@ static void up_shutdown(struct uart_dev_s *dev)
  * Name: up_attach
  *
  * Description:
- *   Configure the UART to operation in interrupt driven mode.  This method is
- *   called when the serial port is opened.  Normally, this is just after the
- *   the setup() method is called, however, the serial console may operate in
- *   a non-interrupt driven mode during the boot phase.
+ *   Configure the UART to operation in interrupt driven mode.
+ *   This method is called when the serial port is opened.
+ *   Normally, this is just after the the setup() method is called,
+ *   however, the serial console may operate in a non-interrupt driven mode
+ *   during the boot phase.
  *
- *   RX and TX interrupts are not enabled when by the attach method (unless the
- *   hardware supports multiple levels of interrupt enabling).  The RX and TX
- *   interrupts are not enabled until the txint() and rxint() methods are called.
+ *   RX and TX interrupts are not enabled when by the attach method
+ *   (unless the hardware supports multiple levels of interrupt enabling).
+ *   The RX and TX interrupts are not enabled until the txint() and rxint()
+ *   methods are called.
  *
  ****************************************************************************/
 
@@ -641,8 +632,8 @@ static int up_attach(struct uart_dev_s *dev)
  *
  * Description:
  *   Detach UART interrupts.  This method is called when the serial port is
- *   closed normally just before the shutdown method is called.  The exception is
- *   the serial console which is never shutdown.
+ *   closed normally just before the shutdown method is called.
+ *   The exception is the serial console which is never shutdown.
  *
  ****************************************************************************/
 
@@ -683,6 +674,7 @@ static int up_interrupt(int irq, void *context, FAR void *arg)
   /* Handle incoming, receive bytes (with or without timeout) */
 
   /* Rx buffer not empty ... process incoming bytes */
+
   if (mis & UART_UISR_UARTRF)
     {
       uart_recvchars(dev);
@@ -765,8 +757,6 @@ static int up_ioctl(struct file *filep, int cmd, unsigned long arg)
               break;
             }
 
-          cfsetispeed(termiosp, priv->baud);
-
           /* Note that since we only support 8/9 bit modes and
            * there is no way to report 9-bit mode, we always claim 8.
            */
@@ -782,6 +772,7 @@ static int up_ioctl(struct file *filep, int cmd, unsigned long arg)
 #endif
                               CS8;
 
+          cfsetispeed(termiosp, priv->baud);
         }
         break;
 
@@ -984,6 +975,7 @@ static void up_txint(struct uart_dev_s *dev, bool enable)
       priv->im &= ~UART_UIEN_UARTTF_IEN;
       up_serialout(priv, UART_UIEN, priv->im);
     }
+
   leave_critical_section(flags);
 }
 
@@ -1089,7 +1081,7 @@ static void uart_dma_callback(DMA_HANDLE hdma, void *arg, int result)
  * Name: uart_rxdma_callback
  ****************************************************************************/
 
- static void uart_rxdma_callback(DMA_HANDLE hdma, void *arg, int result)
+static void uart_rxdma_callback(DMA_HANDLE hdma, void *arg, int result)
 {
   if (hs_dmaact == HS_DMAACT_ACT1)
     {
@@ -1150,7 +1142,8 @@ static void  up_hs_dmasetup()
                           LC823450_DMA_DSTWIDTH_BYTE |
                           LC823450_DMA_DSTINC,
                           LC823450_UART1_REGBASE + UART_USRF,
-                          (uint32_t)(g_uart1rxbuffer + CONFIG_UART1_RXBUFSIZE / 2) ,
+                          (uint32_t)(g_uart1rxbuffer + CONFIG_UART1_RXBUFSIZE
+                                     / 2),
                           CONFIG_UART1_RXBUFSIZE / 2);
 
         lc823450_dmastart(g_uart1priv.hrxdma, uart_rxdma_callback, NULL);
@@ -1230,7 +1223,9 @@ retry:
                     LC823450_DMA_SRCWIDTH_BYTE |
                     LC823450_DMA_DSTWIDTH_BYTE |
                     LC823450_DMA_SRCINC,
-                    (uint32_t)dev->xmit.buffer, priv->uartbase + UART_USTF, len);
+                    (uint32_t)dev->xmit.buffer,
+                    priv->uartbase + UART_USTF,
+                    len);
   lc823450_dmastart(priv->htxdma, uart_dma_callback, dev);
 
   /* BT stack may not handle to short write */
@@ -1271,16 +1266,28 @@ void arm_earlyserialinit(void)
   /* workaround: force clock enable */
 
 #if defined(CONFIG_LC823450_UART0)
-  modifyreg32(MCLKCNTAPB, 0, MCLKCNTAPB_UART0_CLKEN | MCLKCNTAPB_UART0IF_CLKEN);
-  modifyreg32(MRSTCNTAPB, 0, MRSTCNTAPB_UART0_RSTB);
+  modifyreg32(MCLKCNTAPB,
+              0,
+              MCLKCNTAPB_UART0_CLKEN | MCLKCNTAPB_UART0IF_CLKEN);
+  modifyreg32(MRSTCNTAPB,
+              0,
+              MRSTCNTAPB_UART0_RSTB);
 #endif
 #if defined(CONFIG_LC823450_UART1)
-  modifyreg32(MCLKCNTAPB, 0, MCLKCNTAPB_UART1_CLKEN | MCLKCNTAPB_UART1IF_CLKEN);
-  modifyreg32(MRSTCNTAPB, 0, MRSTCNTAPB_UART1_RSTB);
+  modifyreg32(MCLKCNTAPB,
+              0,
+              MCLKCNTAPB_UART1_CLKEN | MCLKCNTAPB_UART1IF_CLKEN);
+  modifyreg32(MRSTCNTAPB,
+              0,
+              MRSTCNTAPB_UART1_RSTB);
 #endif
 #if defined(CONFIG_LC823450_UART2)
-  modifyreg32(MCLKCNTAPB, 0, MCLKCNTAPB_UART2_CLKEN | MCLKCNTAPB_UART2IF_CLKEN);
-  modifyreg32(MRSTCNTAPB, 0, MRSTCNTAPB_UART2_RSTB);
+  modifyreg32(MCLKCNTAPB,
+              0,
+              MCLKCNTAPB_UART2_CLKEN | MCLKCNTAPB_UART2IF_CLKEN);
+  modifyreg32(MRSTCNTAPB,
+              0,
+              MRSTCNTAPB_UART2_RSTB);
 #endif
 
   /* Disable all UARTS */
@@ -1327,12 +1334,12 @@ void arm_serialinit(void)
   g_uart1priv.htxdma = lc823450_dmachannel(DMA_CHANNEL_UART1TX);
   lc823450_dmarequest(g_uart1priv.htxdma, DMA_REQUEST_UART1TX);
 
-
   nxsem_init(&g_uart1priv.rxdma_wait, 0, 0);
   g_uart1priv.hrxdma = lc823450_dmachannel(DMA_CHANNEL_UART1RX);
   lc823450_dmarequest(g_uart1priv.hrxdma, DMA_REQUEST_UART1RX);
 
-  up_serialout(&g_uart1priv, UART_UDMA, UART_UDMA_RREQ_EN | UART_UDMA_TREQ_EN);
+  up_serialout(&g_uart1priv, UART_UDMA,
+               UART_UDMA_RREQ_EN | UART_UDMA_TREQ_EN);
   hsuart_register("/dev/ttyHS1", &TTYS1_DEV);
 #endif /* CONFIG_HSUART */
 #endif
@@ -1356,7 +1363,9 @@ int up_putc(int ch)
 
 #ifdef CONFIG_DEV_CONSOLE_SWITCH
   if (g_console_disable)
-    return ch;
+    {
+      return ch;
+    }
 #endif /* CONFIG_DEV_CONSOLE_SWITCH */
 
   up_disableuartint(priv, &im);
@@ -1463,10 +1472,12 @@ void hsuart_wdtimer(void)
   switch (hs_dmaact)
     {
       case HS_DMAACT_ACT1:
-        newhead = CONFIG_UART1_RXBUFSIZE / 2 - lc823450_dmaremain(g_uart1priv.hrxdma);
+        newhead = CONFIG_UART1_RXBUFSIZE /
+          2 - lc823450_dmaremain(g_uart1priv.hrxdma);
         break;
       case HS_DMAACT_ACT2:
-        newhead = CONFIG_UART1_RXBUFSIZE  - lc823450_dmaremain(g_uart1priv.hrxdma);
+        newhead = CONFIG_UART1_RXBUFSIZE  -
+          lc823450_dmaremain(g_uart1priv.hrxdma);
         break;
       case HS_DMAACT_STOP1:
         newhead = 0;
