@@ -118,8 +118,8 @@ struct lpc2378_i2cdev_s
   sem_t            mutex;      /* Only one thread can access at a time */
   sem_t            wait;       /* Place to wait for state machine completion */
   volatile uint8_t state;      /* State of state machine */
-  WDOG_ID          timeout;    /* Watchdog to timeout when bus hung */
-   uint32_t        frequency;  /* Current I2C frequency */
+  struct wdog_s    timeout;    /* Watchdog to timeout when bus hung */
+  uint32_t         frequency;  /* Current I2C frequency */
 
   struct i2c_msg_s *msgs;      /* remaining transfers - first one is in progress */
   unsigned int     nmsg;       /* number of transfer remaining */
@@ -135,7 +135,7 @@ struct lpc2378_i2cdev_s
 static int  lpc2378_i2c_start(struct lpc2378_i2cdev_s *priv);
 static void lpc2378_i2c_stop(struct lpc2378_i2cdev_s *priv);
 static int  lpc2378_i2c_interrupt(int irq, FAR void *context, FAR void *arg);
-static void lpc2378_i2c_timeout(int argc, uint32_t arg, ...);
+static void lpc2378_i2c_timeout(wdparm_t arg);
 static void lpc2378_i2c_setfrequency(struct lpc2378_i2cdev_s *priv,
               uint32_t frequency);
 static void lpc2378_stopnext(struct lpc2378_i2cdev_s *priv);
@@ -220,11 +220,11 @@ static int lpc2378_i2c_start(struct lpc2378_i2cdev_s *priv)
            priv->base + I2C_CONCLR_OFFSET);
   putreg32(I2C_CONSET_STA, priv->base + I2C_CONSET_OFFSET);
 
-  wd_start(priv->timeout, I2C_TIMEOUT, lpc2378_i2c_timeout, 1,
-           (uint32_t)priv);
+  wd_start(&priv->timeout, I2C_TIMEOUT,
+           lpc2378_i2c_timeout, (wdparm_t)priv);
   nxsem_wait(&priv->wait);
 
-  wd_cancel(priv->timeout);
+  wd_cancel(&priv->timeout);
 
   return priv->nmsg;
 }
@@ -256,7 +256,7 @@ static void lpc2378_i2c_stop(struct lpc2378_i2cdev_s *priv)
  *
  ****************************************************************************/
 
-static void lpc2378_i2c_timeout(int argc, uint32_t arg, ...)
+static void lpc2378_i2c_timeout(wdparm_t arg)
 {
   struct lpc2378_i2cdev_s *priv = (struct lpc2378_i2cdev_s *)arg;
 
@@ -314,9 +314,9 @@ static int lpc2378_i2c_interrupt(int irq, FAR void *context, FAR void *arg)
   state &= 0xf8;  /* state mask, only 0xX8 is possible */
   switch (state)
     {
+    case 0x08:    /* A START condition has been transmitted. */
+    case 0x10:    /* A Repeated START condition has been transmitted. */
 
-    case 0x08:     /* A START condition has been transmitted. */
-    case 0x10:     /* A Repeated START condition has been transmitted. */
       /* Set address */
 
       putreg32(((I2C_M_READ & msg->flags) == I2C_M_READ) ?
@@ -401,7 +401,7 @@ static int lpc2378_i2c_transfer(FAR struct i2c_master_s *dev,
   struct lpc2378_i2cdev_s *priv = (struct lpc2378_i2cdev_s *)dev;
   int ret;
 
-   DEBUGASSERT(dev != NULL && msgs != NULL && count > 0);
+  DEBUGASSERT(dev != NULL && msgs != NULL && count > 0);
 
   /* Get exclusive access to the I2C bus */
 
@@ -430,7 +430,7 @@ static int lpc2378_i2c_transfer(FAR struct i2c_master_s *dev,
   return ret;
 }
 
-/************************************************************************************
+/****************************************************************************
  * Name: lpc2378_i2c_reset
  *
  * Description:
@@ -442,7 +442,7 @@ static int lpc2378_i2c_transfer(FAR struct i2c_master_s *dev,
  * Returned Value:
  *   Zero (OK) on success; a negated errno value on failure.
  *
- ************************************************************************************/
+ ****************************************************************************/
 
 #ifdef CONFIG_I2C_RESET
 static int lpc2378_i2c_reset(FAR struct i2c_master_s * dev)
@@ -590,11 +590,6 @@ struct i2c_master_s *lpc2378_i2cbus_initialize(int port)
 
   nxsem_set_protocol(&priv->wait, SEM_PRIO_NONE);
 
-  /* Allocate a watchdog timer */
-
-  priv->timeout = wd_create();
-  DEBUGASSERT(priv->timeout != 0);
-
   /* Attach Interrupt Handler */
 
   irq_attach(priv->irqid, lpc2378_i2c_interrupt, priv);
@@ -630,10 +625,9 @@ int lpc2378_i2cbus_uninitialize(FAR struct i2c_master_s * dev)
   nxsem_destroy(&priv->mutex);
   nxsem_destroy(&priv->wait);
 
-  /* Free the watchdog timer */
+  /* Cancel the watchdog timer */
 
-  wd_delete(priv->timeout);
-  priv->timeout = NULL;
+  wd_cancel(&priv->timeout);
 
   /* Disable interrupts */
 
