@@ -1,130 +1,133 @@
-/************************************************************************************************
+/****************************************************************************
  * arch/arm/src/nrf52/hardware/nrf52_radio.h
  *
- *   Copyright (C) 2019 Gregory Nutt. All rights reserved.
- *   Author: Mateusz Szafoni <raiden00@railab.me>
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.  The
+ * ASF licenses this file to you under the Apache License, Version 2.0 (the
+ * "License"); you may not use this file except in compliance with the
+ * License.  You may obtain a copy of the License at
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- * 3. Neither the name NuttX nor the names of its contributors may be
- *    used to endorse or promote products derived from this software
- *    without specific prior written permission.
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+ * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
+ * License for the specific language governing permissions and limitations
+ * under the License.
  *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
- * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
- * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
- * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
- * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
- * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
- * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
- * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
- * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
- * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
- * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
- * POSSIBILITY OF SUCH DAMAGE.
- *
- ************************************************************************************************/
+ ****************************************************************************/
 
 #ifndef __ARCH_ARM_SRC_NRF52_HARDWARE_NRF52_RADIO_H
 #define __ARCH_ARM_SRC_NRF52_HARDWARE_NRF52_RADIO_H
 
-/************************************************************************************************
+/****************************************************************************
  * Included Files
- ************************************************************************************************/
+ ****************************************************************************/
 
 #include <nuttx/config.h>
 #include "hardware/nrf52_memorymap.h"
 
-/************************************************************************************************
+/****************************************************************************
  * Pre-processor Definitions
- ************************************************************************************************/
+ ****************************************************************************/
 
-/* Register offsets *****************************************************************************/
+/* Configuration ************************************************************/
 
-#define NRF52_RADIO_TASKS_TXEN_OFFSET        0x0000 /* Enable RADIO in TX mode */
-#define NRF52_RADIO_TASKS_RXEN_OFFSET        0x0004 /* Enable RADIO in RX mode */
-#define NRF52_RADIO_TASKS_START_OFFSET       0x0008 /* Start RADIO */
-#define NRF52_RADIO_TASKS_STOP_OFFSET        0x000C /* Stop RADIO */
-#define NRF52_RADIO_TASKS_DISABLE_OFFSET     0x0010 /* Disable RADIO */
-#define NRF52_RADIO_TASKS_RSSISTART_OFFSET   0x0014 /* Start the RSSI and take one single sample of the receive signal strength */
-#define NRF52_RADIO_TASKS_RSSISTOP_OFFSET    0x0018 /* Stop the RSSI measurement */
-#define NRF52_RADIO_TASKS_BCSTART_OFFSET     0x001c /* Start the bit counter */
-#define NRF52_RADIO_TASKS_BCSTOP_OFFSET      0x0020 /* Stop the bit counter */
-#define NRF52_RADIO_TASKS_EDSTART_OFFSET     0x0024 /* Start the energy detect measurement used in IEEE 802.15.4 mode */
-#define NRF52_RADIO_TASKS_EDSTOP_OFFSET      0x0028 /* Stop the energy detect measurement  */
-#define NRF52_RADIO_TASKS_CCASTART_OFFSET    0x002c /* Start the clear channel assessment used in IEEE 802.15.4 mode */
-#define NRF52_RADIO_TASKS_CCASTOP_OFFSET     0x0030 /* Stop the clear channel assessment */
-#define NRF52_RADIO_EVENTS_READY_OFFSET      0x0100 /* RADIO has ramped up and is ready to be started */
-#define NRF52_RADIO_EVENTS_ADDRESS_OFFSET    0x0104 /* Address sent or received */
-#define NRF52_RADIO_EVENTS_PAYLOAD_OFFSET    0x0108 /* Packet payload sent or received */
-#define NRF52_RADIO_EVENTS_END_OFFSET        0x010c /* Packet sent or received */
-#define NRF52_RADIO_EVENTS_DISABLED_OFFSET   0x0110 /* RADIO has been disabled */
-#define NRF52_RADIO_EVENTS_DEVMATCH_OFFSET   0x0114 /* A device address match occurred on the last received packet */
-#define NRF52_RADIO_EVENTS_DEVMISS_OFFSET    0x0118 /* No device address match occurred on the last received packet */
-#define NRF52_RADIO_EVENTS_RSSIEND_OFFSET    0x011c /* Sampling of receive signal strength complete */
-#define NRF52_RADIO_EVENTS_BCMATCH_OFFSET    0x0128 /* Bit counter reached bit count value */
-#define NRF52_RADIO_EVENTS_CRCOK_OFFSET      0x0130 /* Packet received with CRC ok */
-#define NRF52_RADIO_EVENTS_CRCERROR_OFFSET   0x0134 /* Packet received with CRC error */
-#define NRF52_RADIO_EVENTS_FRAMESTART_OFFSET 0x0138 /* IEEE 802.15.4 length field received */
-#define NRF52_RADIO_EVENTS_EDEND_OFFSET      0x013c /* Sampling of energy detection complete */
-#define NRF52_RADIO_EVENTS_EDSTOPPED_OFFSET  0x0140 /* The sampling of energy detection has stopped */
-#define NRF52_RADIO_EVENTS_CCAIDLE_OFFSET    0x0144 /* Wireless medium in idle - clear to send */
-#define NRF52_RADIO_EVENTS_CCABUSY_OFFSET    0x0148 /* Wireless medium busy - do not send */
-#define NRF52_RADIO_EVENTS_CCASTOPPED_OFFSET 0x014c /* The CCA has stopped */
-#define NRF52_RADIO_EVENTS_RATEBOOST_OFFSET  0x0150 /* Ble_LR CI field received */
-#define NRF52_RADIO_EVENTS_TXREADY_OFFSET    0x0154 /* RADIO has ramped up and is ready to be started TX path */
-#define NRF52_RADIO_EVENTS_RXREADY_OFFSET    0x0158 /* RADIO has ramped up and is ready to be started RX path */
-#define NRF52_RADIO_EVENTS_MHRMATCH_OFFSET   0x015c /* MAC header match found */
-#define NRF52_RADIO_EVENTS_PHYEND_OFFSET     0x016c /* Last bit is sent on air */
-#define NRF52_RADIO_SHORTS_OFFSET            0x0200 /* Shortcuts between local events and tasks */
-#define NRF52_RADIO_INTENSET_OFFSET          0x0304 /* Enable interrupt */
-#define NRF52_RADIO_INTENCLR_OFFSET          0x0308 /* Disable interrupt */
-#define NRF52_RADIO_CRCSTATUS_OFFSET         0x0400 /* CRC status */
-#define NRF52_RADIO_RXMATCH_OFFSET           0x0408 /* Received address */
-#define NRF52_RADIO_RXCRC_OFFSET             0x040c /* CRC field of previously received packet */
-#define NRF52_RADIO_DAI_OFFSET               0x0410 /* Device address match index */
-#define NRF52_RADIO_PDUSTAT_OFFSET           0x0414 /* Payload status */
-#define NRF52_RADIO_PACKETPTR_OFFSET         0x0504 /* Packet pointer */
-#define NRF52_RADIO_FREQUENCY_OFFSET         0x0508 /* Frequency */
-#define NRF52_RADIO_TXPOWER_OFFSET           0x050c /* Output power */
-#define NRF52_RADIO_MODE_OFFSET              0x0510 /* Data rate and modulation */
-#define NRF52_RADIO_PCNF0_OFFSET             0x0514 /* Packet configuration register 0 */
-#define NRF52_RADIO_PCNF1_OFFSET             0x0518 /* Packet configuration register 1 */
-#define NRF52_RADIO_BASE0_OFFSET             0x051c /* Base address 0 */
-#define NRF52_RADIO_BASE1_OFFSET             0x0520 /* Base address 1 */
-#define NRF52_RADIO_PREFIX0_OFFSET           0x0524 /* Prefixes bytes for logical addresses 0-3 */
-#define NRF52_RADIO_PREFIX1_OFFSET           0x0528 /* Prefixes bytes for logical addresses 4-7 */
-#define NRF52_RADIO_TXADDRESS_OFFSET         0x052c /* Transmit address select */
-#define NRF52_RADIO_RXADDRESS_OFFSET         0x0530 /* Receive address select */
-#define NRF52_RADIO_CRCCNF_OFFSET            0x0534 /* CRC configuration */
-#define NRF52_RADIO_CRCPOLY_OFFSET           0x0538 /* CRC polynomial */
-#define NRF52_RADIO_CRCINIT_OFFSET           0x053c /* CRC initial value */
-#define NRF52_RADIO_TIFS_OFFSET              0x0544 /* Interframe spacing in μs */
-#define NRF52_RADIO_RSSISAMPLE_OFFSET        0x0548 /* RSSI sample */
-#define NRF52_RADIO_STATE_OFFSET             0x0550 /* Current radio state */
-#define NRF52_RADIO_DATAWHITEIV_OFFSET       0x0554 /* Data whitening initial value */
-#define NRF52_RADIO_BCC_OFFSET               0x0560 /* Bit counter compare */
+#if defined(CONFIG_ARCH_CHIP_NRF52832)
+#  define HAVE_RADIO_NRF250KBIT
+#  undef  HAVE_RADIO_BLELR
+#  undef  HAVE_RADIO_IEEE802154
+#elif defined(CONFIG_ARCH_CHIP_NRF52833)
+#  undef  HAVE_RADIO_NRF250KBIT
+#  define HAVE_RADIO_BLELR
+#  define HAVE_RADIO_IEEE802154
+#elif defined(CONFIG_ARCH_CHIP_NRF52840)
+#  undef  HAVE_RADIO_NRF250KBIT
+#  define HAVE_RADIO_BLELR
+#  define HAVE_RADIO_IEEE802154
+#else
+#  error Unknown NRF52 chip !
+#endif
+
+/* Register offsets *********************************************************/
+
+#define NRF52_RADIO_TASKS_TXEN_OFFSET        0x0000                 /* Enable RADIO in TX mode */
+#define NRF52_RADIO_TASKS_RXEN_OFFSET        0x0004                 /* Enable RADIO in RX mode */
+#define NRF52_RADIO_TASKS_START_OFFSET       0x0008                 /* Start RADIO */
+#define NRF52_RADIO_TASKS_STOP_OFFSET        0x000C                 /* Stop RADIO */
+#define NRF52_RADIO_TASKS_DISABLE_OFFSET     0x0010                 /* Disable RADIO */
+#define NRF52_RADIO_TASKS_RSSISTART_OFFSET   0x0014                 /* Start the RSSI and take one single sample of the receive signal strength */
+#define NRF52_RADIO_TASKS_RSSISTOP_OFFSET    0x0018                 /* Stop the RSSI measurement */
+#define NRF52_RADIO_TASKS_BCSTART_OFFSET     0x001c                 /* Start the bit counter */
+#define NRF52_RADIO_TASKS_BCSTOP_OFFSET      0x0020                 /* Stop the bit counter */
+#define NRF52_RADIO_TASKS_EDSTART_OFFSET     0x0024                 /* Start the energy detect measurement used in IEEE 802.15.4 mode */
+#define NRF52_RADIO_TASKS_EDSTOP_OFFSET      0x0028                 /* Stop the energy detect measurement  */
+#define NRF52_RADIO_TASKS_CCASTART_OFFSET    0x002c                 /* Start the clear channel assessment used in IEEE 802.15.4 mode */
+#define NRF52_RADIO_TASKS_CCASTOP_OFFSET     0x0030                 /* Stop the clear channel assessment */
+#define NRF52_RADIO_EVENTS_READY_OFFSET      0x0100                 /* RADIO has ramped up and is ready to be started */
+#define NRF52_RADIO_EVENTS_ADDRESS_OFFSET    0x0104                 /* Address sent or received */
+#define NRF52_RADIO_EVENTS_PAYLOAD_OFFSET    0x0108                 /* Packet payload sent or received */
+#define NRF52_RADIO_EVENTS_END_OFFSET        0x010c                 /* Packet sent or received */
+#define NRF52_RADIO_EVENTS_DISABLED_OFFSET   0x0110                 /* RADIO has been disabled */
+#define NRF52_RADIO_EVENTS_DEVMATCH_OFFSET   0x0114                 /* A device address match occurred on the last received packet */
+#define NRF52_RADIO_EVENTS_DEVMISS_OFFSET    0x0118                 /* No device address match occurred on the last received packet */
+#define NRF52_RADIO_EVENTS_RSSIEND_OFFSET    0x011c                 /* Sampling of receive signal strength complete */
+#define NRF52_RADIO_EVENTS_BCMATCH_OFFSET    0x0128                 /* Bit counter reached bit count value */
+#define NRF52_RADIO_EVENTS_CRCOK_OFFSET      0x0130                 /* Packet received with CRC ok */
+#define NRF52_RADIO_EVENTS_CRCERROR_OFFSET   0x0134                 /* Packet received with CRC error */
+#define NRF52_RADIO_EVENTS_FRAMESTART_OFFSET 0x0138                 /* IEEE 802.15.4 length field received */
+#define NRF52_RADIO_EVENTS_EDEND_OFFSET      0x013c                 /* Sampling of energy detection complete */
+#define NRF52_RADIO_EVENTS_EDSTOPPED_OFFSET  0x0140                 /* The sampling of energy detection has stopped */
+#define NRF52_RADIO_EVENTS_CCAIDLE_OFFSET    0x0144                 /* Wireless medium in idle - clear to send */
+#define NRF52_RADIO_EVENTS_CCABUSY_OFFSET    0x0148                 /* Wireless medium busy - do not send */
+#define NRF52_RADIO_EVENTS_CCASTOPPED_OFFSET 0x014c                 /* The CCA has stopped */
+#define NRF52_RADIO_EVENTS_RATEBOOST_OFFSET  0x0150                 /* Ble_LR CI field received */
+#define NRF52_RADIO_EVENTS_TXREADY_OFFSET    0x0154                 /* RADIO has ramped up and is ready to be started TX path */
+#define NRF52_RADIO_EVENTS_RXREADY_OFFSET    0x0158                 /* RADIO has ramped up and is ready to be started RX path */
+#define NRF52_RADIO_EVENTS_MHRMATCH_OFFSET   0x015c                 /* MAC header match found */
+#define NRF52_RADIO_EVENTS_PHYEND_OFFSET     0x016c                 /* Last bit is sent on air */
+#define NRF52_RADIO_SHORTS_OFFSET            0x0200                 /* Shortcuts between local events and tasks */
+#define NRF52_RADIO_INTENSET_OFFSET          0x0304                 /* Enable interrupt */
+#define NRF52_RADIO_INTENCLR_OFFSET          0x0308                 /* Disable interrupt */
+#define NRF52_RADIO_CRCSTATUS_OFFSET         0x0400                 /* CRC status */
+#define NRF52_RADIO_RXMATCH_OFFSET           0x0408                 /* Received address */
+#define NRF52_RADIO_RXCRC_OFFSET             0x040c                 /* CRC field of previously received packet */
+#define NRF52_RADIO_DAI_OFFSET               0x0410                 /* Device address match index */
+#define NRF52_RADIO_PDUSTAT_OFFSET           0x0414                 /* Payload status */
+#define NRF52_RADIO_PACKETPTR_OFFSET         0x0504                 /* Packet pointer */
+#define NRF52_RADIO_FREQUENCY_OFFSET         0x0508                 /* Frequency */
+#define NRF52_RADIO_TXPOWER_OFFSET           0x050c                 /* Output power */
+#define NRF52_RADIO_MODE_OFFSET              0x0510                 /* Data rate and modulation */
+#define NRF52_RADIO_PCNF0_OFFSET             0x0514                 /* Packet configuration register 0 */
+#define NRF52_RADIO_PCNF1_OFFSET             0x0518                 /* Packet configuration register 1 */
+#define NRF52_RADIO_BASE0_OFFSET             0x051c                 /* Base address 0 */
+#define NRF52_RADIO_BASE1_OFFSET             0x0520                 /* Base address 1 */
+#define NRF52_RADIO_PREFIX0_OFFSET           0x0524                 /* Prefixes bytes for logical addresses 0-3 */
+#define NRF52_RADIO_PREFIX1_OFFSET           0x0528                 /* Prefixes bytes for logical addresses 4-7 */
+#define NRF52_RADIO_TXADDRESS_OFFSET         0x052c                 /* Transmit address select */
+#define NRF52_RADIO_RXADDRESSES_OFFSET       0x0530                 /* Receive address select */
+#define NRF52_RADIO_CRCCNF_OFFSET            0x0534                 /* CRC configuration */
+#define NRF52_RADIO_CRCPOLY_OFFSET           0x0538                 /* CRC polynomial */
+#define NRF52_RADIO_CRCINIT_OFFSET           0x053c                 /* CRC initial value */
+#define NRF52_RADIO_TIFS_OFFSET              0x0544                 /* Interframe spacing in μs */
+#define NRF52_RADIO_RSSISAMPLE_OFFSET        0x0548                 /* RSSI sample */
+#define NRF52_RADIO_STATE_OFFSET             0x0550                 /* Current radio state */
+#define NRF52_RADIO_DATAWHITEIV_OFFSET       0x0554                 /* Data whitening initial value */
+#define NRF52_RADIO_BCC_OFFSET               0x0560                 /* Bit counter compare */
 #define NRF52_RADIO_DAB_OFFSET(p)            (0x0600 + ((p) * 0x4)) /* Device address base segment */
 #define NRF52_RADIO_DAP_OFFSET(p)            (0x0620 + ((p) * 0x4)) /* Device address prefix */
-#define NRF52_RADIO_DACNF_OFFSET             0x0640 /* Device address match configuration */
-#define NRF52_RADIO_MHRMATCHCONF_OFFSET      0x0644 /* Search pattern configuration */
-#define NRF52_RADIO_MHRMATCHMAS_OFFSET       0x0648 /* Pattern mask */
-#define NRF52_RADIO_MODECNF0_OFFSET          0x0650 /* Radio mode configuration register 0 */
-#define NRF52_RADIO_SFD_OFFSET               0x0660 /* IEEE 802.15.4 start of frame delimiter */
-#define NRF52_RADIO_EDCNT_OFFSET             0x0664 /* IEEE 802.15.4 energy detect loop count */
-#define NRF52_RADIO_EDSAMPLE_OFFSET          0x0668 /* IEEE 802.15.4 energy detect level */
-#define NRF52_RADIO_CCACTRL_OFFSET           0x066c /* IEEE 802.15.4 clear channel assessment control */
-#define NRF52_RADIO_POWER_OFFSET             0x0ffc /* Peripheral power control */
+#define NRF52_RADIO_DACNF_OFFSET             0x0640                 /* Device address match configuration */
+#define NRF52_RADIO_MHRMATCHCONF_OFFSET      0x0644                 /* Search pattern configuration */
+#define NRF52_RADIO_MHRMATCHMAS_OFFSET       0x0648                 /* Pattern mask */
+#define NRF52_RADIO_MODECNF0_OFFSET          0x0650                 /* Radio mode configuration register 0 */
+#define NRF52_RADIO_SFD_OFFSET               0x0660                 /* IEEE 802.15.4 start of frame delimiter */
+#define NRF52_RADIO_EDCNT_OFFSET             0x0664                 /* IEEE 802.15.4 energy detect loop count */
+#define NRF52_RADIO_EDSAMPLE_OFFSET          0x0668                 /* IEEE 802.15.4 energy detect level */
+#define NRF52_RADIO_CCACTRL_OFFSET           0x066c                 /* IEEE 802.15.4 clear channel assessment control */
+#define NRF52_RADIO_POWER_OFFSET             0x0ffc                 /* Peripheral power control */
 
-/* Register Addresses ***************************************************************************/
+/* Register Addresses *******************************************************/
 
 #define NRF52_RADIO_TASKS_TXEN        (NRF52_RADIO_BASE + NRF52_RADIO_TASKS_TXEN_OFFSET)
 #define NRF52_RADIO_TASKS_RXEN        (NRF52_RADIO_BASE + NRF52_RADIO_TASKS_RXEN_OFFSET)
@@ -180,7 +183,7 @@
 #define NRF52_RADIO_PREFIX0           (NRF52_RADIO_BASE + NRF52_RADIO_PREFIX0_OFFSET)
 #define NRF52_RADIO_PREFIX1           (NRF52_RADIO_BASE + NRF52_RADIO_PREFIX1_OFFSET)
 #define NRF52_RADIO_TXADDRESS         (NRF52_RADIO_BASE + NRF52_RADIO_TXADDRESS_OFFSET)
-#define NRF52_RADIO_RXADDRESS         (NRF52_RADIO_BASE + NRF52_RADIO_RXADDRESS_OFFSET)
+#define NRF52_RADIO_RXADDRESSES       (NRF52_RADIO_BASE + NRF52_RADIO_RXADDRESSES_OFFSET)
 #define NRF52_RADIO_CRCCNF            (NRF52_RADIO_BASE + NRF52_RADIO_CRCCNF_OFFSET)
 #define NRF52_RADIO_CRCPOLY           (NRF52_RADIO_BASE + NRF52_RADIO_CRCPOLY_OFFSET)
 #define NRF52_RADIO_CRCINIT           (NRF52_RADIO_BASE + NRF52_RADIO_CRCINIT_OFFSET)
@@ -201,7 +204,7 @@
 #define NRF52_RADIO_CCACTRL           (NRF52_RADIO_BASE + NRF52_RADIO_CCACTRL_OFFSET)
 #define NRF52_RADIO_POWER             (NRF52_RADIO_BASE + NRF52_RADIO_POWER_OFFSET)
 
-/* Register Bitfield Definitions ****************************************************************/
+/* Register Bitfield Definitions ********************************************/
 
 /* TASKS_TXEN Register */
 
@@ -432,15 +435,21 @@
 
 /* MODE Register */
 
-#define RADIO_MODE_SHIFT                  (0)       /* Bits 0-3: Radio data rate and modulation setting (FSK) */
+#define RADIO_MODE_SHIFT                  (0)                        /* Bits 0-3: Radio data rate and modulation setting (FSK) */
 #define RADIO_MODE_MASK                   (0xf << RADIO_MODE_SHIFT)
 #define RADIO_MODE_NRF1MBIT               (0x00 << RADIO_MODE_SHIFT) /* 0: 1 Mbit/s Nordic proprietary radio mode */
 #define RADIO_MODE_NRF2MBIT               (0x01 << RADIO_MODE_SHIFT) /* 1: 2 Mbit/s Nordic proprietary radio mode */
+#ifdef HAVE_RADIO_NRF250KBIT
+#  define RADIO_MODE_NRF250KBIT           (0x02 << RADIO_MODE_SHIFT) /* 2: 250 kbit/s Nordic proprietary radio mode (deprecated) */
+#endif
 #define RADIO_MODE_BLE1MBIT               (0x03 << RADIO_MODE_SHIFT) /* 3: 1 Mbit/s BLE */
 #define RADIO_MODE_BLE2MBIT               (0x04 << RADIO_MODE_SHIFT) /* 4: 2 Mbit/s BLE */
-#define RADIO_MODE_BLELR125KBIT           (0x05 << RADIO_MODE_SHIFT) /* 5: Long range 125 kbit/s TX, 125 kbit/s and 500 kbit/s RX */
-#define RADIO_MODE_BLELR500KBIT           (0x06 << RADIO_MODE_SHIFT) /* 6: Long range 500 kbit/s TX, 125 kbit/s and 500 kbit/s RX */
-#define RADIO_MODE_IEEE802154             (0x0f << RADIO_MODE_SHIFT) /* 15: IEEE 802.15.4-2006 250 kbit/s */
+#ifdef HAVE_RADIO_BLELR
+#  define RADIO_MODE_BLELR125KBIT         (0x05 << RADIO_MODE_SHIFT) /* 5: Long range 125 kbit/s TX, 125 kbit/s and 500 kbit/s RX */
+#  define RADIO_MODE_BLELR500KBIT         (0x06 << RADIO_MODE_SHIFT) /* 6: Long range 500 kbit/s TX, 125 kbit/s and 500 kbit/s RX */
+#ifdef HAVE_RADIO_IEEE802154
+#  define RADIO_MODE_IEEE802154           (0x0f << RADIO_MODE_SHIFT) /* 15: IEEE 802.15.4-2006 250 kbit/s */
+#endif
 
 /* PCNF0 Register */
 
@@ -454,20 +463,29 @@
 #define RADIO_PCNF0_S1LEN_MASK            (0xf << RADIO_PCNF0_S1LEN_SHIFT)
 #define RADIO_PCNF0_S1LEN_MAX             (0xf)
 #define RADIO_PCNF0_S1INCL                (1 << 20) /* Bit 20: Include or exclude S1 field in RAM */
-#define RADIO_PCNF0_CILEN_SHIFT           (22)      /* Bits 22-23: Length of code indicator - long range */
-#define RADIO_PCNF0_CILEN_MASK            (0x3 << RADIO_PCNF0_CILEN_SHIFT)
-#define RADIO_PCNF0_CILEN_MAX             (0x3)
+#ifdef HAVE_RADIO_BLELR
+#  define RADIO_PCNF0_CILEN_SHIFT         (22)      /* Bits 22-23: Length of code indicator - long range */
+#  define RADIO_PCNF0_CILEN_MASK          (0x3 << RADIO_PCNF0_CILEN_SHIFT)
+#  define RADIO_PCNF0_CILEN_MAX           (0x3)
+#endif
+
 #define RADIO_PCNF0_PLEN_SHIFT            (24)      /* Bits 24-25: Length of preamble on air */
 #define RADIO_PCNF0_PLEN_MASK             (0x3 << RADIO_PCNF0_PLEN_SHIFT)
 #  define RADIO_PCNF0_PLEN_8BIT           (0 << RADIO_PCNF0_PLEN_SHIFT)
 #  define RADIO_PCNF0_PLEN_16BIT          (1 << RADIO_PCNF0_PLEN_SHIFT)
+#ifdef HAVE_RADIO_IEEE802154
 #  define RADIO_PCNF0_PLEN_32BITZ         (2 << RADIO_PCNF0_PLEN_SHIFT)
+#endif
+#ifdef HAVE_RADIO_BLELR
 #  define RADIO_PCNF0_PLEN_LONGRANGE      (3 << RADIO_PCNF0_PLEN_SHIFT)
-#define RADIO_PCNF0_CRCINC_SHIFT          (26)      /* Bit 26: Indicates if LENGTH field contains CRC */
-#define RADIO_PCNF0_CRCINC                (1 << RADIO_PCNF0_CRCINC_SHIFT)
-#define RADIO_PCNF0_TERMLEN_SHIFT         (29)      /* Bits 29-30: Length of TERM field in Long Range operation */
-#define RADIO_PCNF0_TERMLEN_MASK          (0x3 << RADIO_PCNF0_TERMLEN_SHIFT)
-#define RADIO_PCNF0_TERMLEN_MAX           (0x3)
+#endif
+#ifdef HAVE_RADIO_BLELR
+#  define RADIO_PCNF0_CRCINC_SHIFT        (26)      /* Bit 26: Indicates if LENGTH field contains CRC */
+#  define RADIO_PCNF0_CRCINC              (1 << RADIO_PCNF0_CRCINC_SHIFT)
+#  define RADIO_PCNF0_TERMLEN_SHIFT       (29)      /* Bits 29-30: Length of TERM field in Long Range operation */
+#  define RADIO_PCNF0_TERMLEN_MASK        (0x3 << RADIO_PCNF0_TERMLEN_SHIFT)
+#  define RADIO_PCNF0_TERMLEN_MAX         (0x3)
+#endif
 
 /* PCNF1 Register */
 
@@ -506,10 +524,16 @@
 #  define RADIO_CRCCNF_LEN_2              (2 << RADIO_CRCCNF_LEN_SHIFT)
 #  define RADIO_CRCCNF_LEN_3              (3 << RADIO_CRCCNF_LEN_SHIFT)
 #define RADIO_CRCCNF_SKIPADDR_SHIFT       (8)       /* Bit 8-9: Include or exclude packet address field out of CRC calculation */
-#define RADIO_CRCCNF_SKIPADDR_MASK        (0 << RADIO_CRCCNF_SKIPADDR_SHIFT)
-#  define RADIO_CRCCNF_SKIPADDR_INCL      (1 << RADIO_CRCCNF_SKIPADDR_SHIFT)
-#  define RADIO_CRCCNF_SKIPADDR_SKIP      (2 << RADIO_CRCCNF_SKIPADDR_SHIFT)
+#ifdef HAVE_RADIO_IEEE802154
+#  define RADIO_CRCCNF_SKIPADDR_MASK      (0x3 << RADIO_CRCCNF_SKIPADDR_SHIFT)
+#  define RADIO_CRCCNF_SKIPADDR_INCL      (0 << RADIO_CRCCNF_SKIPADDR_SHIFT)
+#  define RADIO_CRCCNF_SKIPADDR_SKIP      (1 << RADIO_CRCCNF_SKIPADDR_SHIFT)
 #  define RADIO_CRCCNF_SKIPADDR_IEEE      (3 << RADIO_CRCCNF_SKIPADDR_SHIFT)
+#else
+#  define RADIO_CRCCNF_SKIPADDR_MASK      (0x1 << RADIO_CRCCNF_SKIPADDR_SHIFT)
+#  define RADIO_CRCCNF_SKIPADDR_INCL      (0 << RADIO_CRCCNF_SKIPADDR_SHIFT)
+#  define RADIO_CRCCNF_SKIPADDR_SKIP      (1 << RADIO_CRCCNF_SKIPADDR_SHIFT)
+#endif
 
 /* CRCPOLY Register */
 
@@ -571,20 +595,22 @@
 #  define RADIO_MODECNF0_DTX_B0           (1 << RADIO_MODECNF0_DTX_SHIFT)
 #  define RADIO_MODECNF0_DTX_CENTER       (2 << RADIO_MODECNF0_DTX_SHIFT)
 
+#ifdef HAVE_RADIO_IEEE802154
 /* SFD Register */
 
-#define RADIO_SFD_SHIFT                   (0)     /* Bits 0-7: IEEE 802.15.4 start of frame delimiter */
-#define RADIO_SFD_MASK                    (0xff << RADIO_SFD_SHIFT)
+#  define RADIO_SFD_SHIFT                 (0)     /* Bits 0-7: IEEE 802.15.4 start of frame delimiter */
+#  define RADIO_SFD_MASK                  (0xff << RADIO_SFD_SHIFT)
 
 /* EDCNT Register */
 
-#define RADIO_EDCNT_SHIFT                 (0)     /* Bits 0-20: IEEE 802.15.4 energy detect loop count */
-#define RADIO_EDCNT_MASK                  (0x1fffff << RADIO_EDCNT_SHIFT)
+#  define RADIO_EDCNT_SHIFT               (0)     /* Bits 0-20: IEEE 802.15.4 energy detect loop count */
+#  define RADIO_EDCNT_MASK                (0x1fffff << RADIO_EDCNT_SHIFT)
 
 /* EDSAMPLE Register */
 
-#define RADIO_EDSAMPLE_SHIFT              (0)     /* Bits 0-7: IEEE 802.15.4 energy detect level */
-#define RADIO_EDSAMPLE_MASK               (0xff << RADIO_EDSAMPLE_SHIFT)
+#  define RADIO_EDSAMPLE_SHIFT            (0)     /* Bits 0-7: IEEE 802.15.4 energy detect level */
+#  define RADIO_EDSAMPLE_MASK             (0xff << RADIO_EDSAMPLE_SHIFT)
+#endif  /* CONFIG_NRF52_HAVE_RADIO_IEEE802154 */
 
 /* CCACTRL Register */
 
