@@ -166,15 +166,23 @@ static const struct spi_ops_s g_spi0ops =
 #  endif
   .status            = nrf52_spi0status,
 #  ifdef CONFIG_SPI_CMDDATA
-  .cmddata           = nrf52_spi1cmddata,
+  .cmddata           = nrf52_spi0cmddata,
 #  endif
   .send              = nrf52_spi_send,
 #  ifdef CONFIG_SPI_EXCHANGE
   .exchange          = nrf52_spi_exchange,
 #  else
-  .sendlock          = nrf52_spi_sendblock,
-  .recvblock         = nrf52_spi_recvblock
+  .sndblock          = nrf52_spi_sndblock,
+  .recvblock         = nrf52_spi_recvblock,
 #  endif
+#ifdef CONFIG_SPI_TRIGGER
+  .trigger           = nrf52_spi_trigger,
+#endif
+#ifdef CONFIG_SPI_CALLBACK
+  .registercallback  = nrf52_spi0register,  /* Provided externally */
+#else
+  .registercallback  = NULL,                /* Not implemented */
+#endif
 };
 
 static struct nrf52_spidev_s g_spi0dev =
@@ -217,9 +225,17 @@ static const struct spi_ops_s g_spi1ops =
 #  ifdef CONFIG_SPI_EXCHANGE
   .exchange          = nrf52_spi_exchange,
 #  else
-  .sendlock          = nrf52_spi_sendblock,
-  .recvblock         = nrf52_spi_recvblock
+  .sndlock           = nrf52_spi_sndblock,
+  .recvblock         = nrf52_spi_recvblock,
 #  endif
+#ifdef CONFIG_SPI_TRIGGER
+  .trigger           = nrf52_spi_trigger,
+#endif
+#ifdef CONFIG_SPI_CALLBACK
+  .registercallback  = nrf52_spi1register,  /* Provided externally */
+#else
+  .registercallback  = NULL,                /* Not implemented */
+#endif
 };
 
 static struct nrf52_spidev_s g_spi1dev =
@@ -229,7 +245,7 @@ static struct nrf52_spidev_s g_spi1dev =
     &g_spi1ops
   },
 
-  .base      = NRF52_SPIM0_BASE,
+  .base      = NRF52_SPIM1_BASE,
 #ifdef CONFIG_NRF52_SPI_MASTER_INTERRUPTS
   .irq       = NRF52_IRQ_SPI_TWI_1,
 #endif
@@ -256,15 +272,23 @@ static const struct spi_ops_s g_spi2ops =
 #  endif
   .status            = nrf52_spi2status,
 #  ifdef CONFIG_SPI_CMDDATA
-  .cmddata           = nrf52_spi1cmddata,
+  .cmddata           = nrf52_spi2cmddata,
 #  endif
   .send              = nrf52_spi_send,
 #  ifdef CONFIG_SPI_EXCHANGE
   .exchange          = nrf52_spi_exchange,
 #  else
-  .sendlock          = nrf52_spi_sendblock,
-  .recvblock         = nrf52_spi_recvblock
+  .sndlock           = nrf52_spi_sndblock,
+  .recvblock         = nrf52_spi_recvblock,
 #  endif
+#ifdef CONFIG_SPI_TRIGGER
+  .trigger           = nrf52_spi_trigger,
+#endif
+#ifdef CONFIG_SPI_CALLBACK
+  .registercallback  = nrf52_spi2register,  /* Provided externally */
+#else
+  .registercallback  = NULL,                /* Not implemented */
+#endif
 };
 
 static struct nrf52_spidev_s g_spi2dev =
@@ -274,7 +298,7 @@ static struct nrf52_spidev_s g_spi2dev =
     &g_spi2ops
   },
 
-  .base      = NRF52_SPIM0_BASE,
+  .base      = NRF52_SPIM2_BASE,
 #ifdef CONFIG_NRF52_SPI_MASTER_INTERRUPTS
   .irq       = NRF52_IRQ_SPI2,
 #endif
@@ -301,15 +325,23 @@ static const struct spi_ops_s g_spi3ops =
 #  endif
   .status            = nrf52_spi3status,
 #  ifdef CONFIG_SPI_CMDDATA
-  .cmddata           = nrf52_spi1cmddata,
+  .cmddata           = nrf52_spi3cmddata,
 #  endif
   .send              = nrf52_spi_send,
 #  ifdef CONFIG_SPI_EXCHANGE
   .exchange          = nrf52_spi_exchange,
 #  else
-  .sendlock          = nrf52_spi_sendblock,
-  .recvblock         = nrf52_spi_recvblock
+  .sndlock           = nrf52_spi_sndblock,
+  .recvblock         = nrf52_spi_recvblock,
 #  endif
+#ifdef CONFIG_SPI_TRIGGER
+  .trigger           = nrf52_spi_trigger,
+#endif
+#ifdef CONFIG_SPI_CALLBACK
+  .registercallback  = nrf52_spi3register,  /* Provided externally */
+#else
+  .registercallback  = NULL,                /* Not implemented */
+#endif
 };
 
 static struct nrf52_spidev_s g_spi3dev =
@@ -319,7 +351,7 @@ static struct nrf52_spidev_s g_spi3dev =
     &g_spi3ops
   },
 
-  .base      = NRF52_SPIM0_BASE,
+  .base      = NRF52_SPIM3_BASE,
 #ifdef CONFIG_NRF52_SPI_MASTER_INTERRUPTS
   .irq       = NRF52_IRQ_SPI3,
 #endif
@@ -858,7 +890,7 @@ static void nrf52_spi_1b_workaround(FAR struct spi_dev_s *dev, bool enable)
  *   dev      - Device-specific state data
  *   txbuffer - A pointer to the buffer of data to be sent
  *   rxbuffer - A pointer to a buffer in which to receive data
- *   nwords   - the length of data to be exchaned in units of words.
+ *   nwords   - the length of data to be exchanged in units of words.
  *              The wordsize is determined by the number of bits-per-word
  *              selected for the SPI interface.
  *
@@ -874,6 +906,15 @@ static void nrf52_spi_exchange(FAR struct spi_dev_s *dev,
   FAR struct nrf52_spidev_s *priv = (FAR struct nrf52_spidev_s *)dev;
   uint32_t regval = 0;
 
+  if (nwords > 0xff)
+    {
+      /* MAXCNT register can only hold 8bits */
+
+      spierr("SPI transfer max of 255 bytes, %d requested\n")
+      DEBUGASSERT(false);
+      return;
+    }
+
 #ifdef CONFIG_NRF52_SPI_MASTER_WORKAROUND_1BYTE_TRANSFER
   if (nwords <= 1)
     {
@@ -893,6 +934,10 @@ static void nrf52_spi_exchange(FAR struct spi_dev_s *dev,
       regval = nwords;
       nrf52_spi_putreg(priv, NRF52_SPIM_RXDMAXCNT_OFFSET, regval);
     }
+  else
+    {
+      nrf52_spi_putreg(priv, NRF52_SPIM_RXDMAXCNT_OFFSET, 0);
+    }
 
   if (txbuffer != NULL)
     {
@@ -906,6 +951,10 @@ static void nrf52_spi_exchange(FAR struct spi_dev_s *dev,
       regval = nwords;
       nrf52_spi_putreg(priv, NRF52_SPIM_TXDMAXCNT_OFFSET, regval);
     }
+  else
+    {
+      nrf52_spi_putreg(priv, NRF52_SPIM_TXDMAXCNT_OFFSET, 0);
+    }
 
   /* SPI start */
 
@@ -925,6 +974,11 @@ static void nrf52_spi_exchange(FAR struct spi_dev_s *dev,
   nxsem_wait(&priv->sem_isr);
 #endif
 
+  if (nrf52_spi_getreg(priv, NRF52_SPIM_TXDAMOUNT_OFFSET) != nwords)
+    {
+      spierr("Incomplete transfer wrote %d expected %d\n", regval, nwords);
+    }
+
   /* SPI stop */
 
   nrf52_spi_putreg(priv, NRF52_SPIM_TASK_STOP_OFFSET, SPIM_TASKS_STOP);
@@ -1003,10 +1057,33 @@ static void nrf52_spi_recvblock(FAR struct spi_dev_s *dev,
                                 size_t nwords)
 {
   spiinfo("txbuffer=%p nwords=%d\n", txbuffer, nwords);
-  return nrf52_spi_exchange(dev, txbuffer, NULL, nwords);
+  return nrf52_spi_exchange(dev, rxbuffer, NULL, nwords);
 }
 #endif /* CONFIG_SPI_EXCHANGE */
 
+/****************************************************************************
+ * Name: nrf52_spi_trigger
+ *
+ * Description:
+ *   Trigger a previously configured DMA transfer.
+ *
+ * Input Parameters:
+ *   dev      - Device-specific state data
+ *
+ * Returned Value:
+ *   OK       - Trigger was fired
+ *   -ENOSYS  - Trigger not fired due to lack of DMA or low level support
+ *   -EIO     - Trigger not fired because not previously primed
+ *
+ ****************************************************************************/
+
+#ifdef CONFIG_SPI_TRIGGER
+static int nrf52_spi_trigger(FAR struct spi_dev_s *dev)
+{
+  return -ENOSYS;
+}
+#endif
+
 /****************************************************************************
  * Public Functions
  ****************************************************************************/
