@@ -160,7 +160,7 @@ struct twi_dev_s
 
   sem_t               exclsem;    /* Only one thread can access at a time */
   sem_t               waitsem;    /* Wait for TWIHS transfer completion */
-  WDOG_ID             timeout;    /* Watchdog to recover from bus hangs */
+  struct wdog_s       timeout;    /* Watchdog to recover from bus hangs */
   volatile int        result;     /* The result of the transfer */
   volatile int        xfrd;       /* Number of bytes transfers */
 
@@ -205,7 +205,7 @@ static inline void twi_putrel(struct twi_dev_s *priv, unsigned int offset,
 static int  twi_wait(struct twi_dev_s *priv, unsigned int size);
 static void twi_wakeup(struct twi_dev_s *priv, int result);
 static int  twi_interrupt(int irq, FAR void *context, FAR void *arg);
-static void twi_timeout(int argc, uint32_t arg, ...);
+static void twi_timeout(wdparm_t arg);
 
 static void twi_startread(struct twi_dev_s *priv, struct i2c_msg_s *msg);
 static void twi_startwrite(struct twi_dev_s *priv, struct i2c_msg_s *msg);
@@ -484,8 +484,8 @@ static int twi_wait(struct twi_dev_s *priv, unsigned int size)
    * a TWIHS transfer stalls.
    */
 
-  wd_start(priv->timeout, (timeout * size), twi_timeout, 1,
-           (uint32_t)priv);
+  wd_start(&priv->timeout, (timeout * size),
+           twi_timeout, (wdparm_t)priv);
 
   /* Wait for either the TWIHS transfer or the timeout to complete */
 
@@ -498,7 +498,7 @@ static int twi_wait(struct twi_dev_s *priv, unsigned int size)
 
       if (ret < 0)
         {
-          wd_cancel(priv->timeout);
+          wd_cancel(&priv->timeout);
           return ret;
         }
     }
@@ -543,7 +543,7 @@ static void twi_wakeup(struct twi_dev_s *priv, int result)
 {
   /* Cancel any pending timeout */
 
-  wd_cancel(priv->timeout);
+  wd_cancel(&priv->timeout);
 
   /* Disable any further TWIHS interrupts */
 
@@ -769,7 +769,7 @@ static int twi_interrupt(int irq, FAR void *context, FAR void *arg)
  *
  ****************************************************************************/
 
-static void twi_timeout(int argc, uint32_t arg, ...)
+static void twi_timeout(wdparm_t arg)
 {
   struct twi_dev_s *priv = (struct twi_dev_s *)arg;
 
@@ -1425,22 +1425,13 @@ struct i2c_master_s *sam_i2cbus_initialize(int bus)
 
       priv->attr = attr;
 
-      /* Allocate a watchdog timer */
-
-      priv->timeout = wd_create();
-      if (priv->timeout == NULL)
-        {
-          ierr("ERROR: Failed to allocate a timer\n");
-          goto errout_with_irq;
-        }
-
       /* Attach Interrupt Handler */
 
       ret = irq_attach(priv->attr->irq, twi_interrupt, priv);
       if (ret < 0)
         {
           ierr("ERROR: Failed to attach irq %d\n", priv->attr->irq);
-          goto errout_with_wdog;
+          goto errout_with_lock;
         }
 
       /* Initialize the TWIHS driver structure */
@@ -1466,11 +1457,7 @@ struct i2c_master_s *sam_i2cbus_initialize(int bus)
   leave_critical_section(flags);
   return &priv->dev;
 
-errout_with_wdog:
-  wd_delete(priv->timeout);
-  priv->timeout = NULL;
-
-errout_with_irq:
+errout_with_lock:
   priv->refs--;
   leave_critical_section(flags);
   return NULL;
@@ -1513,10 +1500,9 @@ int sam_i2cbus_uninitialize(FAR struct i2c_master_s *dev)
       nxsem_destroy(&priv->exclsem);
       nxsem_destroy(&priv->waitsem);
 
-      /* Free the watchdog timer */
+      /* Cancel the watchdog timer */
 
-      wd_delete(priv->timeout);
-      priv->timeout = NULL;
+      wd_cancel(&priv->timeout);
 
       /* Detach Interrupt Handler */
 
