@@ -71,7 +71,9 @@
 # define CONFIG_HCS12_NINTERFACES 1
 #endif
 
-/* TX poll deley = 1 seconds. CLK_TCK is the number of clock ticks per second */
+/* TX poll deley = 1 seconds.
+ * CLK_TCK is the number of clock ticks per second
+ */
 
 #define HCS12_WDDELAY   (1*CLK_TCK)
 
@@ -79,7 +81,7 @@
 
 #define HCS12_TXTIMEOUT (60*CLK_TCK)
 
-/* This is a helper pointer for accessing the contents of the Ethernet header */
+/* This is a helper pointer for accessing the contents of Ethernet header */
 
 #define BUF ((struct eth_hdr_s *)priv->d_dev.d_buf)
 
@@ -94,8 +96,8 @@
 struct emac_driver_s
 {
   bool    d_bifup;            /* true:ifup false:ifdown */
-  WDOG_ID d_txpoll;           /* TX poll timer */
-  WDOG_ID d_txtimeout;        /* TX timeout timer */
+  struct wdog_s d_txpoll;     /* TX poll timer */
+  struct wdog_s d_txtimeout;  /* TX timeout timer */
 
   /* This holds the information visible to the NuttX network */
 
@@ -131,8 +133,8 @@ static int  emac_interrupt(int irq, FAR void *context, FAR void *arg);
 
 /* Watchdog timer expirations */
 
-static void emac_polltimer(int argc, uint32_t arg, ...);
-static void emac_txtimeout(int argc, uint32_t arg, ...);
+static void emac_polltimer(wdparm_t arg);
+static void emac_txtimeout(wdparm_t arg);
 
 /* NuttX callback functions */
 
@@ -183,7 +185,8 @@ static int emac_transmit(FAR struct emac_driver_s *priv)
 
   /* Setup the TX timeout watchdog (perhaps restarting the timer) */
 
-  wd_start(priv->d_txtimeout, HCS12_TXTIMEOUT, emac_txtimeout, 1, (uint32_t)priv);
+  wd_start(&priv->d_txtimeout, HCS12_TXTIMEOUT,
+           emac_txtimeout, (wdparm_t)priv);
   return OK;
 }
 
@@ -214,7 +217,8 @@ static int emac_transmit(FAR struct emac_driver_s *priv)
 
 static int emac_txpoll(struct net_driver_s *dev)
 {
-  FAR struct emac_driver_s *priv = (FAR struct emac_driver_s *)dev->d_private;
+  FAR struct emac_driver_s *priv =
+    (FAR struct emac_driver_s *)dev->d_private;
 
   /* If the polling resulted in data that should be sent out on the network,
    * the field d_len is set to a value > 0.
@@ -250,14 +254,14 @@ static int emac_txpoll(struct net_driver_s *dev)
 
           emac_transmit(priv);
 
-          /* Check if there is room in the device to hold another packet. If not,
-           * return a non-zero value to terminate the poll.
+          /* Check if there is room in the device to hold another packet.
+           * If not, return a non-zero value to terminate the poll.
            */
         }
     }
 
-  /* If zero is returned, the polling will continue until all connections have
-   * been examined.
+  /* If zero is returned, the polling will continue until all connections
+   * have been examined.
    */
 
   return 0;
@@ -286,14 +290,16 @@ static void emac_receive(FAR struct emac_driver_s *priv)
     {
       /* Check for errors and update statistics */
 
-      /* Check if the packet is a valid size for the network buffer configuration */
+      /* Check if the packet is a valid size for the network buffer
+       * configuration
+       */
 
       /* Copy the data data from the hardware to priv->d_dev.d_buf.  Set
        * amount of data in priv->d_dev.d_len
        */
 
 #ifdef CONFIG_NET_PKT
-      /* When packet sockets are enabled, feed the frame into the packet tap */
+      /* When packet sockets are enabled, feed the frame into the tap */
 
       pkt_input(&priv->d_dev);
 #endif
@@ -313,7 +319,7 @@ static void emac_receive(FAR struct emac_driver_s *priv)
           ipv4_input(&priv->d_dev);
 
           /* If the above function invocation resulted in data that should be
-           * sent out on the network, the field  d_len will set to a value > 0.
+           * sent out on the network, d_len field will set to a value > 0.
            */
 
           if (priv->d_dev.d_len > 0)
@@ -350,11 +356,11 @@ static void emac_receive(FAR struct emac_driver_s *priv)
           ipv6_input(&priv->d_dev);
 
           /* If the above function invocation resulted in data that should be
-           * sent out on the network, the field  d_len will set to a value > 0.
+           * sent out on the network, d_len field will set to a value > 0.
            */
 
           if (priv->d_dev.d_len > 0)
-           {
+            {
               /* Update the Ethernet header with the correct MAC address */
 
 #ifdef CONFIG_NET_IPv4
@@ -383,7 +389,7 @@ static void emac_receive(FAR struct emac_driver_s *priv)
           arp_arpin(&priv->d_dev);
 
           /* If the above function invocation resulted in data that should be
-           * sent out on the network, the field  d_len will set to a value > 0.
+           * sent out on the network, d_len field will set to a value > 0.
            */
 
           if (priv->d_dev.d_len > 0)
@@ -421,7 +427,7 @@ static void emac_txdone(FAR struct emac_driver_s *priv)
    * disable further Tx interrupts.
    */
 
-  wd_cancel(priv->d_txtimeout);
+  wd_cancel(&priv->d_txtimeout);
 
   /* Then poll the network for new XMIT data */
 
@@ -475,8 +481,7 @@ static int emac_interrupt(int irq, FAR void *context, FAR void *arg)
  *   The last TX never completed.  Reset the hardware and start again.
  *
  * Input Parameters:
- *   argc - The number of available arguments
- *   arg  - The first argument
+ *   arg  - The argument
  *
  * Returned Value:
  *   None
@@ -486,7 +491,7 @@ static int emac_interrupt(int irq, FAR void *context, FAR void *arg)
  *
  ****************************************************************************/
 
-static void emac_txtimeout(int argc, uint32_t arg, ...)
+static void emac_txtimeout(wdparm_t arg)
 {
   FAR struct emac_driver_s *priv = (FAR struct emac_driver_s *)arg;
 
@@ -506,8 +511,7 @@ static void emac_txtimeout(int argc, uint32_t arg, ...)
  *   Periodic timer handler.  Called from the timer interrupt handler.
  *
  * Input Parameters:
- *   argc - The number of available arguments
- *   arg  - The first argument
+ *   arg  - The argument
  *
  * Returned Value:
  *   None
@@ -517,7 +521,7 @@ static void emac_txtimeout(int argc, uint32_t arg, ...)
  *
  ****************************************************************************/
 
-static void emac_polltimer(int argc, uint32_t arg, ...)
+static void emac_polltimer(wdparm_t arg)
 {
   FAR struct emac_driver_s *priv = (FAR struct emac_driver_s *)arg;
 
@@ -525,16 +529,16 @@ static void emac_polltimer(int argc, uint32_t arg, ...)
    * the TX poll if he are unable to accept another packet for transmission.
    */
 
-  /* If so, update TCP timing states and poll the network for new XMIT data. Hmmm..
-   * might be bug here.  Does this mean if there is a transmit in progress,
-   * we will missing TCP time state updates?
+  /* If so, update TCP timing states and poll the network for new XMIT data.
+   * Hmmm.. might be bug here.  Does this mean if there is a transmit in
+   * progress, we will missing TCP time state updates?
    */
 
   devif_timer(&priv->d_dev, HCS12_WDDELAY, emac_txpoll);
 
   /* Setup the watchdog poll timer again */
 
-  wd_start(priv->d_txpoll, HCS12_WDDELAY, emac_polltimer, 1, arg);
+  wd_start(&priv->d_txpoll, HCS12_WDDELAY, emac_polltimer, (wdparm_t)arg);
 }
 
 /****************************************************************************
@@ -556,17 +560,19 @@ static void emac_polltimer(int argc, uint32_t arg, ...)
 
 static int emac_ifup(struct net_driver_s *dev)
 {
-  FAR struct emac_driver_s *priv = (FAR struct emac_driver_s *)dev->d_private;
+  FAR struct emac_driver_s *priv =
+    (FAR struct emac_driver_s *)dev->d_private;
 
   ninfo("Bringing up: %d.%d.%d.%d\n",
         dev->d_ipaddr & 0xff, (dev->d_ipaddr >> 8) & 0xff,
-        (dev->d_ipaddr >> 16) & 0xff, dev->d_ipaddr >> 24 );
+        (dev->d_ipaddr >> 16) & 0xff, dev->d_ipaddr >> 24);
 
-  /* Initialize PHYs, the Ethernet interface, and setup up Ethernet interrupts */
+  /* Initialize PHYs, Ethernet interface, and setup up Ethernet interrupts */
 
   /* Set and activate a timer process */
 
-  wd_start(priv->d_txpoll, HCS12_WDDELAY, emac_polltimer, 1, (uint32_t)priv);
+  wd_start(&priv->d_txpoll, HCS12_WDDELAY,
+           emac_polltimer, (wdparm_t)priv);
 
   /* Enable the Ethernet interrupt */
 
@@ -593,7 +599,8 @@ static int emac_ifup(struct net_driver_s *dev)
 
 static int emac_ifdown(struct net_driver_s *dev)
 {
-  FAR struct emac_driver_s *priv = (FAR struct emac_driver_s *)dev->d_private;
+  FAR struct emac_driver_s *priv =
+    (FAR struct emac_driver_s *)dev->d_private;
   irqstate_t flags;
 
   /* Disable the Ethernet interrupt */
@@ -603,8 +610,8 @@ static int emac_ifdown(struct net_driver_s *dev)
 
   /* Cancel the TX poll timer and TX timeout timers */
 
-  wd_cancel(priv->d_txpoll);
-  wd_cancel(priv->d_txtimeout);
+  wd_cancel(&priv->d_txpoll);
+  wd_cancel(&priv->d_txtimeout);
 
   /* Put the EMAC is its reset, non-operational state.  This should be
    * a known configuration that will guarantee the emac_ifup() always
@@ -639,7 +646,8 @@ static int emac_ifdown(struct net_driver_s *dev)
 
 static int emac_txavail(struct net_driver_s *dev)
 {
-  FAR struct emac_driver_s *priv = (FAR struct emac_driver_s *)dev->d_private;
+  FAR struct emac_driver_s *priv =
+    (FAR struct emac_driver_s *)dev->d_private;
   irqstate_t flags;
 
   /* Disable interrupts because this function may be called from interrupt
@@ -652,7 +660,7 @@ static int emac_txavail(struct net_driver_s *dev)
 
   if (priv->d_bifup)
     {
-      /* Check if there is room in the hardware to hold another outgoing packet. */
+      /* Check if there is room in the hardware to hold another packet. */
 
       /* If so, then poll the network for new XMIT data */
 
@@ -684,7 +692,8 @@ static int emac_txavail(struct net_driver_s *dev)
 #ifdef CONFIG_NET_MCASTGROUP
 static int emac_addmac(struct net_driver_s *dev, FAR const uint8_t *mac)
 {
-  FAR struct emac_driver_s *priv = (FAR struct emac_driver_s *)dev->d_private;
+  FAR struct emac_driver_s *priv =
+    (FAR struct emac_driver_s *)dev->d_private;
 
   /* Add the MAC address to the hardware multicast routing table */
 
@@ -696,8 +705,8 @@ static int emac_addmac(struct net_driver_s *dev, FAR const uint8_t *mac)
  * Function: emac_rmmac
  *
  * Description:
- *   NuttX Callback: Remove the specified MAC address from the hardware multicast
- *   address filtering
+ *   NuttX Callback: Remove the specified MAC address from the hardware
+ *   multicast address filtering
  *
  * Input Parameters:
  *   dev  - Reference to the NuttX driver state structure
@@ -713,7 +722,8 @@ static int emac_addmac(struct net_driver_s *dev, FAR const uint8_t *mac)
 #ifdef CONFIG_NET_MCASTGROUP
 static int emac_rmmac(struct net_driver_s *dev, FAR const uint8_t *mac)
 {
-  FAR struct emac_driver_s *priv = (FAR struct emac_driver_s *)dev->d_private;
+  FAR struct emac_driver_s *priv =
+    (FAR struct emac_driver_s *)dev->d_private;
 
   /* Add the MAC address to the hardware multicast routing table */
 
@@ -751,7 +761,7 @@ int emac_initialize(int intf)
   DEBUGASSERT(inf <  CONFIG_HCS12_NINTERFACES);
   priv = &g_emac[intf];
 
-   /* Check if a Ethernet chip is recognized at its I/O base */
+  /* Check if a Ethernet chip is recognized at its I/O base */
 
   /* Attach the IRQ to the driver */
 
@@ -775,16 +785,13 @@ int emac_initialize(int intf)
 #endif
   priv->d_dev.d_private = priv;          /* Used to recover private state from dev */
 
-  /* Create a watchdog for timing polling for and timing of transmissions */
-
-  priv->d_txpoll       = wd_create();    /* Create periodic poll timer */
-  priv->d_txtimeout    = wd_create();    /* Create TX timeout timer */
-
   /* Put the interface in the down state.  This usually amounts to resetting
    * the device and/or calling emac_ifdown().
    */
 
-  /* Read the MAC address from the hardware into priv->d_dev.d_mac.ether.ether_addr_octet */
+  /* Read the MAC address from the hardware into
+   * priv->d_dev.d_mac.ether.ether_addr_octet
+   */
 
   /* Register the device with the OS so that socket IOCTLs can be performed */
 
