@@ -37,13 +37,13 @@
 #include <nuttx/arch.h>
 #include <nuttx/serial/serial.h>
 #include "rx65n_macrodriver.h"
-#include "rx65n/iodefine.h"
+#include "arch/rx65n/iodefine.h"
 #include "chip.h"
 #include "up_arch.h"
 #include "up_internal.h"
 #include "rx65n_definitions.h"
 #include "rx65n_sci.h"
-#include "rx65n/irq.h"
+#include "arch/rx65n/irq.h"
 
 /****************************************************************************
  * Pre-processor Definitions
