@@ -170,16 +170,17 @@
 #  define PIC_OCW3_PCMD_MASK     (3 << PIC_OCW3_PCMD_SHIFT)
 #    define PIC_OCW3_PCMD_IRR    (2 << PIC_OCW3_PCMD_SHIFT) /* Next Read Returns Interrupt Request Register */
 #    define PIC_OCW3_PCMD_ISR    (3 << PIC_OCW3_PCMD_SHIFT) /* Next Read Returns In-Service Register */
-#  define PIC_OCW3_POLLCMD       (1 << 2) /* Poll command */
-#  define PIC_OCW3_ONE           (1 << 3) /* Must be set to 1 */
+#  define PIC_OCW3_POLLCMD       (1 << 2)                   /* Poll command */
+#  define PIC_OCW3_ONE           (1 << 3)                   /* Must be set to 1 */
 #  define PIC_OCW3_SM_SHIFT      (5)
 #  define PIC_OCW3_SM_MASK       (3 << PIC_OCW3_SM_SHIFT)
 #    define PIC_OCW3_RSM         (2 << PIC_OCW3_SM_SHIFT) /* Reset Special Mask */
 #    define PIC_OCW3_SSM         (3 << PIC_OCW3_SM_SHIFT) /* Set Special Mask */
 
-/* If the PIC has been reset, it must be initialized with 2 to 4 Initialization
- * Command Words (ICW) before it will accept and process Interrupt Requests. The
- * following outlines the four possible Initialization Command Words.
+/* If the PIC has been reset, it must be initialized with 2 to 4
+ * Initialization Command Words (ICW) before it will accept and process
+ * Interrupt Requests. The following outlines the four possible
+ * Initialization Command Words.
  */
 
 #define PIC1_ICW1                0x20
@@ -243,8 +244,8 @@
 #    define PIC_ICW4_BMODE_NON   (0 << PIC_ICW4_BMODE_SHIFT) /* Non - Buffered Mode */
 #    define PIC_ICW4_BMODE_SLAVE (2 << PIC_ICW4_BMODE_SHIFT) /* Buffered Mode - Slave */
 #    define PIC_ICW4_BMODE_MSTR  (3 << PIC_ICW4_BMODE_SHIFT) /* Buffered Mode - Master */
-#  define PIC_ICW4_AEOI          (1 << 1) /* Auto EOI  */
-#  define PIC_ICW4_808xMODE      (1 << 0) /* 8086/8080 Mode (vs MCS-80/85) */
+#  define PIC_ICW4_AEOI          (1 << 1)                    /* Auto EOI  */
+#  define PIC_ICW4_808xMODE      (1 << 0)                    /* 8086/8080 Mode (vs MCS-80/85) */
 
 /* Interrupt Mask Register */
 
@@ -340,7 +341,7 @@ begin_packed_struct struct gdt_ptr_s
 /* IDT data structures ******************************************************
  *
  * The Interrupt Descriptor Table (IDT) is a data structure used by the x86
- * architecture to implement an interrupt vector table. The IDT is used by the
+ * architecture to implement an interrupt vector table. IDT is used by the
  * processor to determine the correct response to interrupts and exceptions.
  */
 
@@ -371,7 +372,7 @@ begin_packed_struct struct idt_ptr_s
 
 /* Return stack pointer */
 
-static inline uint32_t up_getsp()
+static inline uint32_t x86_getsp()
 {
   uint32_t regval;
 
