@@ -1,4 +1,4 @@
-/***************************************************************************
+/****************************************************************************
  * boards/arm/cxd56xx/drivers/audio/cxd56_audio.c
  *
  *   Copyright 2018 Sony Semiconductor Solutions Corporation
@@ -33,7 +33,7 @@
  *
  ****************************************************************************/
 
-/***************************************************************************
+/****************************************************************************
  * Included Files
  ****************************************************************************/
 
@@ -59,14 +59,14 @@
 #include "cxd56_audio_ac_reg.h"
 #include "cxd56_audio_bca_reg.h"
 
-/***************************************************************************
+/****************************************************************************
  * Pre-processor Definitions
  ****************************************************************************/
 
 #define AUDIO_DNC_ID_NUM      (CXD56_AUDIO_DNC_ID_FF + 1)
 #define AUDIO_VOL_ID_NUM      (CXD56_AUDIO_VOLID_MIXER_OUT + 1)
 
-/***************************************************************************
+/****************************************************************************
  * Private Types
  ****************************************************************************/
 
@@ -141,7 +141,7 @@ struct power_on_param_s
   struct data_path_s          path;
 };
 
-/***************************************************************************
+/****************************************************************************
  * Private Data
  ****************************************************************************/
 
@@ -219,11 +219,11 @@ static struct power_on_param_s g_pwon_param =
     }
 };
 
-/***************************************************************************
+/****************************************************************************
  * Public Data
  ****************************************************************************/
 
-/***************************************************************************
+/****************************************************************************
  * Public Functions
  ****************************************************************************/
 
@@ -760,7 +760,8 @@ CXD56_AUDIO_ECODE cxd56_audio_unmute_vol(cxd56_audio_volid_t id)
   return ret;
 }
 
-CXD56_AUDIO_ECODE cxd56_audio_mute_vol_fade(cxd56_audio_volid_t id, bool wait)
+CXD56_AUDIO_ECODE cxd56_audio_mute_vol_fade(cxd56_audio_volid_t id,
+                                            bool wait)
 {
   CXD56_AUDIO_ECODE ret = CXD56_AUDIO_ECODE_OK;
 
@@ -1041,8 +1042,9 @@ CXD56_AUDIO_ECODE cxd56_audio_set_dmacb(cxd56_audio_dma_t handle,
   return ret;
 }
 
-CXD56_AUDIO_ECODE cxd56_audio_get_dmamstate(cxd56_audio_dma_t handle,
-                                            FAR cxd56_audio_dma_mstate_t *state)
+CXD56_AUDIO_ECODE
+cxd56_audio_get_dmamstate(cxd56_audio_dma_t handle,
+                          FAR cxd56_audio_dma_mstate_t *state)
 {
   CXD56_AUDIO_ECODE ret = CXD56_AUDIO_ECODE_OK;
 
