@@ -649,7 +649,7 @@ bool cxd56_audio_bca_reg_is_dma_fifo_empty(cxd56_audio_dma_t handle)
         break;
 
       default:
-        reg_id = BCA_I2S2_OUT_RTF_TRG;
+        reg_id = BCA_I2S2_OUT_RTD_TRG;
         break;
     }
 
@@ -878,7 +878,7 @@ void cxd56_audio_bca_reg_set_sample_no(cxd56_audio_dma_t handle,
         break;
 
       case CXD56_AUDIO_DMAC_I2S0_DOWN:
-        reg_id = BCA_I2S2_OUT_SAMPLE_NO;
+        reg_id = BCA_I2S1_OUT_SAMPLE_NO;
         break;
 
       default:
@@ -902,11 +902,11 @@ void cxd56_audio_bca_reg_start_dma(cxd56_audio_dma_t handle,
         break;
 
       case CXD56_AUDIO_DMAC_I2S0_DOWN:
-        reg_id = BCA_I2S1_OUT_RTF_TRG;
+        reg_id = BCA_I2S1_OUT_RTD_TRG;
         break;
 
       default:
-        reg_id = BCA_I2S2_OUT_RTF_TRG;
+        reg_id = BCA_I2S2_OUT_RTD_TRG;
         break;
     }
 
@@ -924,11 +924,11 @@ void cxd56_audio_bca_reg_stop_dma(cxd56_audio_dma_t handle)
         break;
 
       case CXD56_AUDIO_DMAC_I2S0_DOWN:
-        reg_id = BCA_I2S1_OUT_RTF_TRG;
+        reg_id = BCA_I2S1_OUT_RTD_TRG;
         break;
 
       default:
-        reg_id = BCA_I2S2_OUT_RTF_TRG;
+        reg_id = BCA_I2S2_OUT_RTD_TRG;
         break;
     }
 
@@ -1152,11 +1152,11 @@ uint32_t cxd56_audio_bca_reg_get_dma_state(cxd56_audio_dma_t handle)
         break;
 
       case CXD56_AUDIO_DMAC_I2S0_DOWN:
-        reg_id = BCA_I2S1_OUT_RTF_TRG;
+        reg_id = BCA_I2S1_OUT_RTD_TRG;
         break;
 
       default:
-        reg_id = BCA_I2S2_OUT_RTF_TRG;
+        reg_id = BCA_I2S2_OUT_RTD_TRG;
         break;
     }
 
