@@ -329,7 +329,7 @@ struct sam_dev_s
   /* Allocated DMA channel */
 
   DMA_HANDLE dmach;
-  WDOG_ID dmadog;         /* For DMA timeout detection */
+  struct wdog_s dmadog;   /* For DMA timeout detection */
   volatile int result;    /* Result of the DMA transfer */
   sem_t waitsem;          /* Used to way for DMA completion */
   volatile bool dmabusy;  /* True: DMA is in progress */
@@ -382,7 +382,7 @@ static void sam_lcd_dump(struct sam_dev_s *priv);
 #endif
 
 static void sam_lcd_endwait(struct sam_dev_s *priv, int result);
-static void sam_lcd_dmatimeout(int argc, uint32_t arg, ...);
+static void sam_lcd_dmatimeout(wdparm_t arg);
 static int  sam_lcd_dmawait(FAR struct sam_dev_s *priv, uint32_t timeout);
 static void sam_lcd_dmacallback(DMA_HANDLE handle, void *arg, int result);
 static int  sam_lcd_txtransfer(FAR struct sam_dev_s *priv,
@@ -914,7 +914,7 @@ static void sam_lcd_endwait(struct sam_dev_s *priv, int result)
 {
   /* Save the result and cancel the watchdog timeout */
 
-  wd_cancel(priv->dmadog);
+  wd_cancel(&priv->dmadog);
   priv->result = result;
 
   /* Wake up the waiting thread */
@@ -930,8 +930,7 @@ static void sam_lcd_endwait(struct sam_dev_s *priv, int result)
  *   timeout failure.
  *
  * Input Parameters:
- *   argc   - The number of arguments (should be 1)
- *   arg    - The argument (state structure reference cast to uint32_t)
+ *   arg    - The argument
  *
  * Returned Value:
  *   None
@@ -941,12 +940,12 @@ static void sam_lcd_endwait(struct sam_dev_s *priv, int result)
  *
  ****************************************************************************/
 
-static void sam_lcd_dmatimeout(int argc, uint32_t arg, ...)
+static void sam_lcd_dmatimeout(wdparm_t arg)
 {
   struct sam_dev_s *priv = (struct sam_dev_s *)arg;
 
-  DEBUGASSERT(argc == 1 && priv != NULL);
-  sam_lcd_sample((struct sam_dev_s *)arg, SAMPLENDX_TIMEOUT);
+  DEBUGASSERT(priv != NULL);
+  sam_lcd_sample(priv, SAMPLENDX_TIMEOUT);
 
   /* Make sure that any hung DMA is stopped.  dmabusy == false is the cue
    * so the DMA callback is ignored.
@@ -983,8 +982,8 @@ static int sam_lcd_dmawait(FAR struct sam_dev_s *priv, uint32_t timeout)
 
   /* Started ... setup the timeout */
 
-  ret = wd_start(priv->dmadog, timeout, sam_lcd_dmatimeout,
-                 1, (uint32_t)priv);
+  ret = wd_start(&priv->dmadog, timeout,
+                 sam_lcd_dmatimeout, (wdparm_t)priv);
   if (ret < 0)
     {
       lcderr("ERROR: wd_start failed: %d\n", errno);
@@ -1582,16 +1581,6 @@ int board_lcd_initialize(void)
       goto errout_with_waitsem;
     }
 
-  /* Allocate a watchdog timer to catch DMA timeouts */
-
-  priv->dmadog = wd_create();
-  if (!priv->dmadog)
-    {
-      lcderr("ERROR: Failed to allocate a timer\n");
-      ret = -EAGAIN;
-      goto errout_with_dmach;
-    }
-
   /* Identify and configure the LCD */
 
   up_mdelay(50);
@@ -1599,7 +1588,7 @@ int board_lcd_initialize(void)
   if (ret < 0)
     {
       lcderr("ERROR: sam_lcd_initialize failed: %d\n", ret);
-      goto errout_with_dmadog;
+      goto errout_with_dmach;
     }
 
   /* Clear the display (setting it to the color 0=black) */
@@ -1612,15 +1601,11 @@ int board_lcd_initialize(void)
   if (ret < 0)
     {
       lcderr("ERROR: sam_poweroff failed: %d\n", ret);
-      goto errout_with_dmadog;
+      goto errout_with_dmach;
     }
 
   return OK;
 
-errout_with_dmadog:
-  wd_delete(priv->dmadog);
-  priv->dmadog = NULL;
-
 errout_with_dmach:
   sam_dmafree(priv->dmach);
   priv->dmach = NULL;
@@ -1667,9 +1652,7 @@ void board_lcd_uninitialize(void)
 
   /* Free other resources */
 
-  wd_delete(priv->dmadog);
-  priv->dmadog = NULL;
-
+  wd_cancel(&priv->dmadog);
   nxsem_destroy(&priv->waitsem);
 
   /* Put the LCD in the lowest possible power state */
