@@ -43,10 +43,101 @@
 #  include "rx65n_rtc.h"
 #endif
 
+#ifdef CONFIG_CDCACM
+#  include <nuttx/usb/cdcacm.h>
+#endif
+
+#ifdef HAVE_DTC_DRIVER
+#  include "rx65n_dtc.h"
+#endif
+
+#ifdef HAVE_RSPI_DRIVER
+#  include <nuttx/spi/spi_transfer.h>
+#  include "rx65n_rspi.h"
+#endif
+
+#ifdef HAVE_RIIC_DRIVER
+#  include <nuttx/i2c/i2c_master.h>
+#  include "rx65n_riic.h"
+#endif
 /****************************************************************************
  * Public Functions
  ****************************************************************************/
 
+/****************************************************************************
+ * Name: rx65n_rspi_initialize
+ *
+ * Description:
+ *   Initialize and register the RSPI driver.
+ *
+ ****************************************************************************/
+#ifdef CONFIG_RX65N_RSPI
+static void rx65n_rspi_initialize(void)
+{
+  int ret;
+#ifdef CONFIG_RX65N_RSPI0
+  struct spi_dev_s *rspi0;
+#endif
+#ifdef CONFIG_RX65N_RSPI1
+  struct spi_dev_s *rspi1;
+#endif
+#ifdef CONFIG_RX65N_RSPI2
+  struct spi_dev_s *rspi2;
+#endif
+
+#ifdef CONFIG_RX65N_RSPI0
+  rspi0 = rx65n_rspibus_initialize(0);
+  if (!rspi0)
+    {
+      spierr("ERROR: [boot] FAILED to initialize SPI port 0\n");
+    }
+
+#ifdef CONFIG_SPI_DRIVER
+  ret = spi_register(rspi0, 0);
+  if (ret < 0)
+    {
+      spierr("ERROR: [boot] FAILED to register driver for channel 0\n");
+    }
+#endif
+
+#endif
+
+#ifdef CONFIG_RX65N_RSPI1
+  rspi1 = rx65n_rspibus_initialize(1);
+  if (!rspi1)
+    {
+      spierr("ERROR: [boot] FAILED to initialize SPI port 1\n");
+    }
+
+#ifdef CONFIG_SPI_DRIVER
+  ret = spi_register(rspi1, 1);
+  if (ret < 0)
+    {
+      spierr("ERROR: [boot] FAILED to register driver for channel 1\n");
+    }
+#endif
+
+#endif
+
+#ifdef CONFIG_RX65N_RSPI2
+  rspi2 = rx65n_rspibus_initialize(2);
+  if (!rspi2)
+    {
+      spierr("ERROR: [boot] FAILED to initialize SPI port 2\n");
+    }
+
+#ifdef CONFIG_SPI_DRIVER
+  ret = spi_register(rspi2, 2);
+  if (ret < 0)
+    {
+      spierr("ERROR: [boot] FAILED to register driver for channel 2\n");
+    }
+#endif
+
+#endif
+}
+#endif
+
 /****************************************************************************
  * Name: rtc_driver_initialize
  *
@@ -102,6 +193,7 @@ static int rtc_driver_initialize(void)
 
 int rx65n_bringup(void)
 {
+#if defined (HAVE_RTC_DRIVER) || defined (CONFIG_FS_PROCFS)
   int ret;
 #ifdef HAVE_RTC_DRIVER
   ret = rtc_driver_initialize();
@@ -124,11 +216,81 @@ int rx65n_bringup(void)
     }
 
 #endif
+#endif
 
 #ifdef CONFIG_RX65N_SBRAM
   /* Initialize standby RAM */
 
   (void)rx65n_sbram_int();
+#endif
+
+#ifdef HAVE_DTC_DRIVER
+  /* Initialize DTC */
+
+  (void)rx65n_dtc_initialize();
+#endif
+
+#ifdef CONFIG_RX65N_RSPI
+  (void)rx65n_rspi_initialize();
+#endif
+
+#if defined(CONFIG_CDCACM) && !defined(CONFIG_CDCACM_CONSOLE)
+  /* Initialize CDCACM */
+
+  syslog(LOG_INFO, "Initialize CDCACM device\n");
+
+  ret = cdcacm_initialize(0, NULL);
+  if (ret < 0)
+    {
+      syslog(LOG_ERR, "ERROR: cdcacm_initialize failed: %d\n", ret);
+    }
+#endif /* CONFIG_CDCACM & !CONFIG_CDCACM_CONSOLE */
+
+#ifdef HAVE_RIIC_DRIVER
+  FAR struct i2c_master_s *i2c;
+
+  /* Get the I2C lower half instance */
+
+#ifdef CONFIG_RX65N_RIIC0
+  i2c = rx65n_i2cbus_initialize(0);
+  if (i2c == NULL)
+    {
+      i2cerr("ERROR: Initialization of RIIC Channel 0 failed: %d\n", ret);
+    }
+  else
+    {
+      /* Register the I2C character driver */
+
+      ret = i2c_register(i2c, 0);
+      if (ret < 0)
+        {
+          i2cerr("ERROR: Failed to register RIIC device: %d\n", ret);
+        }
+    }
+
+#endif
+#ifdef CONFIG_RX65N_RIIC1
+  i2c = rx65n_i2cbus_initialize(1);
+  if (i2c == NULL)
+    {
+      i2cerr("ERROR: Initialization of RIIC Channel 1 failed: %d\n", ret);
+    }
+  else
+    {
+      /* Register the I2C character driver */
+
+      ret = i2c_register(i2c, 1);
+      if (ret < 0)
+        {
+          i2cerr("ERROR: Failed to register RIIC device: %d\n", ret);
+        }
+    }
+
+#endif
+#ifdef CONFIG_RX65N_RIIC2
+  i2cerr("RIIC2 setting is not supported on RSK-2MB Board\n");
+  i2cerr("It is used for USB port and cannot be configured\n");
+#endif
 #endif
   return OK;
 }
