@@ -119,7 +119,7 @@
 #define CXD56_ACA_OSC_49_152MHZ       3  /* 49.152MHz */
 #define CXD56_ACA_OSC_49_152MHZ_HIRES 4  /* 49.152MHz, Hi-Res */
 
-/* Control IDs for external as_aca_control */
+/* Control IDs for external fw_as_acacontrol */
 #define CXD56_ACA_CTL_CHECK_ID          0
 #define CXD56_ACA_CTL_POWER_ON_COMMON   1
 #define CXD56_ACA_CTL_POWER_ON_INPUT    2
@@ -193,7 +193,7 @@ extern bool cxd56_audio_clock_is_enabled(void);
 
 /* Located in arch/arm/src/cxd56xx/cxd56_farapistub.S */
 
-extern uint32_t as_aca_control(uint8_t type, uint32_t param);
+extern uint32_t fw_as_acacontrol(uint8_t type, uint32_t param);
 
 /****************************************************************************
  * Private Types
@@ -1381,7 +1381,9 @@ static void cxd56_dma_int_handler(void)
           FAR struct ap_buffer_s *apb;
 
           apb = (struct ap_buffer_s *) dq_get(&dev->runningq);
+          spin_unlock_irqrestore(flags);
           dev->dev.upper(dev->dev.priv, AUDIO_CALLBACK_DEQUEUE, apb, OK);
+          flags = spin_lock_irqsave();
         }
 
       spin_unlock_irqrestore(flags);
@@ -1392,6 +1394,8 @@ static void cxd56_dma_int_handler(void)
 
           if (dev->state != CXD56_DEV_STATE_PAUSED)
             {
+              audinfo("DMA_TRANS pendingq=%d \n",
+                     dq_count(&dev->pendingq));
               msg.msg_id = AUDIO_MSG_STOP;
               msg.u.data = 0;
               ret = nxmq_send(dev->mq, (FAR const char *)&msg,
@@ -1511,7 +1515,7 @@ static int cxd56_set_volume(enum cxd56_vol_id_e id, int16_t vol)
     {
       /* Disable analog out */
 
-      ret = as_aca_control(CXD56_ACA_CTL_SET_OUTPUT_DEVICE,
+      ret = fw_as_acacontrol(CXD56_ACA_CTL_SET_OUTPUT_DEVICE,
                            (uint32_t)CXD56_OUT_DEV_OFF);
       if (ret != CXD56_AUDIO_ECODE_OK)
         {
@@ -1523,7 +1527,7 @@ static int cxd56_set_volume(enum cxd56_vol_id_e id, int16_t vol)
     {
       /* Enable analog out */
 
-      ret = as_aca_control(CXD56_ACA_CTL_SET_OUTPUT_DEVICE,
+      ret = fw_as_acacontrol(CXD56_ACA_CTL_SET_OUTPUT_DEVICE,
                            (uint32_t)CXD56_OUT_DEV_SP);
       if (ret != CXD56_AUDIO_ECODE_OK)
         {
@@ -1711,7 +1715,7 @@ static int cxd56_power_on_aca(uint32_t samplerate)
   uint8_t mic_sel;
   uint8_t i;
 
-  if (as_aca_control(CXD56_ACA_CTL_CHECK_ID, (uint32_t)NULL) != 0)
+  if (fw_as_acacontrol(CXD56_ACA_CTL_CHECK_ID, (uint32_t)NULL) != 0)
     {
       return -ENXIO;
     }
@@ -1735,7 +1739,7 @@ static int cxd56_power_on_aca(uint32_t samplerate)
   pwon_param.mclk_ds = CXD56_MCLKOUT_DS;
   pwon_param.gpo_ds = CXD56_GPO_A_DS;
 
-  if (as_aca_control(CXD56_ACA_CTL_POWER_ON_COMMON,
+  if (fw_as_acacontrol(CXD56_ACA_CTL_POWER_ON_COMMON,
                     (uint32_t)&pwon_param) != 0)
     {
       return -EBUSY;
@@ -1763,7 +1767,7 @@ static int cxd56_power_on_aca(uint32_t samplerate)
       ser_param.sel_ch.in[i] = (enum cxd56_pulco_ser_sel_ch_id_e)mic_sel;
     }
 
-  if (as_aca_control(CXD56_ACA_CTL_SET_SERDES, (uint32_t)&ser_param) != 0)
+  if (fw_as_acacontrol(CXD56_ACA_CTL_SET_SERDES, (uint32_t)&ser_param) != 0)
     {
       return -EBUSY;
     }
@@ -1802,13 +1806,13 @@ static int cxd56_power_on_analog_output(FAR struct cxd56_dev_s *dev)
   pwon_param.sp_spliton  = CXD56_SP_SPLIT_ON;
   pwon_param.sp_drv      = CXD56_SP_DRIVER;
 
-  if (as_aca_control(CXD56_ACA_CTL_SET_SMASTER,
+  if (fw_as_acacontrol(CXD56_ACA_CTL_SET_SMASTER,
                     (uint32_t)&smaster_param) != 0)
     {
       return -EBUSY;
     }
 
-  if (as_aca_control(CXD56_ACA_CTL_POWER_ON_OUTPUT,
+  if (fw_as_acacontrol(CXD56_ACA_CTL_POWER_ON_OUTPUT,
                     (uint32_t)&pwon_param) != 0)
     {
       return -EBUSY;
@@ -1939,7 +1943,7 @@ static int cxd56_power_on_micbias(FAR struct cxd56_dev_s *dev)
 {
   struct timespec start;
 
-  if (as_aca_control(CXD56_ACA_CTL_POWER_ON_MICBIAS, (uint32_t)NULL) != 0)
+  if (fw_as_acacontrol(CXD56_ACA_CTL_POWER_ON_MICBIAS, (uint32_t)NULL) != 0)
     {
       return -EBUSY;
     }
@@ -2207,7 +2211,7 @@ static int cxd56_power_on_input(FAR struct cxd56_dev_s *dev)
 
   cxd56_set_mic_gains(120, &param);
 
-  if (as_aca_control(CXD56_ACA_CTL_POWER_ON_INPUT,
+  if (fw_as_acacontrol(CXD56_ACA_CTL_POWER_ON_INPUT,
                      (uint32_t)&param) != 0)
     {
       return -EBUSY;
@@ -2423,7 +2427,7 @@ static int cxd56_power_off(FAR struct cxd56_dev_s *dev)
 
   cxd56_audio_clock_disable();
 
-  if (as_aca_control(CXD56_ACA_CTL_POWER_OFF_COMMON, (uint32_t)NULL) != 0)
+  if (fw_as_acacontrol(CXD56_ACA_CTL_POWER_OFF_COMMON, (uint32_t)NULL) != 0)
     {
       return -EBUSY;
     }
@@ -2857,7 +2861,7 @@ static int cxd56_stop_dma(FAR struct cxd56_dev_s *priv)
 
           /* Disable input */
 
-          if (as_aca_control(CXD56_ACA_CTL_POWER_OFF_INPUT,
+          if (fw_as_acacontrol(CXD56_ACA_CTL_POWER_OFF_INPUT,
                              (uint32_t)NULL) != 0)
             {
               return -EBUSY;
@@ -2881,7 +2885,7 @@ static int cxd56_stop_dma(FAR struct cxd56_dev_s *priv)
           write_reg(REG_AC_NSPMUTE, 1);
           write_reg(REG_AC_PDN_SMSTR, 1);
 
-          if (as_aca_control(CXD56_ACA_CTL_POWER_OFF_OUTPUT,
+          if (fw_as_acacontrol(CXD56_ACA_CTL_POWER_OFF_OUTPUT,
                                (uint32_t)NULL) != 0)
             {
               return -EBUSY;
@@ -2899,32 +2903,28 @@ static int cxd56_stop(FAR struct audio_lowerhalf_s *lower, FAR void *session)
 static int cxd56_stop(FAR struct audio_lowerhalf_s *lower)
 #endif
 {
+  int ret;
+  FAR void *value;
+  struct audio_msg_s msg;
   FAR struct cxd56_dev_s *priv = (FAR struct cxd56_dev_s *)lower;
 
   audinfo("cxd56_stop\n");
 
-  if (priv->state != CXD56_DEV_STATE_STOPPED)
+  msg.msg_id = AUDIO_MSG_STOP;
+  msg.u.data = 0;
+  ret = nxmq_send(priv->mq, (FAR const char *)&msg,
+                  sizeof(msg), CONFIG_CXD56_MSG_PRIO);
+  if (ret != OK)
     {
-      int ret;
-      FAR void *value;
-      struct audio_msg_s msg;
-
-      msg.msg_id = AUDIO_MSG_STOP;
-      msg.u.data = 0;
-      ret = nxmq_send(priv->mq, (FAR const char *)&msg,
-                      sizeof(msg), CONFIG_CXD56_MSG_PRIO);
-      if (ret != OK)
-        {
-          auderr("ERROR: nxmq_send stop message failed (%d)\n", ret);
-          return ret;
-        }
-
-      /* Join the worker thread */
-
-      pthread_join(priv->threadid, &value);
-      priv->threadid = 0;
+      auderr("ERROR: nxmq_send stop message failed (%d)\n", ret);
+      return ret;
     }
 
+  /* Join the worker thread */
+
+  pthread_join(priv->threadid, &value);
+  priv->threadid = 0;
+
   return OK;
 }
 #endif /* CONFIG_AUDIO_EXCLUDE_STOP */
@@ -2982,10 +2982,22 @@ static int cxd56_resume(FAR struct audio_lowerhalf_s *lower)
   if (dev->state == CXD56_DEV_STATE_PAUSED ||
       dev->state == CXD56_DEV_STATE_BUFFERING)
     {
-      dev->state = CXD56_DEV_STATE_STARTED;
-      cxd56_power_on_analog_output(dev);
-      board_external_amp_mute_control(false);
+      if (dev->state == CXD56_DEV_STATE_PAUSED)
+        {
+          dev->state = CXD56_DEV_STATE_STARTED;
+          cxd56_power_on_analog_output(dev);
+          board_external_amp_mute_control(false);
+        }
+      else
+        {
+          /* NOTE: only power on the analog output
+           * when resumed from buffering
+           */
 
+          cxd56_power_on_analog_output(dev);
+        }
+
+      audinfo("START DMA pendingq=%d \n", dq_count(&dev->pendingq));
       ret = cxd56_start_dma(dev);
       if (ret != OK)
         {
@@ -3063,19 +3075,21 @@ static int cxd56_start_dma(FAR struct cxd56_dev_s *dev)
   flags = spin_lock_irqsave();
   if (dq_count(&dev->pendingq) == 0)
     {
-      /* Underrun occurred, send user message to start buffering */
+      /* Underrun occurred, stop DMA and change state for buffering */
 
       audwarn("Underrun \n");
-      struct audio_msg_s msg;
-      msg.msg_id = AUDIO_MSG_USER;
-      msg.u.data = 0;
-      ret = nxmq_send(dev->mq, (FAR const char *)&msg,
-                      sizeof(msg), CONFIG_CXD56_MSG_PRIO);
-      if (ret != OK)
+
+      spin_unlock_irqrestore(flags);
+      ret = cxd56_stop_dma(dev);
+      flags = spin_lock_irqsave();
+      audwarn("STOP DMA due to underrun \n");
+      if (ret != CXD56_AUDIO_ECODE_OK)
         {
-          auderr("ERROR: nxmq_send for buffering failed (%d)\n", ret);
-          goto exit;
+          auderr("ERROR: Could not stop DMA transfer (%d)\n", ret);
+          dev->running = false;
         }
+
+      dev->state = CXD56_DEV_STATE_BUFFERING;
     }
   else
     {
@@ -3118,7 +3132,9 @@ static int cxd56_start_dma(FAR struct cxd56_dev_s *dev)
             {
               /* Turn on amplifier */
 
+              spin_unlock_irqrestore(flags);
               board_external_amp_mute_control(false);
+              flags = spin_lock_irqsave();
 
               /* Mask interrupts */
 
@@ -3134,11 +3150,6 @@ static int cxd56_start_dma(FAR struct cxd56_dev_s *dev)
                   cxd56_int_clear(dev->dma_handle, CXD56_DMA_INT_ERR);
                   cxd56_int_clear(dev->dma_handle, CXD56_DMA_INT_SMP);
 
-                  /* Lock interrupt */
-
-                  up_irq_disable();
-                  sched_lock();
-
                   for (timeout = 0; timeout < CXD56_DMA_TIMEOUT; timeout++)
                     {
                       if (cxd56_int_has_smp(dev->dma_handle))
@@ -3161,11 +3172,6 @@ static int cxd56_start_dma(FAR struct cxd56_dev_s *dev)
 
                   cxd56_set_dma_running(dev->dma_handle, true);
 
-                  /* Unlock interrupt */
-
-                  sched_unlock();
-                  up_irq_enable();
-
                   /* Wait for 1sample tramsfer */
 
                   if (dev->samplerate > 48000)
@@ -3234,8 +3240,11 @@ static int cxd56_start_dma(FAR struct cxd56_dev_s *dev)
               struct audio_msg_s msg;
               msg.msg_id = AUDIO_MSG_STOP;
               msg.u.data = 0;
+
+              spin_unlock_irqrestore(flags);
               ret = nxmq_send(dev->mq, (FAR const char *)&msg,
                               sizeof(msg), CONFIG_CXD56_MSG_PRIO);
+              flags = spin_lock_irqsave();
 
               if (ret != OK)
                 {
@@ -3397,18 +3406,6 @@ static void *cxd56_workerthread(pthread_addr_t pvarg)
 
       switch (msg.msg_id)
         {
-          case AUDIO_MSG_USER:
-            ret = cxd56_stop_dma(priv);
-            if (ret != CXD56_AUDIO_ECODE_OK)
-              {
-                auderr("ERROR: Could not stop DMA transfer (%d)\n", ret);
-                priv->running = false;
-              }
-
-            priv->state = CXD56_DEV_STATE_BUFFERING;
-            audinfo("Workerthread paused for buffering.\n");
-            break;
-
           case AUDIO_MSG_STOP:
             ret = cxd56_stop_dma(priv);
             if (ret != CXD56_AUDIO_ECODE_OK)
