@@ -50,6 +50,7 @@
 #include <sys/types.h>
 #include <sys/ioctl.h>
 
+#include <math.h>
 #include <stdint.h>
 #include <stdio.h>
 #include <fcntl.h>
@@ -71,7 +72,6 @@
 #include <nuttx/audio/i2s.h>
 #include <nuttx/audio/audio.h>
 #include <nuttx/audio/wm8904.h>
-#include <nuttx/lib/math.h>
 
 #include "wm8904.h"
 
