@@ -187,7 +187,7 @@ static ssize_t gpio_read(FAR struct file *filep, FAR char *buffer,
 
   /* Read the GPIO value */
 
-  ret = dev->gp_ops->go_read(dev, (FAR uint8_t *)&buffer[0]);
+  ret = dev->gp_ops->go_read(dev, (FAR bool *)&buffer[0]);
   if (ret < 0)
     {
       return ret;
@@ -229,7 +229,8 @@ static ssize_t gpio_write(FAR struct file *filep, FAR const char *buffer,
 
   /* Check if this pin is write-able */
 
-  if (dev->gp_pintype != GPIO_OUTPUT_PIN)
+  if (dev->gp_pintype != GPIO_OUTPUT_PIN &&
+      dev->gp_pintype != GPIO_OUTPUT_PIN_OPENDRAIN)
     {
       return -EACCES;
     }
@@ -336,7 +337,8 @@ static int gpio_ioctl(FAR struct file *filep, int cmd, unsigned long arg)
        */
 
       case GPIOC_WRITE:
-        if (dev->gp_pintype == GPIO_OUTPUT_PIN)
+        if (dev->gp_pintype == GPIO_OUTPUT_PIN ||
+            dev->gp_pintype == GPIO_OUTPUT_PIN_OPENDRAIN)
           {
             DEBUGASSERT(arg == 0ul || arg == 1ul);
             ret = dev->gp_ops->go_write(dev, (bool)arg);
@@ -544,6 +546,8 @@ int gpio_pin_register(FAR struct gpio_dev_s *dev, int minor)
   switch (dev->gp_pintype)
     {
       case GPIO_INPUT_PIN:
+      case GPIO_INPUT_PIN_PULLUP:
+      case GPIO_INPUT_PIN_PULLDOWN:
         {
           DEBUGASSERT(dev->gp_ops->go_read != NULL);
           fmt = "/dev/gpin%u";
@@ -551,6 +555,7 @@ int gpio_pin_register(FAR struct gpio_dev_s *dev, int minor)
         break;
 
       case GPIO_OUTPUT_PIN:
+      case GPIO_OUTPUT_PIN_OPENDRAIN:
         {
           DEBUGASSERT(dev->gp_ops->go_read != NULL &&
                      dev->gp_ops->go_write != NULL);
@@ -606,12 +611,15 @@ void gpio_pin_unregister(FAR struct gpio_dev_s *dev, int minor)
   switch (dev->gp_pintype)
     {
       case GPIO_INPUT_PIN:
+      case GPIO_INPUT_PIN_PULLUP:
+      case GPIO_INPUT_PIN_PULLDOWN:
         {
           fmt = "/dev/gpin%u";
         }
         break;
 
       case GPIO_OUTPUT_PIN:
+      case GPIO_OUTPUT_PIN_OPENDRAIN:
         {
           fmt = "/dev/gpout%u";
         }
