@@ -116,7 +116,7 @@ static void tca64_register_update(FAR struct tca64_dev_s *priv);
 static void tca64_irqworker(void *arg);
 static void tca64_interrupt(FAR void *arg);
 #ifdef CONFIG_TCA64XX_INT_POLL
-static void tca64_poll_expiry(int argc, wdparm_t arg1, ...);
+static void tca64_poll_expiry(wdparm_t arg);
 #endif
 #endif
 
@@ -419,10 +419,14 @@ static int tca64_direction(FAR struct ioexpander_dev_s *dev, uint8_t pin,
   uint8_t regval;
   int ret;
 
+  if (direction != IOEXPANDER_DIRECTION_IN &&
+      direction != IOEXPANDER_DIRECTION_OUT)
+    {
+      return -EINVAL;
+    }
+
   DEBUGASSERT(priv != NULL && priv->config != NULL &&
-              pin < CONFIG_IOEXPANDER_NPINS &&
-              (direction == IOEXPANDER_DIRECTION_IN ||
-               direction == IOEXPANDER_DIRECTION_OUT));
+              pin < CONFIG_IOEXPANDER_NPINS);
 
   gpioinfo("I2C addr=%02x pin=%u direction=%s\n",
            priv->config->address, pin,
@@ -1257,8 +1261,8 @@ errout_with_restart:
   /* Re-start the poll timer */
 
   sched_lock();
-  ret = wd_start(priv->wdog, TCA64XX_POLLDELAY, tca64_poll_expiry,
-                 1, (wdparm_t)priv);
+  ret = wd_start(&priv->wdog, TCA64XX_POLLDELAY,
+                 tca64_poll_expiry, (wdparm_t)priv);
   if (ret < 0)
     {
       gpioerr("ERROR: Failed to start poll timer\n");
@@ -1306,7 +1310,7 @@ static void tca64_interrupt(FAR void *arg)
 #ifdef CONFIG_TCA64XX_INT_POLL
       /* Cancel the poll timer */
 
-      wd_cancel(priv->wdog);
+      wd_cancel(&priv->wdog);
 #endif
 
       /* Disable interrupts */
@@ -1335,12 +1339,11 @@ static void tca64_interrupt(FAR void *arg)
  ****************************************************************************/
 
 #if defined(CONFIG_TCA64XX_INT_ENABLE) && defined(CONFIG_TCA64XX_INT_POLL)
-static void tca64_poll_expiry(int argc, wdparm_t arg1, ...)
+static void tca64_poll_expiry(wdparm_t arg)
 {
   FAR struct tca64_dev_s *priv;
 
-  DEBUGASSERT(argc == 1);
-  priv = (FAR struct tca64_dev_s *)arg1;
+  priv = (FAR struct tca64_dev_s *)arg;
   DEBUGASSERT(priv != NULL && priv->config != NULL);
 
   /* Defer interrupt processing to the worker thread.  This is not only
@@ -1363,8 +1366,7 @@ static void tca64_poll_expiry(int argc, wdparm_t arg1, ...)
        * thread.
        */
 
-      work_queue(HPWORK, &priv->work, tca64_irqworker,
-                 (FAR void *)priv, 0);
+      work_queue(HPWORK, &priv->work, tca64_irqworker, priv, 0);
     }
 }
 #endif
@@ -1427,11 +1429,8 @@ FAR struct ioexpander_dev_s *tca64_initialize(FAR struct i2c_master_s *i2c,
 #ifdef CONFIG_TCA64XX_INT_POLL
   /* Set up a timer to poll for missed interrupts */
 
-  priv->wdog    = wd_create();
-  DEBUGASSERT(priv->wdog != NULL);
-
-  ret = wd_start(priv->wdog, TCA64XX_POLLDELAY, tca64_poll_expiry,
-                 1, (wdparm_t)priv);
+  ret = wd_start(&priv->wdog, TCA64XX_POLLDELAY,
+                 tca64_poll_expiry, (wdparm_t)priv);
   if (ret < 0)
     {
       gpioerr("ERROR: Failed to start poll timer\n");
