@@ -284,7 +284,9 @@
 #   define CONFIG_DM9X_MODE_AUTO 1
 #endif
 
-/* TX poll deley = 1 seconds. CLK_TCK is the number of clock ticks per second */
+/* TX poll deley = 1 seconds.
+ * CLK_TCK is the number of clock ticks per second
+ */
 
 #define DM9X_WDDELAY   (1*CLK_TCK)
 
@@ -292,7 +294,7 @@
 
 #define DM6X_TXTIMEOUT (60*CLK_TCK)
 
-/* This is a helper pointer for accessing the contents of the Ethernet header */
+/* This is a helper pointer for accessing the contents of Ethernet header */
 
 #define BUF ((struct eth_hdr_s *)priv->dm_dev.d_buf)
 
@@ -321,8 +323,8 @@ struct dm9x_driver_s
   bool dm_b100m;               /* true:speed == 100M; false:speed == 10M */
   uint8_t dm_ntxpending;       /* Count of packets pending transmission */
   uint8_t ncrxpackets;         /* Number of continuous rx packets  */
-  WDOG_ID dm_txpoll;           /* TX poll timer */
-  WDOG_ID dm_txtimeout;        /* TX timeout timer */
+  struct wdog_s dm_txpoll;     /* TX poll timer */
+  struct wdog_s dm_txtimeout;  /* TX timeout timer */
   struct work_s dm_irqwork;    /* For deferring interrupt work to the work queue */
   struct work_s dm_pollwork;   /* For deferring poll work to the work queue */
 
@@ -396,10 +398,10 @@ static int  dm9x_interrupt(int irq, FAR void *context, FAR void *arg);
 /* Watchdog timer expirations */
 
 static void dm9x_txtimeout_work(FAR void *arg);
-static void dm9x_txtimeout_expiry(int argc, uint32_t arg, ...);
+static void dm9x_txtimeout_expiry(wdparm_t arg);
 
 static void dm9x_poll_work(FAR void *arg);
-static void dm9x_poll_expiry(int argc, uint32_t arg, ...);
+static void dm9x_poll_expiry(wdparm_t arg);
 
 /* NuttX callback functions */
 
@@ -766,8 +768,8 @@ static int dm9x_transmit(FAR struct dm9x_driver_s *priv)
 
       /* Setup the TX timeout watchdog (perhaps restarting the timer) */
 
-      wd_start(priv->dm_txtimeout, DM6X_TXTIMEOUT,
-               dm9x_txtimeout_expiry, 1, (wdparm_t)priv);
+      wd_start(&priv->dm_txtimeout, DM6X_TXTIMEOUT,
+               dm9x_txtimeout_expiry, (wdparm_t)priv);
       return OK;
     }
 
@@ -798,7 +800,8 @@ static int dm9x_transmit(FAR struct dm9x_driver_s *priv)
 
 static int dm9x_txpoll(FAR struct net_driver_s *dev)
 {
-  FAR struct dm9x_driver_s *priv = (FAR struct dm9x_driver_s *)dev->d_private;
+  FAR struct dm9x_driver_s *priv =
+    (FAR struct dm9x_driver_s *)dev->d_private;
 
   /* If the polling resulted in data that should be sent out on the network,
    * the field d_len is set to a value > 0.
@@ -841,15 +844,15 @@ static int dm9x_txpoll(FAR struct net_driver_s *dev)
 
           if (priv->dm_ntxpending > 1 || !priv->dm_b100m)
             {
-              /* Returning a non-zero value will terminate the poll operation */
+              /* Returning a non-zero value terminate the poll operation */
 
               return 1;
             }
         }
     }
 
-  /* If zero is returned, the polling will continue until all connections have
-   * been examined.
+  /* If zero is returned, the polling will continue until all connections
+   * have been examined.
    */
 
   return 0;
@@ -920,7 +923,7 @@ static void dm9x_receive(FAR struct dm9x_driver_s *priv)
           priv->dm_discard(rx.desc.rx_len);
         }
 
-      /* Also check if the packet is a valid size for the network configuration */
+      /* Also check if the packet is a valid size for the configuration */
 
       else if (rx.desc.rx_len < ETH_HDRLEN ||
                rx.desc.rx_len > (CONFIG_NET_ETH_PKTSIZE + 2))
@@ -934,18 +937,20 @@ static void dm9x_receive(FAR struct dm9x_driver_s *priv)
         }
       else
         {
-          /* Good packet... Copy the packet data out of SRAM and pass it one to the network */
+          /* Good packet...
+           * Copy the packet data out of SRAM and pass it one to the network
+           */
 
           priv->dm_dev.d_len = rx.desc.rx_len;
           priv->dm_read(priv->dm_dev.d_buf, rx.desc.rx_len);
 
 #ifdef CONFIG_NET_PKT
-          /* When packet sockets are enabled, feed the frame into the packet tap */
+          /* When packet sockets are enabled, feed the frame into the tap */
 
           pkt_input(&priv->dm_dev);
 #endif
 
-          /* We only accept IP packets of the configured type and ARP packets */
+          /* We accept IP packets of the configured type and ARP packets */
 
 #ifdef CONFIG_NET_IPv4
           if (BUF->type == HTONS(ETHTYPE_IP))
@@ -960,14 +965,14 @@ static void dm9x_receive(FAR struct dm9x_driver_s *priv)
               arp_ipin(&priv->dm_dev);
               ipv4_input(&priv->dm_dev);
 
-              /* If the above function invocation resulted in data that should
-               * be sent out on the network, the field  d_len will set to a
-               * value > 0.
+              /* If the above function invocation resulted in data that
+               * should be sent out on the network, the field  d_len will
+               * set to a value > 0.
                */
 
               if (priv->dm_dev.d_len > 0)
                 {
-                  /* Update the Ethernet header with the correct MAC address */
+                  /* Update Ethernet header with the correct MAC address */
 
 #ifdef CONFIG_NET_IPv6
                   if (IFF_IS_IPv4(priv->dm_dev.d_flags))
@@ -999,14 +1004,14 @@ static void dm9x_receive(FAR struct dm9x_driver_s *priv)
 
               ipv6_input(&priv->dm_dev);
 
-              /* If the above function invocation resulted in data that should
-               * be sent out on the network, the field  d_len will set to a
-               * value > 0.
+              /* If the above function invocation resulted in data that
+               * should be sent out on the network, the field  d_len will
+               * set to a value > 0.
                */
 
               if (priv->dm_dev.d_len > 0)
                 {
-                  /* Update the Ethernet header with the correct MAC address */
+                  /* Update Ethernet header with the correct MAC address */
 
 #ifdef CONFIG_NET_IPv4
                   if (IFF_IS_IPv4(priv->dm_dev.d_flags))
@@ -1034,9 +1039,9 @@ static void dm9x_receive(FAR struct dm9x_driver_s *priv)
               arp_arpin(&priv->dm_dev);
               NETDEV_RXARP(&priv->dm_dev);
 
-              /* If the above function invocation resulted in data that should
-               * be sent out on the network, the field  d_len will set to a
-               * value > 0.
+              /* If the above function invocation resulted in data that
+               * should be sent out on the network, the field  d_len will set
+               * to a value > 0.
                */
 
               if (priv->dm_dev.d_len > 0)
@@ -1054,7 +1059,8 @@ static void dm9x_receive(FAR struct dm9x_driver_s *priv)
       NETDEV_RXPACKETS(&priv->dm_dev);
       priv->ncrxpackets++;
     }
-  while ((rxbyte & 0x01) == DM9X_PKTRDY && priv->ncrxpackets < DM9X_CRXTHRES);
+  while ((rxbyte & 0x01) == DM9X_PKTRDY &&
+         priv->ncrxpackets < DM9X_CRXTHRES);
   ninfo("All RX packets processed\n");
 }
 
@@ -1113,7 +1119,7 @@ static void dm9x_txdone(FAR struct dm9x_driver_s *priv)
 
   if (priv->dm_ntxpending == 0)
     {
-      wd_cancel(priv->dm_txtimeout);
+      wd_cancel(&priv->dm_txtimeout);
     }
 
   /* Then poll the network for new XMIT data */
@@ -1285,7 +1291,7 @@ static int dm9x_interrupt(int irq, FAR void *context, FAR void *arg)
        * expiration and the deferred interrupt processing.
        */
 
-       wd_cancel(priv->dm_txtimeout);
+       wd_cancel(&priv->dm_txtimeout);
     }
 
   /* Schedule to perform the interrupt processing on the worker thread. */
@@ -1346,8 +1352,7 @@ static void dm9x_txtimeout_work(FAR void *arg)
  *   The last TX never completed.  Reset the hardware and start again.
  *
  * Input Parameters:
- *   argc - The number of available arguments
- *   arg  - The first argument
+ *   arg  - The argument
  *
  * Returned Value:
  *   None
@@ -1357,7 +1362,7 @@ static void dm9x_txtimeout_work(FAR void *arg)
  *
  ****************************************************************************/
 
-static void dm9x_txtimeout_expiry(int argc, wdparm_t arg, ...)
+static void dm9x_txtimeout_expiry(wdparm_t arg)
 {
   FAR struct dm9x_driver_s *priv = (FAR struct dm9x_driver_s *)arg;
 
@@ -1414,15 +1419,15 @@ static void dm9x_poll_work(FAR void *arg)
 
   if (priv->dm_ntxpending < 1 || (priv->dm_b100m && priv->dm_ntxpending < 2))
     {
-      /* If so, update TCP timing states and poll the network for new XMIT data */
+      /* Update TCP timing states and poll the network for new XMIT data */
 
       devif_timer(&priv->dm_dev, DM9X_WDDELAY, dm9x_txpoll);
     }
 
   /* Setup the watchdog poll timer again */
 
-  wd_start(priv->dm_txpoll, DM9X_WDDELAY, dm9x_poll_expiry, 1,
-           (wdparm_t)priv);
+  wd_start(&priv->dm_txpoll, DM9X_WDDELAY,
+           dm9x_poll_expiry, (wdparm_t)priv);
   net_unlock();
 }
 
@@ -1433,8 +1438,7 @@ static void dm9x_poll_work(FAR void *arg)
  *   Periodic timer handler.  Called from the timer interrupt handler.
  *
  * Input Parameters:
- *   argc - The number of available arguments
- *   arg  - The first argument
+ *   arg  - The argument
  *
  * Returned Value:
  *   None
@@ -1444,7 +1448,7 @@ static void dm9x_poll_work(FAR void *arg)
  *
  ****************************************************************************/
 
-static void dm9x_poll_expiry(int argc, wdparm_t arg, ...)
+static void dm9x_poll_expiry(wdparm_t arg)
 {
   FAR struct dm9x_driver_s *priv = (FAR struct dm9x_driver_s *)arg;
 
@@ -1516,7 +1520,8 @@ static inline void dm9x_phymode(FAR struct dm9x_driver_s *priv)
 
 static int dm9x_ifup(FAR struct net_driver_s *dev)
 {
-  FAR struct dm9x_driver_s *priv = (FAR struct dm9x_driver_s *)dev->d_private;
+  FAR struct dm9x_driver_s *priv =
+    (FAR struct dm9x_driver_s *)dev->d_private;
   uint8_t netstatus;
   int i;
 
@@ -1556,8 +1561,8 @@ static int dm9x_ifup(FAR struct net_driver_s *dev)
 
   /* Set and activate a timer process */
 
-  wd_start(priv->dm_txpoll, DM9X_WDDELAY, dm9x_poll_expiry, 1,
-           (wdparm_t)priv);
+  wd_start(&priv->dm_txpoll, DM9X_WDDELAY,
+           dm9x_poll_expiry, (wdparm_t)priv);
 
   /* Enable the DM9X interrupt */
 
@@ -1584,7 +1589,8 @@ static int dm9x_ifup(FAR struct net_driver_s *dev)
 
 static int dm9x_ifdown(FAR struct net_driver_s *dev)
 {
-  FAR struct dm9x_driver_s *priv = (FAR struct dm9x_driver_s *)dev->d_private;
+  FAR struct dm9x_driver_s *priv =
+    (FAR struct dm9x_driver_s *)dev->d_private;
   irqstate_t flags;
 
   ninfo("Stopping\n");
@@ -1596,8 +1602,8 @@ static int dm9x_ifdown(FAR struct net_driver_s *dev)
 
   /* Cancel the TX poll timer and TX timeout timers */
 
-  wd_cancel(priv->dm_txpoll);
-  wd_cancel(priv->dm_txtimeout);
+  wd_cancel(&priv->dm_txpoll);
+  wd_cancel(&priv->dm_txtimeout);
 
   /* Reset the device */
 
@@ -1631,7 +1637,8 @@ static int dm9x_ifdown(FAR struct net_driver_s *dev)
 
 static void dm9x_txavail_work(FAR void *arg)
 {
-  FAR struct dm9x_driver_s *priv = (FAR struct dm9x_driver_s *)arg;
+  FAR struct dm9x_driver_s *priv =
+    (FAR struct dm9x_driver_s *)arg;
 
   ninfo("Polling\n");
 
@@ -1640,7 +1647,7 @@ static void dm9x_txavail_work(FAR void *arg)
   net_lock();
   if (priv->dm_bifup)
     {
-      /* Check if there is room in the DM90x0 to hold another packet.  In 100M
+      /* Check if there is room in the DM90x0 to hold another packet. In 100M
        * mode, that can be 2 packets, otherwise it is a single packet.
        */
 
@@ -1677,7 +1684,8 @@ static void dm9x_txavail_work(FAR void *arg)
 
 static int dm9x_txavail(FAR struct net_driver_s *dev)
 {
-  FAR struct dm9x_driver_s *priv = (FAR struct dm9x_driver_s *)dev->d_private;
+  FAR struct dm9x_driver_s *priv =
+    (FAR struct dm9x_driver_s *)dev->d_private;
 
   /* Is our single work structure available?  It may not be if there are
    * pending interrupt actions and we will have to ignore the Tx
@@ -1715,7 +1723,8 @@ static int dm9x_txavail(FAR struct net_driver_s *dev)
 #ifdef CONFIG_NET_MCASTGROUP
 static int dm9x_addmac(FAR struct net_driver_s *dev, FAR const uint8_t *mac)
 {
-  FAR struct dm9x_driver_s *priv = (FAR struct dm9x_driver_s *)dev->d_private;
+  FAR struct dm9x_driver_s *priv =
+    (FAR struct dm9x_driver_s *)dev->d_private;
 
   /* Add the MAC address to the hardware multicast routing table */
 
@@ -1745,7 +1754,8 @@ static int dm9x_addmac(FAR struct net_driver_s *dev, FAR const uint8_t *mac)
 #ifdef CONFIG_NET_MCASTGROUP
 static int dm9x_rmmac(FAR struct net_driver_s *dev, FAR const uint8_t *mac)
 {
-  FAR struct dm9x_driver_s *priv = (FAR struct dm9x_driver_s *)dev->d_private;
+  FAR struct dm9x_driver_s *priv =
+    (FAR struct dm9x_driver_s *)dev->d_private;
 
   /* Add the MAC address to the hardware multicast routing table */
 
@@ -1826,7 +1836,8 @@ static void dm9x_bringup(FAR struct dm9x_driver_s *priv)
   putreg(DM9X_TXC, 0x00);         /* Clear TX Polling */
   putreg(DM9X_BPTHRES, 0x3f);     /* Less 3kb, 600us */
   putreg(DM9X_SMODEC, 0x00);      /* Special mode */
-  putreg(DM9X_NETS, (DM9X_NETS_WAKEST | DM9X_NETS_TX1END | DM9X_NETS_TX2END)); /* Clear TX status */
+                                  /* Clear TX status */
+  putreg(DM9X_NETS, DM9X_NETS_WAKEST | DM9X_NETS_TX1END | DM9X_NETS_TX2END);
   putreg(DM9X_ISR, DM9X_INT_ALL); /* Clear interrupt status */
 
 #if defined(CONFIG_DM9X_CHECKSUM)
@@ -1874,8 +1885,8 @@ static void dm9x_reset(FAR struct dm9x_driver_s *priv)
 
   /* Cancel the TX poll timer and TX timeout timers */
 
-  wd_cancel(priv->dm_txpoll);
-  wd_cancel(priv->dm_txtimeout);
+  wd_cancel(&priv->dm_txpoll);
+  wd_cancel(&priv->dm_txtimeout);
 
   /* Save previous register address */
 
@@ -1947,7 +1958,7 @@ int dm9x_initialize(void)
   if (vid != DM9X_DAVICOMVID ||
       (pid != DM9X_DM9000PID && pid != DM9X_DM9010PID))
     {
-      nerr("ERROR: DM90x0 vendor/product ID not found at this base address\n");
+      nerr("ERROR: vendor/product ID not found at this base address\n");
       return -ENODEV;
     }
 
@@ -1972,12 +1983,7 @@ int dm9x_initialize(void)
   g_dm9x[0].dm_dev.d_addmac  = dm9x_addmac;   /* Add multicast MAC address */
   g_dm9x[0].dm_dev.d_rmmac   = dm9x_rmmac;    /* Remove multicast MAC address */
 #endif
-  g_dm9x[0].dm_dev.d_private = (FAR void *)g_dm9x; /* Used to recover private state from dev */
-
-  /* Create a watchdog for timing polling for and timing of transmissions */
-
-  g_dm9x[0].dm_txpoll       = wd_create();    /* Create periodic poll timer */
-  g_dm9x[0].dm_txtimeout    = wd_create();    /* Create TX timeout timer */
+  g_dm9x[0].dm_dev.d_private = g_dm9x;        /* Used to recover private state from dev */
 
   /* Read the MAC address */
 
