@@ -55,6 +55,13 @@
 #  error "Worker thread support is required (CONFIG_SCHED_WORKQUEUE)"
 #endif
 
+/****************************************************************************
+ * Private Function Prototypes
+ ****************************************************************************/
+
+static ssize_t rwb_read_(FAR struct rwbuffer_s *rwb, off_t startblock,
+                         size_t nblocks, FAR uint8_t *rdbuffer);
+
 /****************************************************************************
  * Private Functions
  ****************************************************************************/
@@ -134,9 +141,8 @@ static inline void rwb_resetwrbuffer(FAR struct rwbuffer_s *rwb)
 {
   /* We assume that the caller holds the wrsem */
 
-  rwb->wrnblocks       = 0;
-  rwb->wrblockstart    = (off_t)-1;
-  rwb->wrexpectedblock = (off_t)-1;
+  rwb->wrnblocks    = 0;
+  rwb->wrblockstart = -1;
 }
 #endif
 
@@ -155,8 +161,19 @@ static void rwb_wrflush(FAR struct rwbuffer_s *rwb)
 
   if (rwb->wrnblocks > 0)
     {
+      size_t padblocks;
+
       finfo("Flushing: blockstart=0x%08lx nblocks=%d from buffer=%p\n",
-      (long)rwb->wrblockstart, rwb->wrnblocks, rwb->wrbuffer);
+            (long)rwb->wrblockstart, rwb->wrnblocks, rwb->wrbuffer);
+
+      padblocks = rwb->wrnblocks % rwb->wralignblocks;
+      if (padblocks)
+        {
+          padblocks = rwb->wralignblocks - padblocks;
+          rwb_read_(rwb, rwb->wrblockstart + rwb->wrnblocks, padblocks,
+                    &rwb->wrbuffer[rwb->wrnblocks * rwb->blocksize]);
+          rwb->wrnblocks += padblocks;
+        }
 
       /* Flush cache.  On success, the flush method will return the number
        * of blocks written.  Anything other than the number requested is
@@ -240,56 +257,152 @@ static ssize_t rwb_writebuffer(FAR struct rwbuffer_s *rwb,
                                off_t startblock, uint32_t nblocks,
                                FAR const uint8_t *wrbuffer)
 {
-  int ret;
+  uint32_t nwritten = nblocks;
 
   /* Write writebuffer Logic */
 
   rwb_wrcanceltimeout(rwb);
 
-  /* First: Should we flush out our cache? We would do that if (1) we already
-   * buffering blocks and the next block writing is not in the same sequence,
-   * or (2) the number of blocks would exceed our allocated buffer capacity
-   */
+  /* Is data saved in the write buffer? */
 
-  if (((startblock != rwb->wrexpectedblock) && (rwb->wrnblocks)) ||
-      ((rwb->wrnblocks + nblocks) > rwb->wrmaxblocks))
+  if (rwb->wrnblocks > 0)
     {
-      finfo("writebuffer miss, expected: %08x, given: %08x\n",
-            rwb->wrexpectedblock, startblock);
+      off_t wrbend;
+      off_t newend;
 
-      /* Flush the write buffer */
+      /* Now there are five cases:
+       *
+       * 1. We update the non-overlapping region
+       */
 
-      ret = rwb->wrflush(rwb->dev, rwb->wrbuffer, rwb->wrblockstart,
-                         rwb->wrnblocks);
-      if (ret < 0)
+      wrbend = rwb->wrblockstart + rwb->wrnblocks;
+      newend = startblock + nblocks;
+
+      if (wrbend < startblock || rwb->wrblockstart > newend)
         {
-          ferr("ERROR: Error writing multiple from cache: %d\n", -ret);
-          return ret;
+          /* Nothing to do */;
         }
 
-      rwb_resetwrbuffer(rwb);
+      /* 2. We update the entire write buffer. */
+
+      else if (rwb->wrblockstart > startblock && wrbend < newend)
+        {
+          rwb->wrnblocks = 0;
+        }
+
+      /* We are going to update a subset of the write buffer.  Three
+       * more cases to consider:
+       *
+       * 3. We update a portion in the middle of the write buffer
+       */
+
+      else if (rwb->wrblockstart <= startblock && wrbend >= newend)
+        {
+          FAR uint8_t *dest;
+          size_t offset;
+
+          /* Copy the data to the middle of write buffer */
+
+          offset = startblock - rwb->wrblockstart;
+          dest   = rwb->wrbuffer + offset * rwb->blocksize;
+          memcpy(dest, wrbuffer, nblocks * rwb->blocksize);
+
+          nblocks = 0;
+        }
+
+      /* 4. We upate a portion at the end of the write buffer */
+
+      else if (wrbend >= startblock && wrbend <= newend)
+        {
+          FAR uint8_t *dest;
+          size_t offset;
+          size_t ncopy;
+
+          /* Copy the data from the updating region to the end
+           * of the write buffer.
+           */
+
+          offset = rwb->wrnblocks - (wrbend - startblock);
+          ncopy  = rwb->wrmaxblocks - offset;
+          if (ncopy > nblocks)
+            {
+              ncopy = nblocks;
+            }
+
+          dest = rwb->wrbuffer + offset * rwb->blocksize;
+          memcpy(dest, wrbuffer, ncopy * rwb->blocksize);
+
+          rwb->wrnblocks = offset + ncopy;
+          wrbuffer      += ncopy * rwb->blocksize;
+          startblock    += ncopy;
+          nblocks       -= ncopy;
+        }
+
+      /* 5. We update a portion at the beginning of the write buffer */
+
+      else /* if (rwb->wrblockstart >= startblock && wrbend >= newend) */
+        {
+          FAR uint8_t *dest;
+          FAR const uint8_t *src;
+          size_t ncopy;
+
+          DEBUGASSERT(rwb->wrblockstart >= startblock && wrbend >= newend);
+
+          /* Move the cached data to the end of the write buffer */
+
+          ncopy = rwb->wrblockstart - startblock;
+          if (ncopy > rwb->wrmaxblocks - rwb->wrnblocks)
+            {
+              ncopy = rwb->wrmaxblocks - rwb->wrnblocks;
+            }
+
+          dest = rwb->wrbuffer + ncopy * rwb->blocksize;
+          memmove(dest, rwb->wrbuffer, ncopy * rwb->blocksize);
+
+          rwb->wrblockstart -= ncopy;
+          rwb->wrnblocks    += ncopy;
+
+          /* Copy the data from the updating region to the beginning
+           * of the write buffer.
+           */
+
+          ncopy = newend - rwb->wrblockstart;
+          src   = wrbuffer + (nblocks - ncopy) * rwb->blocksize;
+          memcpy(rwb->wrbuffer, src, ncopy * rwb->blocksize);
+
+          nblocks -= ncopy;
+        }
     }
 
-  /* writebuffer is empty? Then initialize it */
+  /* Use the block cache unless the buffer size is bigger than block cache */
 
-  if (rwb->wrnblocks == 0)
+  if (nblocks > rwb->wrmaxblocks)
     {
-      finfo("Fresh cache starting at block: 0x%08x\n", startblock);
+      ssize_t ret = rwb->wrflush(rwb->dev, wrbuffer, startblock, nblocks);
+      if (ret < 0)
+        {
+          return ret;
+        }
+    }
+  else if (nblocks)
+    {
+      /* Flush the write buffer */
+
+      rwb_wrflush(rwb);
+
+      /* Buffer the data in the write buffer */
+
+      memcpy(rwb->wrbuffer, wrbuffer, nblocks * rwb->blocksize);
       rwb->wrblockstart = startblock;
+      rwb->wrnblocks    = nblocks;
     }
 
-  /* Add data to cache */
+  if (rwb->wrnblocks > 0)
+    {
+      rwb_wrstarttimeout(rwb);
+    }
 
-  finfo("writebuffer: copying %d bytes from %p to %p\n",
-        nblocks * rwb->blocksize, wrbuffer,
-        &rwb->wrbuffer[rwb->wrnblocks * rwb->blocksize]);
-  memcpy(&rwb->wrbuffer[rwb->wrnblocks * rwb->blocksize],
-         wrbuffer, nblocks * rwb->blocksize);
-
-  rwb->wrnblocks      += nblocks;
-  rwb->wrexpectedblock = rwb->wrblockstart + rwb->wrnblocks;
-  rwb_wrstarttimeout(rwb);
-  return nblocks;
+  return nwritten;
 }
 #endif
 
@@ -303,7 +416,7 @@ static inline void rwb_resetrhbuffer(FAR struct rwbuffer_s *rwb)
   /* We assume that the caller holds the readAheadBufferSemphore */
 
   rwb->rhnblocks    = 0;
-  rwb->rhblockstart = (off_t)-1;
+  rwb->rhblockstart = -1;
 }
 #endif
 
@@ -454,7 +567,7 @@ int rwb_invalidate_writebuffer(FAR struct rwbuffer_s *rwb,
       /* We are going to invalidate a subset of the write buffer.  Three
        * more cases to consider:
        *
-       * 2. We invalidate a portion in the middle of the write buffer
+       * 3. We invalidate a portion in the middle of the write buffer
        */
 
       else if (rwb->wrblockstart < startblock && wrbend > invend)
@@ -488,15 +601,15 @@ int rwb_invalidate_writebuffer(FAR struct rwbuffer_s *rwb,
             }
         }
 
-      /* 3. We invalidate a portion at the end of the write buffer */
+      /* 4. We invalidate a portion at the end of the write buffer */
 
       else if (wrbend > startblock && wrbend <= invend)
         {
-          rwb->wrnblocks = wrbend - startblock;
+          rwb->wrnblocks -= wrbend - startblock;
           ret = OK;
         }
 
-      /* 4. We invalidate a portion at the beginning of the write buffer */
+      /* 5. We invalidate a portion at the beginning of the write buffer */
 
       else /* if (rwb->wrblockstart >= startblock && wrbend > invend) */
         {
@@ -612,11 +725,11 @@ int rwb_invalidate_readahead(FAR struct rwbuffer_s *rwb,
 
       else if (rhbend > startblock && rhbend <= invend)
         {
-          rwb->rhnblocks = rhbend - startblock;
+          rwb->rhnblocks -= rhbend - startblock;
           ret = OK;
         }
 
-      /* 4. We invalidate a portion at the beginning of the write buffer */
+      /* 4. We invalidate a portion at the begin of the read-ahead buffer */
 
       else /* if (rwb->rhblockstart >= startblock && rhbend > invend) */
         {
@@ -697,6 +810,14 @@ int rwb_initialize(FAR struct rwbuffer_s *rwb)
     {
       finfo("Initialize the write buffer\n");
 
+      if (rwb->wralignblocks == 0)
+        {
+          rwb->wralignblocks = 1;
+        }
+
+      DEBUGASSERT(rwb->wralignblocks <= rwb->wrmaxblocks &&
+                  rwb->wrmaxblocks % rwb->wralignblocks == 0);
+
       /* Initialize the write buffer access semaphore */
 
       nxsem_init(&rwb->wrsem, 0, 1);
@@ -707,16 +828,12 @@ int rwb_initialize(FAR struct rwbuffer_s *rwb)
 
       /* Allocate the write buffer */
 
-      rwb->wrbuffer = NULL;
-      if (rwb->wrmaxblocks > 0)
+      allocsize     = rwb->wrmaxblocks * rwb->blocksize;
+      rwb->wrbuffer = kmm_malloc(allocsize);
+      if (!rwb->wrbuffer)
         {
-          allocsize     = rwb->wrmaxblocks * rwb->blocksize;
-          rwb->wrbuffer = kmm_malloc(allocsize);
-          if (!rwb->wrbuffer)
-            {
-              ferr("Write buffer kmm_malloc(%d) failed\n", allocsize);
-              return -ENOMEM;
-            }
+          ferr("Write buffer kmm_malloc(%d) failed\n", allocsize);
+          return -ENOMEM;
         }
 
       finfo("Write buffer size: %d bytes\n", allocsize);
@@ -738,16 +855,12 @@ int rwb_initialize(FAR struct rwbuffer_s *rwb)
 
       /* Allocate the read-ahead buffer */
 
-      rwb->rhbuffer = NULL;
-      if (rwb->rhmaxblocks > 0)
+      allocsize     = rwb->rhmaxblocks * rwb->blocksize;
+      rwb->rhbuffer = kmm_malloc(allocsize);
+      if (!rwb->rhbuffer)
         {
-          allocsize     = rwb->rhmaxblocks * rwb->blocksize;
-          rwb->rhbuffer = kmm_malloc(allocsize);
-          if (!rwb->rhbuffer)
-            {
-              ferr("Read-ahead buffer kmm_malloc(%d) failed\n", allocsize);
-              return -ENOMEM;
-            }
+          ferr("Read-ahead buffer kmm_malloc(%d) failed\n", allocsize);
+          return -ENOMEM;
         }
 
       finfo("Read-ahead buffer size: %d bytes\n", allocsize);
@@ -767,6 +880,7 @@ void rwb_uninitialize(FAR struct rwbuffer_s *rwb)
   if (rwb->wrmaxblocks > 0)
     {
       rwb_wrcanceltimeout(rwb);
+      rwb_wrflush(rwb);
       nxsem_destroy(&rwb->wrsem);
       if (rwb->wrbuffer)
         {
@@ -804,7 +918,7 @@ static ssize_t rwb_read_(FAR struct rwbuffer_s *rwb, off_t startblock,
       ret = nxsem_wait(&rwb->rhsem);
       if (ret < 0)
         {
-          return (ssize_t)ret;
+          return ret;
         }
 
       /* Loop until we have read all of the requested blocks */
@@ -849,7 +963,7 @@ static ssize_t rwb_read_(FAR struct rwbuffer_s *rwb, off_t startblock,
                        ret);
 
                   rwb_semgive(&rwb->rhsem);
-                  return (ssize_t)ret;
+                  return ret;
                 }
             }
         }
@@ -872,7 +986,7 @@ static ssize_t rwb_read_(FAR struct rwbuffer_s *rwb, off_t startblock,
       ret = rwb->rhreload(rwb->dev, rdbuffer, startblock, nblocks);
     }
 
-  return (ssize_t)ret;
+  return ret;
 }
 
 /****************************************************************************
@@ -898,7 +1012,7 @@ ssize_t rwb_read(FAR struct rwbuffer_s *rwb, off_t startblock,
       ret = nxsem_wait(&rwb->wrsem);
       if (ret < 0)
         {
-          return (ssize_t)ret;
+          return ret;
         }
 
       /* If the write buffer overlaps the block(s) requested */
@@ -916,7 +1030,7 @@ ssize_t rwb_read(FAR struct rwbuffer_s *rwb, off_t startblock,
               if (ret < 0)
                 {
                   rwb_semgive(&rwb->wrsem);
-                  return (ssize_t)ret;
+                  return ret;
                 }
 
               startblock += ret;
@@ -975,7 +1089,7 @@ ssize_t rwb_write(FAR struct rwbuffer_s *rwb, off_t startblock,
       ret = nxsem_wait(&rwb->rhsem);
       if (ret < 0)
         {
-          return (ssize_t)ret;
+          return ret;
         }
 
       if (rwb_overlap(rwb->rhblockstart, rwb->rhnblocks, startblock,
@@ -989,7 +1103,7 @@ ssize_t rwb_write(FAR struct rwbuffer_s *rwb, off_t startblock,
             {
               ferr("ERROR: rwb_invalidate_readahead failed: %d\n", ret);
               rwb_semgive(&rwb->rhsem);
-              return (ssize_t)ret;
+              return ret;
             }
 #else
           rwb_resetrhbuffer(rwb);
@@ -1005,40 +1119,14 @@ ssize_t rwb_write(FAR struct rwbuffer_s *rwb, off_t startblock,
     {
       finfo("startblock=%d wrbuffer=%p\n", startblock, wrbuffer);
 
-      /* Use the block cache unless the buffer size is bigger than block
-       * cache.
-       */
-
-      if (nblocks > rwb->wrmaxblocks)
+      ret = nxsem_wait(&rwb->wrsem);
+      if (ret < 0)
         {
-          /* First flush the cache */
-
-          ret = nxsem_wait(&rwb->wrsem);
-          if (ret < 0)
-            {
-              return (ssize_t)ret;
-            }
-
-          rwb_wrflush(rwb);
-          rwb_semgive(&rwb->wrsem);
-
-          /* Then transfer the data directly to the media */
-
-          ret = rwb->wrflush(rwb->dev, wrbuffer, startblock, nblocks);
+          return ret;
         }
-      else
-        {
-          /* Buffer the data in the write buffer */
 
-          ret = nxsem_wait(&rwb->wrsem);
-          if (ret < 0)
-            {
-              return (ssize_t)ret;
-            }
-
-          ret = rwb_writebuffer(rwb, startblock, nblocks, wrbuffer);
-          rwb_semgive(&rwb->wrsem);
-        }
+      ret = rwb_writebuffer(rwb, startblock, nblocks, wrbuffer);
+      rwb_semgive(&rwb->wrsem);
 
       /* On success, return the number of blocks that we were requested to
        * write.  This is for compatibility with the normal return of a block
@@ -1055,7 +1143,7 @@ ssize_t rwb_write(FAR struct rwbuffer_s *rwb, off_t startblock,
       ret = rwb->wrflush(rwb->dev, wrbuffer, startblock, nblocks);
     }
 
-  return (ssize_t)ret;
+  return ret;
 }
 
 /****************************************************************************
